@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /usr/bin/env bash
 
 MANUAL="\
 
@@ -33,8 +33,10 @@ Options:
   -d FILE, --diff FILE
                     set the path to diff file (default: ROOT/patches/ENGINE.diff) (*)
   -q, --quiet
-                    do not write loggin information; useful with -i to print just
+                    do not write logging information; useful with -i to print just
                     the patching information
+  -I, --include
+                    use include files rather than symbolic links
   -f, --force
                     force patching (*)
 
@@ -48,6 +50,7 @@ engine=""
 diff=""
 mode=shared
 force=""
+include=""
 newpatch=
 
 multiple_actions=
@@ -91,6 +94,7 @@ do
     (--shared) mode=shared ;;
     (--runtime) mode=runtime ;;
     (--force|-f) force=yes ;;
+    (--include|-I) include=yes ;;
     (--quiet|-q) quiet=yes ;;
     (*)
       echo "ERROR: Unknown option $prefix_option. Use -h for help."
@@ -116,7 +120,7 @@ if [ -z "$action" ] ; then
 fi
 
 if [ "$action" = options ] ; then
-  echo "--help -h --patch -p --save -s --save-originals --revert -R -r --list-engines -l --info -i --new --options --description --engine --mdroot --mode --diff --engine -e --mdroot --root --diff -d --mode -m --new -n --static --shared --runtime --force -f --quiet -q"
+  echo "--help -h --patch -p --save -s --save-originals --revert -R -r --list-engines -l --info -i --new --options --description --engine --mdroot --mode --diff --engine -e --mdroot --root --diff -d --mode -m --new -n --static --shared --runtime --force -f --quiet -q --include"
   exit 0
 fi
 
@@ -221,6 +225,7 @@ test -n "$quiet" || echo "diff file: $diff"
 if [ -f "$config" ]
 then
   test -n "$quiet" || echo "sourcing config file: $config"
+  # shellcheck disable=SC1090
   source "$config"
 fi
 
@@ -253,7 +258,7 @@ case "$action" in
       exit 1
       fi
     fi
-    if [ -L Plumed.h -o -L Plumed.inc -o -L Plumed.cmake ]
+    if [ -e Plumed.h ] || [ -e Plumed.inc ] || [ -e Plumed.cmake ]
     then
       if ( type -t plumed_before_revert 1>/dev/null || type -t plumed_after_revert 1>/dev/null) && ( type -t plumed_before_patch 1>/dev/null || type -t plumed_after_patch 1>/dev/null)
       then
@@ -280,11 +285,28 @@ case "$action" in
       test -n "$quiet" || echo "Executing plumed_before_patch function"
       plumed_before_patch
     fi
-    test -n "$quiet" || echo "Linking Plumed.h, Plumed.inc, and Plumed.cmake ($mode mode)"
-    ln -fs "$PLUMED_INCLUDEDIR/$PLUMED_PROGRAM_NAME/wrapper/Plumed.h" Plumed.h
-    ln -fs "$PLUMED_ROOT/src/lib/Plumed.inc.$mode" Plumed.inc
-    ln -fs "$PLUMED_ROOT/src/lib/Plumed.cmake.$mode" Plumed.cmake
+    
+    if [[ -z $PLUMED_PATCH_NO_INCLUDE ]]; then
+      #PLUMED_PATCH_NO_INCLUDE is special for programs that have an embedded plumed integration
+      #and do not need the Plumed.h, Plumed.inc, and Plumed.cmake files
+      if test -n "$include" ; then
+        test -n "$quiet" || echo "Including Plumed.h, Plumed.inc, and Plumed.cmake ($mode mode)"
+        echo "#include \"$PLUMED_INCLUDEDIR/$PLUMED_PROGRAM_NAME/wrapper/Plumed.h\"" > Plumed.h
+        echo "include $PLUMED_ROOT/src/lib/Plumed.inc.$mode" > Plumed.inc
+        echo "include($PLUMED_ROOT/src/lib/Plumed.cmake.$mode)" > Plumed.cmake
+      else
+        test -n "$quiet" || echo "Linking Plumed.h, Plumed.inc, and Plumed.cmake ($mode mode)"
+        ln -fs "$PLUMED_INCLUDEDIR/$PLUMED_PROGRAM_NAME/wrapper/Plumed.h" Plumed.h
+        ln -fs "$PLUMED_ROOT/src/lib/Plumed.inc.$mode" Plumed.inc
+        ln -fs "$PLUMED_ROOT/src/lib/Plumed.cmake.$mode" Plumed.cmake
+      fi
+    fi
 
+    if [[ -n $PLUMED_PATCH_EXTRA_FILES ]]; then
+      for file in $PLUMED_PATCH_EXTRA_FILES; do
+        cp "${diff}/$file" "$file"
+      done
+    fi
     if [ -d "$diff" ]; then
       test -n "$quiet" || echo "Patching with on-the-fly diff from stored originals"
       PREPLUMED=$(cd "$diff" ; find . -name "*.preplumed" | sort)
@@ -340,10 +362,14 @@ case "$action" in
     fi
   ;;
   (save)
-    if [ ! -L Plumed.h -o ! -L Plumed.inc -o ! -L Plumed.cmake ]
-    then
-      echo "ERROR: I cannot find Plumed.h, Plumed.inc, and Plumed.cmake files. You have likely not patched yet."
-      exit 1
+    if [[ -z $PLUMED_PATCH_NO_INCLUDE ]]; then
+      #PLUMED_PATCH_NO_INCLUDE is special for programs that have an embedded plumed integration
+      #and do not need the Plumed.h, Plumed.inc, and Plumed.cmake files
+      if [ ! -e Plumed.h ] || [ ! -e Plumed.inc ] || [ ! -e Plumed.cmake ]
+      then
+        echo "ERROR: I cannot find Plumed.h, Plumed.inc, and Plumed.cmake files. You have likely not patched yet."
+        exit 1
+      fi
     fi
     PREPLUMED=$(find . -name "*.preplumed" | sort)
     for file in $PLUMED_PREPLUMED_IGNORE;
@@ -368,6 +394,11 @@ case "$action" in
     test -n "$quiet" || echo "Saving your changes to $diff"
     test -n "$quiet" || echo "Preplumed files:"
     test -n "$quiet" || echo "$PREPLUMED"
+    if [[ -n $PLUMED_PATCH_EXTRA_FILES ]]; then
+      echo "Extra files:"
+      echo "$PLUMED_PATCH_EXTRA_FILES"
+    fi
+
     if [ -d "$diff" ] && [ -z "$save_originals" ]; then
       echo "This patch uses the dir format (originals are saved)"
       echo "Are you sure you want to save the single diff?"
@@ -400,14 +431,24 @@ case "$action" in
           cp "$file" "$diff/$file"
           cp "$bckfile" "$diff/$bckfile"
         else
-          echo "patch -u -l -b -F 5 -N --suffix=.preplumed \"${file}\" << \\EOF_EOF" >> "$diff"
-          diff -U 5 "${bckfile}" "$file" --label="$bckfile" --label="$file" >> "$diff"
-          echo "EOF_EOF"                                                   >> "$diff"
+          {
+            echo "patch -u -l -b -F 5 -N --suffix=.preplumed \"${file}\" << \\EOF_EOF"
+            diff -U 5 "${bckfile}" "$file" --label="$bckfile" --label="$file"
+            echo "EOF_EOF"
+          } >> "$diff"
         fi
       else
         echo "ERROR: File $file is missing"
       fi
     done
+    if [[ -n $PLUMED_PATCH_EXTRA_FILES ]]; then
+      test -n "$quiet" || echo "saving extra files"
+      for file in $PLUMED_PATCH_EXTRA_FILES; do
+        xx=${diff}/$file
+        mkdir -p "${xx%/*}"
+        cp "$file" "${diff}/$file"
+      done
+    fi
 cat <<EOF
 * If you want your patch to perform some arbitrary action before/after
 * patching the diff files, just add a function named
@@ -425,7 +466,7 @@ EOF
       test -n "$quiet" || echo "Executing plumed_before_revert function"
       plumed_before_revert
     fi
-    if [ ! -L Plumed.h -o ! -L Plumed.inc -o ! -L Plumed.cmake ]
+    if [ ! -e Plumed.h ] || [ ! -e Plumed.inc ] || [ ! -e Plumed.cmake ]
     then
       echo "WARNING: I cannot find Plumed.h, Plumed.inc, and Plumed.cmake files. You have likely not patched yet."
     else
@@ -443,6 +484,12 @@ EOF
         touch "$file"
       done
     fi
+    if [[ -n $PLUMED_PATCH_EXTRA_FILES ]]; then
+      test -n "$quiet" || echo "Removing the extra files"
+      for file in $PLUMED_PATCH_EXTRA_FILES; do
+        rm -v "$file"
+      done
+    fi
     if type -t plumed_after_revert 1>/dev/null ; then
       test -n "$quiet" || echo "Executing plumed_after_revert function"
       plumed_after_revert
