@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2020 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -21,11 +21,9 @@
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Bias.h"
 #include "tools/Random.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include <ctime>
 
-using namespace std;
-
 namespace PLMD {
 namespace bias {
 
@@ -87,7 +85,7 @@ class ABMD : public Bias {
   std::vector<double> kappa;
   std::vector<double> temp;
   std::vector<int> seed;
-  vector<Random> random;
+  std::vector<Random> random;
 public:
   explicit ABMD(const ActionOptions&);
   void calculate() override;
@@ -116,36 +114,51 @@ ABMD::ABMD(const ActionOptions&ao):
   min(getNumberOfArguments(),-1.0),
   kappa(getNumberOfArguments(),0.0),
   temp(getNumberOfArguments(),0.0),
-  seed(getNumberOfArguments(),time(0)),
-  random(getNumberOfArguments())
-{
+  seed(getNumberOfArguments(),std::time(0)),
+  random(getNumberOfArguments()) {
   // Note : parseVector will check that number of arguments is correct
   parseVector("KAPPA",kappa);
   parseVector("MIN",min);
-  if(min.size()==0) min.assign(getNumberOfArguments(),-1.0);
-  if(min.size()!=getNumberOfArguments()) error("MIN array should have the same size as ARG array");
+  if(min.size()==0) {
+    min.assign(getNumberOfArguments(),-1.0);
+  }
+  if(min.size()!=getNumberOfArguments()) {
+    error("MIN array should have the same size as ARG array");
+  }
   parseVector("NOISE",temp);
   parseVector("SEED",seed);
   parseVector("TO",to);
   checkRead();
 
   log.printf("  min");
-  for(unsigned i=0; i<min.size(); i++) log.printf(" %f",min[i]);
+  for(unsigned i=0; i<min.size(); i++) {
+    log.printf(" %f",min[i]);
+  }
   log.printf("\n");
   log.printf("  to");
-  for(unsigned i=0; i<to.size(); i++) log.printf(" %f",to[i]);
+  for(unsigned i=0; i<to.size(); i++) {
+    log.printf(" %f",to[i]);
+  }
   log.printf("\n");
   log.printf("  with force constant");
-  for(unsigned i=0; i<kappa.size(); i++) log.printf(" %f",kappa[i]);
+  for(unsigned i=0; i<kappa.size(); i++) {
+    log.printf(" %f",kappa[i]);
+  }
   log.printf("\n");
 
   for(unsigned i=0; i<getNumberOfArguments(); i++) {
     std::string str_min=getPntrToArgument(i)->getName()+"_min";
-    addComponent(str_min); componentIsNotPeriodic(str_min);
-    if(min[i]!=-1.0) getPntrToComponent(str_min)->set(min[i]);
+    addComponent(str_min);
+    componentIsNotPeriodic(str_min);
+    if(min[i]!=-1.0) {
+      getPntrToComponent(str_min)->set(min[i]);
+    }
   }
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {random[i].setSeed(-seed[i]);}
-  addComponent("force2"); componentIsNotPeriodic("force2");
+  for(unsigned i=0; i<getNumberOfArguments(); i++) {
+    random[i].setSeed(-seed[i]);
+  }
+  addComponent("force2");
+  componentIsNotPeriodic("force2");
 }
 
 
@@ -160,7 +173,10 @@ void ABMD::calculate() {
     double diff=temp[i];
     if(diff>0) {
       noise = 2.*random[i].Gaussian()*diff;
-      if(cv2<=diff) { diff=0.; temp[i]=0.; }
+      if(cv2<=diff) {
+        diff=0.;
+        temp[i]=0.;
+      }
     }
 
     // min < 0 means that the variable has not been used in the input file, so the current position of the CV is used
