@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -40,12 +40,13 @@ information as to how to go about implementing a new bias.
 class Bias :
   public ActionPilot,
   public ActionWithValue,
-  public ActionWithArguments
-{
+  public ActionWithArguments {
 /// the vector of the forces
   std::vector<double> outputForces;
 /// the pointer to the bias component
   Value *valueBias;
+  std::vector<double> f;
+  std::vector<double> forces;
 protected:
 /// set the force from the bias on argument i, this automatically set the partial derivative of the bias with respect to i to -f
   void setOutputForce(int i,double f);
