@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2020 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,15 +20,10 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Bias.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "tools/Grid.h"
 #include "tools/Exception.h"
 #include "tools/File.h"
-#include <memory>
-
-
-using namespace std;
-
 
 namespace PLMD {
 namespace bias {
@@ -135,11 +130,12 @@ void External::registerKeywords(Keywords& keys) {
 }
 
 External::External(const ActionOptions& ao):
-  PLUMED_BIAS_INIT(ao)
-{
-  string filename;
+  PLUMED_BIAS_INIT(ao) {
+  std::string filename;
   parse("FILE",filename);
-  if( filename.length()==0 ) error("No external potential file was specified");
+  if( filename.length()==0 ) {
+    error("No external potential file was specified");
+  }
   bool sparsegrid=false;
   parseFlag("SPARSE",sparsegrid);
   bool nospline=false;
@@ -151,25 +147,35 @@ External::External(const ActionOptions& ao):
 
   log.printf("  External potential from file %s\n",filename.c_str());
   log.printf("  Multiplied by %lf\n",scale_);
-  if(spline) {log.printf("  External potential uses spline interpolation\n");}
-  if(sparsegrid) {log.printf("  External potential uses sparse grid\n");}
+  if(spline) {
+    log.printf("  External potential uses spline interpolation\n");
+  }
+  if(sparsegrid) {
+    log.printf("  External potential uses sparse grid\n");
+  }
 
 // read grid
-  IFile gridfile; gridfile.open(filename);
+  IFile gridfile;
+  gridfile.open(filename);
   std::string funcl=getLabel() + ".bias";
   BiasGrid_=GridBase::create(funcl,getArguments(),gridfile,sparsegrid,spline,true);
-  if(BiasGrid_->getDimension()!=getNumberOfArguments()) error("mismatch between dimensionality of input grid and number of arguments");
+  if(BiasGrid_->getDimension()!=getNumberOfArguments()) {
+    error("mismatch between dimensionality of input grid and number of arguments");
+  }
   for(unsigned i=0; i<getNumberOfArguments(); ++i) {
-    if( getPntrToArgument(i)->isPeriodic()!=BiasGrid_->getIsPeriodic()[i] ) error("periodicity mismatch between arguments and input bias");
+    if( getPntrToArgument(i)->isPeriodic()!=BiasGrid_->getIsPeriodic()[i] ) {
+      error("periodicity mismatch between arguments and input bias");
+    }
   }
 }
 
-void External::calculate()
-{
+void External::calculate() {
   unsigned ncv=getNumberOfArguments();
-  vector<double> cv(ncv), der(ncv);
+  std::vector<double> cv(ncv), der(ncv);
 
-  for(unsigned i=0; i<ncv; ++i) {cv[i]=getArgument(i);}
+  for(unsigned i=0; i<ncv; ++i) {
+    cv[i]=getArgument(i);
+  }
 
   double ene=scale_*BiasGrid_->getValueAndDerivatives(cv,der);
 
