@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,11 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Bias.h"
-#include "ActionRegister.h"
-
-
-using namespace std;
-
+#include "core/ActionRegister.h"
 
 namespace PLMD {
 namespace bias {
@@ -60,6 +56,15 @@ PRINT ARG=restraint.bias
 */
 //+ENDPLUMEDOC
 
+//+PLUMEDOC BIAS RESTRAINT_SCALAR
+/*
+Adds harmonic and/or linear restraints on one or more scalar variables.
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
 class Restraint : public Bias {
   std::vector<double> at;
   std::vector<double> kappa;
@@ -71,11 +76,12 @@ public:
   static void registerKeywords(Keywords& keys);
 };
 
-PLUMED_REGISTER_ACTION(Restraint,"RESTRAINT")
+PLUMED_REGISTER_ACTION(Restraint,"RESTRAINT_SCALAR")
 
 void Restraint::registerKeywords(Keywords& keys) {
   Bias::registerKeywords(keys);
   keys.use("ARG");
+  keys.setDisplayName("RESTRAINT");
   keys.add("compulsory","SLOPE","0.0","specifies that the restraint is linear and what the values of the force constants on each of the variables are");
   keys.add("compulsory","KAPPA","0.0","specifies that the restraint is harmonic and what the values of the force constants on each of the variables are");
   keys.add("compulsory","AT","the position of the restraint");
@@ -86,21 +92,26 @@ Restraint::Restraint(const ActionOptions&ao):
   PLUMED_BIAS_INIT(ao),
   at(getNumberOfArguments()),
   kappa(getNumberOfArguments(),0.0),
-  slope(getNumberOfArguments(),0.0)
-{
+  slope(getNumberOfArguments(),0.0) {
   parseVector("SLOPE",slope);
   parseVector("KAPPA",kappa);
   parseVector("AT",at);
   checkRead();
 
   log.printf("  at");
-  for(unsigned i=0; i<at.size(); i++) log.printf(" %f",at[i]);
+  for(unsigned i=0; i<at.size(); i++) {
+    log.printf(" %f",at[i]);
+  }
   log.printf("\n");
   log.printf("  with harmonic force constant");
-  for(unsigned i=0; i<kappa.size(); i++) log.printf(" %f",kappa[i]);
+  for(unsigned i=0; i<kappa.size(); i++) {
+    log.printf(" %f",kappa[i]);
+  }
   log.printf("\n");
   log.printf("  and linear force constant");
-  for(unsigned i=0; i<slope.size(); i++) log.printf(" %f",slope[i]);
+  for(unsigned i=0; i<slope.size(); i++) {
+    log.printf(" %f",slope[i]);
+  }
   log.printf("\n");
 
   addComponent("force2");
