@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,7 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Bias.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 
 namespace PLMD {
 namespace bias {
@@ -35,10 +35,16 @@ The restraining potential starts acting on the system when the value of the CV i
 minus an offset \f$o_i\f$ (OFFSET).
 The expression for the bias due to the wall is given by:
 
+for UPPER_WALLS:
 \f$
   \sum_i {k_i}((x_i-a_i+o_i)/s_i)^e_i
 \f$
 
+for LOWER_WALLS:
+\f$
+  \sum_i {k_i}|(x_i-a_i-o_i)/s_i|^e_i
+\f$
+
 \f$k_i\f$ (KAPPA) is an energy constant in internal unit of the code, \f$s_i\f$ (EPS) a rescaling factor and
 \f$e_i\f$ (EXP) the exponent determining the power law. By default: EXP = 2, EPS = 1.0, OFFSET = 0.
 
@@ -60,6 +66,16 @@ PRINT ARG=uwall.bias,lwall.bias
 */
 //+ENDPLUMEDOC
 
+//+PLUMEDOC BIAS UPPER_WALLS_SCALAR
+/*
+Defines a wall for the value of one or more collective variables,
+ which limits the region of the phase space accessible during the simulation.
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
 class UWalls : public Bias {
   std::vector<double> at;
   std::vector<double> kappa;
@@ -72,11 +88,13 @@ public:
   static void registerKeywords(Keywords& keys);
 };
 
-PLUMED_REGISTER_ACTION(UWalls,"UPPER_WALLS")
+PLUMED_REGISTER_ACTION(UWalls,"UPPER_WALLS_SCALAR")
 
 void UWalls::registerKeywords(Keywords& keys) {
   Bias::registerKeywords(keys);
+  keys.setDisplayName("UPPER_WALLS");
   keys.use("ARG");
+  keys.add("hidden","NO_ACTION_LOG","suppresses printing from action on the log");
   keys.add("compulsory","AT","the positions of the wall. The a_i in the expression for a wall.");
   keys.add("compulsory","KAPPA","the force constant for the wall.  The k_i in the expression for a wall.");
   keys.add("compulsory","OFFSET","0.0","the offset for the start of the wall.  The o_i in the expression for a wall.");
@@ -91,8 +109,7 @@ UWalls::UWalls(const ActionOptions&ao):
   kappa(getNumberOfArguments(),0.0),
   exp(getNumberOfArguments(),2.0),
   eps(getNumberOfArguments(),1.0),
-  offset(getNumberOfArguments(),0.0)
-{
+  offset(getNumberOfArguments(),0.0) {
   // Note : the sizes of these vectors are checked automatically by parseVector
   parseVector("OFFSET",offset);
   parseVector("EPS",eps);
@@ -102,22 +119,33 @@ UWalls::UWalls(const ActionOptions&ao):
   checkRead();
 
   log.printf("  at");
-  for(unsigned i=0; i<at.size(); i++) log.printf(" %f",at[i]);
+  for(unsigned i=0; i<at.size(); i++) {
+    log.printf(" %f",at[i]);
+  }
   log.printf("\n");
   log.printf("  with an offset");
-  for(unsigned i=0; i<offset.size(); i++) log.printf(" %f",offset[i]);
+  for(unsigned i=0; i<offset.size(); i++) {
+    log.printf(" %f",offset[i]);
+  }
   log.printf("\n");
   log.printf("  with force constant");
-  for(unsigned i=0; i<kappa.size(); i++) log.printf(" %f",kappa[i]);
+  for(unsigned i=0; i<kappa.size(); i++) {
+    log.printf(" %f",kappa[i]);
+  }
   log.printf("\n");
   log.printf("  and exponent");
-  for(unsigned i=0; i<exp.size(); i++) log.printf(" %f",exp[i]);
+  for(unsigned i=0; i<exp.size(); i++) {
+    log.printf(" %f",exp[i]);
+  }
   log.printf("\n");
   log.printf("  rescaled");
-  for(unsigned i=0; i<eps.size(); i++) log.printf(" %f",eps[i]);
+  for(unsigned i=0; i<eps.size(); i++) {
+    log.printf(" %f",eps[i]);
+  }
   log.printf("\n");
 
-  addComponent("force2"); componentIsNotPeriodic("force2");
+  addComponent("force2");
+  componentIsNotPeriodic("force2");
 }
 
 void UWalls::calculate() {
