@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,17 +20,14 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "CLTool.h"
-#include "CLToolRegister.h"
+#include "core/CLToolRegister.h"
 #include "tools/Tools.h"
 #include "config/Config.h"
 #include "core/ActionRegister.h"
 #include <cstdio>
 #include <string>
-#include <vector>
 #include <iostream>
 
-using namespace std;
-
 namespace PLMD {
 namespace cltools {
 
@@ -55,13 +52,12 @@ plumed manual --action DISTANCE
 //+ENDPLUMEDOC
 
 class Manual:
-  public CLTool
-{
+  public CLTool {
 public:
   static void registerKeywords( Keywords& keys );
   explicit Manual(const CLToolOptions& co );
   int main(FILE* in, FILE*out,Communicator& pc) override;
-  string description()const override {
+  std::string description()const override {
     return "print out a description of the keywords for an action in html";
   }
 };
@@ -76,24 +72,29 @@ void Manual::registerKeywords( Keywords& keys ) {
 }
 
 Manual::Manual(const CLToolOptions& co ):
-  CLTool(co)
-{
+  CLTool(co) {
   inputdata=commandline;
 }
 
 int Manual::main(FILE* in, FILE*out,Communicator& pc) {
 
   std::string action;
-  if( !parse("--action",action) ) return 1;
+  if( !parse("--action",action) ) {
+    return 1;
+  }
   std::cerr<<"LIST OF DOCUMENTED ACTIONS:\n";
   std::cerr<<actionRegister()<<"\n";
   std::cerr<<"LIST OF DOCUMENTED COMMAND LINE TOOLS:\n";
   std::cerr<<cltoolRegister()<<"\n\n";
-  bool vimout; parseFlag("--vim",vimout);
-  bool spellout; parseFlag("--spelling",spellout);
-  if( vimout && spellout ) error("can only use one of --vim and --spelling at a time");
+  bool vimout;
+  parseFlag("--vim",vimout);
+  bool spellout;
+  parseFlag("--spelling",spellout);
+  if( vimout && spellout ) {
+    error("can only use one of --vim and --spelling at a time");
+  }
   if( !actionRegister().printManual(action,vimout,spellout) && !cltoolRegister().printManual(action,spellout) ) {
-    fprintf(stderr,"specified action is not registered\n");
+    std::fprintf(stderr,"specified action is not registered\n");
     return 1;
   }
 
