@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2018-2021 The plumed team
+   Copyright (c) 2018-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,7 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "CLTool.h"
-#include "CLToolRegister.h"
+#include "core/CLToolRegister.h"
 #include "tools/Tools.h"
 #include "core/ActionRegister.h"
 #include "tools/IFile.h"
@@ -32,8 +32,6 @@
 #include <array>
 #include <limits>
 
-using namespace std;
-
 namespace PLMD {
 namespace cltools {
 
@@ -100,13 +98,12 @@ Additional lines in `list.txt` will just be ignored.
 //+ENDPLUMEDOC
 
 class PdbRenumber:
-  public CLTool
-{
+  public CLTool {
 public:
   static void registerKeywords( Keywords& keys );
   explicit PdbRenumber(const CLToolOptions& co );
   int main(FILE* in, FILE*out,Communicator& pc) override;
-  string description()const override {
+  std::string description()const override {
     return "Modify atom numbers in a PDB, possibly using hybrid-36 coding";
   }
 };
@@ -122,8 +119,7 @@ void PdbRenumber::registerKeywords( Keywords& keys ) {
 }
 
 PdbRenumber::PdbRenumber(const CLToolOptions& co ):
-  CLTool(co)
-{
+  CLTool(co) {
   inputdata=commandline;
 }
 
@@ -143,14 +139,14 @@ int PdbRenumber::main(FILE* in, FILE*out,Communicator& pc) {
 
   plumed_assert(ipdb.length()>0) << "please specify the input PDB with --ipdb";
   plumed_assert(opdb.length()>0) << "please specify the onput PDB with --opdb";
-  fprintf(out,"  with input PDB: %s\n",ipdb.c_str());
-  fprintf(out,"  with output PDB: %s\n",opdb.c_str());
+  std::fprintf(out,"  with input PDB: %s\n",ipdb.c_str());
+  std::fprintf(out,"  with output PDB: %s\n",opdb.c_str());
 
   std::vector<unsigned> serials;
 
   if(atomnumbers.length()>0) {
     plumed_assert(iat==0) << "it is not possible to use both --atomnumbers and --firstatomnumber";
-    fprintf(out,"  reading atom numbers from file %s\n",atomnumbers.c_str());
+    std::fprintf(out,"  reading atom numbers from file %s\n",atomnumbers.c_str());
     IFile ifile;
     ifile.open(atomnumbers);
     std::string line;
@@ -160,8 +156,10 @@ int PdbRenumber::main(FILE* in, FILE*out,Communicator& pc) {
       serials.push_back(i);
     }
   } else {
-    if(iat==0) iat=1;
-    fprintf(out,"  with atoms starting from %u\n",iat);
+    if(iat==0) {
+      iat=1;
+    }
+    std::fprintf(out,"  with atoms starting from %u\n",iat);
   }
 
   IFile ifile;
@@ -188,7 +186,9 @@ int PdbRenumber::main(FILE* in, FILE*out,Communicator& pc) {
       ofile << line.substr(0,6) << &at[0] << line.substr(11) << "\n";
       iat++;
     } else {
-      if(record=="END" || record=="ENDMDL") iat=0;
+      if(record=="END" || record=="ENDMDL") {
+        iat=0;
+      }
       ofile << line << "\n";
     }
   }
