@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2019 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,16 +20,11 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Colvar.h"
+#include "tools/Communicator.h"
 #include "tools/NeighborList.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "tools/SwitchingFunction.h"
 
-#include <string>
-#include <cmath>
-#include <memory>
-
-using namespace std;
-
 namespace PLMD {
 namespace colvar {
 
@@ -86,17 +81,16 @@ WEIGHT is the 1/(number of contacts) giving equal weight to each contact.
 When using native contact Q switch function, please cite \cite best2013
 
 \plumedfile
-# Full example available in regtest/basic/rt72/
+# The full (much-longer) example available in regtest/basic/rt72/
 
 CONTACTMAP ...
 ATOMS1=1,67 SWITCH1={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.4059} WEIGHT1=0.003597
 ATOMS2=1,68 SWITCH2={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.4039} WEIGHT2=0.003597
 ATOMS3=1,69 SWITCH3={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3215} WEIGHT3=0.003597
-[snip]
-ATOMS275=183,213 SWITCH275={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.355} WEIGHT275=0.003597
-ATOMS276=183,234 SWITCH276={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.428} WEIGHT276=0.003597
-ATOMS277=183,250 SWITCH277={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3832} WEIGHT277=0.003597
-ATOMS278=197,220 SWITCH278={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3827} WEIGHT278=0.003597
+ATOMS4=5,61 SWITCH4={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.4277} WEIGHT4=0.003597
+ATOMS5=5,67 SWITCH5={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3851} WEIGHT5=0.003597
+ATOMS6=5,68 SWITCH6={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3811} WEIGHT6=0.003597
+ATOMS7=5,69 SWITCH7={Q R_0=0.01 BETA=50.0 LAMBDA=1.5 REF=0.3133} WEIGHT7=0.003597
 LABEL=cmap
 SUM
 ... CONTACTMAP
@@ -113,13 +107,13 @@ private:
   bool pbc, serial, docomp, dosum, docmdist;
   std::unique_ptr<NeighborList> nl;
   std::vector<SwitchingFunction> sfs;
-  vector<double> reference, weight;
+  std::vector<double> reference, weight;
 public:
   static void registerKeywords( Keywords& keys );
   explicit ContactMap(const ActionOptions&);
 // active methods:
-  virtual void calculate();
-  void checkFieldsAllowed() {}
+  void calculate() override;
+  void checkFieldsAllowed() override {}
 };
 
 PLUMED_REGISTER_ACTION(ContactMap,"CONTACTMAP")
@@ -153,12 +147,13 @@ ContactMap::ContactMap(const ActionOptions&ao):
   serial(false),
   docomp(true),
   dosum(false),
-  docmdist(false)
-{
+  docmdist(false) {
   parseFlag("SERIAL",serial);
   parseFlag("SUM",dosum);
   parseFlag("CMDIST",docmdist);
-  if(docmdist==true&&dosum==true) error("You cannot use SUM and CMDIST together");
+  if(docmdist==true&&dosum==true) {
+    error("You cannot use SUM and CMDIST together");
+  }
   bool nopbc=!pbc;
   parseFlag("NOPBC",nopbc);
   pbc=!nopbc;
@@ -167,39 +162,61 @@ ContactMap::ContactMap(const ActionOptions&ao):
   std::vector<AtomNumber> t, ga_lista, gb_lista;
   for(int i=1;; ++i ) {
     parseAtomList("ATOMS", i, t );
-    if( t.empty() ) break;
+    if( t.empty() ) {
+      break;
+    }
 
     if( t.size()!=2 ) {
-      std::string ss; Tools::convert(i,ss);
+      std::string ss;
+      Tools::convert(i,ss);
       error("ATOMS" + ss + " keyword has the wrong number of atoms");
     }
-    ga_lista.push_back(t[0]); gb_lista.push_back(t[1]);
+    ga_lista.push_back(t[0]);
+    gb_lista.push_back(t[1]);
     t.resize(0);
 
     // Add a value for this contact
-    std::string num; Tools::convert(i,num);
-    if(!dosum&&!docmdist) {addComponentWithDerivatives("contact-"+num); componentIsNotPeriodic("contact-"+num);}
+    std::string num;
+    Tools::convert(i,num);
+    if(!dosum&&!docmdist) {
+      addComponentWithDerivatives("contact-"+num);
+      componentIsNotPeriodic("contact-"+num);
+    }
   }
   // Create neighbour lists
-  nl.reset(new NeighborList(ga_lista,gb_lista,true,pbc,getPbc()));
+  nl=Tools::make_unique<NeighborList>(ga_lista,gb_lista,serial,true,pbc,getPbc(),comm);
 
   // Read in switching functions
-  std::string errors; sfs.resize( ga_lista.size() ); unsigned nswitch=0;
+  std::string errors;
+  sfs.resize( ga_lista.size() );
+  unsigned nswitch=0;
   for(unsigned i=0; i<ga_lista.size(); ++i) {
-    std::string num, sw1; Tools::convert(i+1, num);
-    if( !parseNumbered( "SWITCH", i+1, sw1 ) ) break;
-    nswitch++; sfs[i].set(sw1,errors);
-    if( errors.length()!=0 ) error("problem reading SWITCH" + num + " keyword : " + errors );
+    std::string num, sw1;
+    Tools::convert(i+1, num);
+    if( !parseNumbered( "SWITCH", i+1, sw1 ) ) {
+      break;
+    }
+    nswitch++;
+    sfs[i].set(sw1,errors);
+    if( errors.length()!=0 ) {
+      error("problem reading SWITCH" + num + " keyword : " + errors );
+    }
   }
   if( nswitch==0 ) {
-    std::string sw; parse("SWITCH",sw);
-    if(sw.length()==0) error("no switching function specified use SWITCH keyword");
+    std::string sw;
+    parse("SWITCH",sw);
+    if(sw.length()==0) {
+      error("no switching function specified use SWITCH keyword");
+    }
     for(unsigned i=0; i<ga_lista.size(); ++i) {
       sfs[i].set(sw,errors);
-      if( errors.length()!=0 ) error("problem reading SWITCH keyword : " + errors );
+      if( errors.length()!=0 ) {
+        error("problem reading SWITCH keyword : " + errors );
+      }
     }
   } else if( nswitch!=sfs.size()  ) {
-    std::string num; Tools::convert(nswitch+1, num);
+    std::string num;
+    Tools::convert(nswitch+1, num);
     error("missing SWITCH" + num + " keyword");
   }
 
@@ -207,7 +224,9 @@ ContactMap::ContactMap(const ActionOptions&ao):
   nswitch=0;
   reference.resize(ga_lista.size(), 0.);
   for(unsigned i=0; i<ga_lista.size(); ++i) {
-    if( !parseNumbered( "REFERENCE", i+1, reference[i] ) ) break;
+    if( !parseNumbered( "REFERENCE", i+1, reference[i] ) ) {
+      break;
+    }
     nswitch++;
   }
   if( nswitch==0 ) {
@@ -217,13 +236,17 @@ ContactMap::ContactMap(const ActionOptions&ao):
       nswitch++;
     }
   }
-  if(nswitch == 0 && docmdist) error("with CMDIST one must use REFERENCE to setup the reference contact map");
+  if(nswitch == 0 && docmdist) {
+    error("with CMDIST one must use REFERENCE to setup the reference contact map");
+  }
 
   // Read in weight values
   nswitch=0;
   weight.resize(ga_lista.size(), 1.0);
   for(unsigned i=0; i<ga_lista.size(); ++i) {
-    if( !parseNumbered( "WEIGHT", i+1, weight[i] ) ) break;
+    if( !parseNumbered( "WEIGHT", i+1, weight[i] ) ) {
+      break;
+    }
     nswitch++;
   }
   if( nswitch==0 ) {
@@ -234,18 +257,20 @@ ContactMap::ContactMap(const ActionOptions&ao):
     nswitch = ga_lista.size();
   }
 
-  // Ouput details of all contacts
+  // Output details of all contacts
   for(unsigned i=0; i<sfs.size(); ++i) {
     log.printf("  The %uth contact is calculated from atoms : %d %d. Inflection point of switching function is at %s. Reference contact value is %f\n",
                i+1, ga_lista[i].serial(), gb_lista[i].serial(), ( sfs[i].description() ).c_str(), reference[i] );
   }
 
   if(dosum) {
-    addValueWithDerivatives(); setNotPeriodic();
+    addValueWithDerivatives();
+    setNotPeriodic();
     log.printf("  colvar is sum of all contacts in contact map\n");
   }
   if(docmdist) {
-    addValueWithDerivatives(); setNotPeriodic();
+    addValueWithDerivatives();
+    setNotPeriodic();
     log.printf("  colvar is distance between the contact map matrix and the provided reference matrix\n");
   }
 
@@ -318,12 +343,16 @@ void ContactMap::calculate() {
 
   if(!serial) {
     comm.Sum(&ncoord,1);
-    if(!deriv.empty()) comm.Sum(&deriv[0][0],3*deriv.size());
+    if(!deriv.empty()) {
+      comm.Sum(&deriv[0][0],3*deriv.size());
+    }
     comm.Sum(&virial[0][0],9);
   }
 
   if( !docomp ) {
-    for(unsigned i=0; i<deriv.size(); ++i) setAtomsDerivatives(i,deriv[i]);
+    for(unsigned i=0; i<deriv.size(); ++i) {
+      setAtomsDerivatives(i,deriv[i]);
+    }
     setValue           (ncoord);
     setBoxDerivatives  (virial);
   }
