@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2013-2021 The plumed team
+   Copyright (c) 2013-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -24,10 +24,6 @@
 #include "tools/Communicator.h"
 #include "tools/OpenMP.h"
 
-#include <string>
-
-using namespace std;
-
 namespace PLMD {
 namespace colvar {
 
@@ -47,12 +43,11 @@ CoordinationBase::CoordinationBase(const ActionOptions&ao):
   pbc(true),
   serial(false),
   invalidateList(true),
-  firsttime(true)
-{
+  firsttime(true) {
 
   parseFlag("SERIAL",serial);
 
-  vector<AtomNumber> ga_lista,gb_lista;
+  std::vector<AtomNumber> ga_lista,gb_lista;
   parseAtomList("GROUPA",ga_lista);
   parseAtomList("GROUPB",gb_lista);
 
@@ -71,18 +66,29 @@ CoordinationBase::CoordinationBase(const ActionOptions&ao):
   parseFlag("NLIST",doneigh);
   if(doneigh) {
     parse("NL_CUTOFF",nl_cut);
-    if(nl_cut<=0.0) error("NL_CUTOFF should be explicitly specified and positive");
+    if(nl_cut<=0.0) {
+      error("NL_CUTOFF should be explicitly specified and positive");
+    }
     parse("NL_STRIDE",nl_st);
-    if(nl_st<=0) error("NL_STRIDE should be explicitly specified and positive");
+    if(nl_st<=0) {
+      error("NL_STRIDE should be explicitly specified and positive");
+    }
   }
 
-  addValueWithDerivatives(); setNotPeriodic();
+  addValueWithDerivatives();
+  setNotPeriodic();
   if(gb_lista.size()>0) {
-    if(doneigh)  nl.reset( new NeighborList(ga_lista,gb_lista,serial,dopair,pbc,getPbc(),comm,nl_cut,nl_st) );
-    else         nl.reset( new NeighborList(ga_lista,gb_lista,serial,dopair,pbc,getPbc(),comm) );
+    if(doneigh) {
+      nl=Tools::make_unique<NeighborList>(ga_lista,gb_lista,serial,dopair,pbc,getPbc(),comm,nl_cut,nl_st);
+    } else {
+      nl=Tools::make_unique<NeighborList>(ga_lista,gb_lista,serial,dopair,pbc,getPbc(),comm);
+    }
   } else {
-    if(doneigh)  nl.reset( new NeighborList(ga_lista,serial,pbc,getPbc(),comm,nl_cut,nl_st) );
-    else         nl.reset( new NeighborList(ga_lista,serial,pbc,getPbc(),comm) );
+    if(doneigh) {
+      nl=Tools::make_unique<NeighborList>(ga_lista,serial,pbc,getPbc(),comm,nl_cut,nl_st);
+    } else {
+      nl=Tools::make_unique<NeighborList>(ga_lista,serial,pbc,getPbc(),comm);
+    }
   }
 
   requestAtoms(nl->getFullAtomList());
@@ -90,18 +96,27 @@ CoordinationBase::CoordinationBase(const ActionOptions&ao):
   log.printf("  between two groups of %u and %u atoms\n",static_cast<unsigned>(ga_lista.size()),static_cast<unsigned>(gb_lista.size()));
   log.printf("  first group:\n");
   for(unsigned int i=0; i<ga_lista.size(); ++i) {
-    if ( (i+1) % 25 == 0 ) log.printf("  \n");
+    if ( (i+1) % 25 == 0 ) {
+      log.printf("  \n");
+    }
     log.printf("  %d", ga_lista[i].serial());
   }
   log.printf("  \n  second group:\n");
   for(unsigned int i=0; i<gb_lista.size(); ++i) {
-    if ( (i+1) % 25 == 0 ) log.printf("  \n");
+    if ( (i+1) % 25 == 0 ) {
+      log.printf("  \n");
+    }
     log.printf("  %d", gb_lista[i].serial());
   }
   log.printf("  \n");
-  if(pbc) log.printf("  using periodic boundary conditions\n");
-  else    log.printf("  without periodic boundary conditions\n");
-  if(dopair) log.printf("  with PAIR option\n");
+  if(pbc) {
+    log.printf("  using periodic boundary conditions\n");
+  } else {
+    log.printf("  without periodic boundary conditions\n");
+  }
+  if(dopair) {
+    log.printf("  with PAIR option\n");
+  }
   if(doneigh) {
     log.printf("  using neighbor lists with\n");
     log.printf("  update every %d steps and cutoff %f\n",nl_st,nl_cut);
@@ -121,19 +136,22 @@ void CoordinationBase::prepare() {
     } else {
       requestAtoms(nl->getReducedAtomList());
       invalidateList=false;
-      if(getExchangeStep()) error("Neighbor lists should be updated on exchange steps - choose a NL_STRIDE which divides the exchange stride!");
+      if(getExchangeStep()) {
+        error("Neighbor lists should be updated on exchange steps - choose a NL_STRIDE which divides the exchange stride!");
+      }
+    }
+    if(getExchangeStep()) {
+      firsttime=true;
     }
-    if(getExchangeStep()) firsttime=true;
   }
 }
 
 // calculator
-void CoordinationBase::calculate()
-{
+void CoordinationBase::calculate() {
 
   double ncoord=0.;
   Tensor virial;
-  vector<Vector> deriv(getNumberOfAtoms());
+  std::vector<Vector> deriv(getNumberOfAtoms());
 
   if(nl->getStride()>0 && invalidateList) {
     nl->update(getPositions());
@@ -151,7 +169,13 @@ void CoordinationBase::calculate()
 
   unsigned nt=OpenMP::getNumThreads();
   const unsigned nn=nl->size();
-  if(nt*stride*10>nn) nt=1;
+  if(nt*stride*10>nn) {
+    nt=1;
+  }
+
+  const unsigned elementsPerRank = std::ceil(double(nn)/stride);
+  const unsigned int start= rank*elementsPerRank;
+  const unsigned int end = ((start + elementsPerRank)< nn)?(start + elementsPerRank): nn;
 
   #pragma omp parallel num_threads(nt)
   {
@@ -159,13 +183,15 @@ void CoordinationBase::calculate()
     Tensor omp_virial;
 
     #pragma omp for reduction(+:ncoord) nowait
-    for(unsigned int i=rank; i<nn; i+=stride) {
+    for(unsigned int i=start; i<end; ++i) {
 
       Vector distance;
-      unsigned i0=nl->getClosePair(i).first;
-      unsigned i1=nl->getClosePair(i).second;
+      const unsigned i0=nl->getClosePair(i).first;
+      const unsigned i1=nl->getClosePair(i).second;
 
-      if(getAbsoluteIndex(i0)==getAbsoluteIndex(i1)) continue;
+      if(getAbsoluteIndex(i0)==getAbsoluteIndex(i1)) {
+        continue;
+      }
 
       if(pbc) {
         distance=pbcDistance(getPosition(i0),getPosition(i1));
@@ -191,18 +217,24 @@ void CoordinationBase::calculate()
     }
     #pragma omp critical
     if(nt>1) {
-      for(unsigned i=0; i<getPositions().size(); i++) deriv[i]+=omp_deriv[i];
+      for(unsigned i=0; i<getPositions().size(); i++) {
+        deriv[i]+=omp_deriv[i];
+      }
       virial+=omp_virial;
     }
   }
 
   if(!serial) {
     comm.Sum(ncoord);
-    if(!deriv.empty()) comm.Sum(&deriv[0][0],3*deriv.size());
+    if(!deriv.empty()) {
+      comm.Sum(&deriv[0][0],3*deriv.size());
+    }
     comm.Sum(virial);
   }
 
-  for(unsigned i=0; i<deriv.size(); ++i) setAtomsDerivatives(i,deriv[i]);
+  for(unsigned i=0; i<deriv.size(); ++i) {
+    setAtomsDerivatives(i,deriv[i]);
+  }
   setValue           (ncoord);
   setBoxDerivatives  (virial);
 
