@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2013-2021 The plumed team
+   Copyright (c) 2013-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -21,9 +21,8 @@
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "CoordinationBase.h"
 #include "tools/SwitchingFunction.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "core/PlumedMain.h"
-#include "core/Atoms.h"
 
 namespace PLMD {
 namespace colvar {
@@ -79,6 +78,7 @@ void DHEnergy::registerKeywords( Keywords& keys ) {
   keys.add("compulsory","I","1.0","Ionic strength (M)");
   keys.add("compulsory","TEMP","300.0","Simulation temperature (K)");
   keys.add("compulsory","EPSILON","80.0","Dielectric constant of solvent");
+  keys.setValueDescription("the value of the DHENERGY");
 }
 
 /*
@@ -108,16 +108,17 @@ DHEnergy::DHEnergy(const ActionOptions&ao):
   Action(ao),
   CoordinationBase(ao),
   k(0.0),
-  constant(0.0)
-{
+  constant(0.0) {
   double I,T;
   parse("I",I);
   parse("TEMP",T);
   parse("EPSILON",epsilon);
   checkRead();
-  if( plumed.getAtoms().usingNaturalUnits() ) error("DHENERGY cannot be used for calculations performed with natural units");
-  constant=138.935458111/atoms.getUnits().getEnergy()/atoms.getUnits().getLength()*atoms.getUnits().getCharge()*atoms.getUnits().getCharge();
-  k=sqrt(I/(epsilon*T))*502.903741125*atoms.getUnits().getLength();
+  if( usingNaturalUnits() ) {
+    error("DHENERGY cannot be used for calculations performed with natural units");
+  }
+  constant=138.935458111/getUnits().getEnergy()/getUnits().getLength()*getUnits().getCharge()*getUnits().getCharge();
+  k=std::sqrt(I/(epsilon*T))*502.903741125*getUnits().getLength();
   checkRead();
   log<<"  with solvent dielectric constant "<<epsilon<<"\n";
   log<<"  at temperature "<<T<<" K\n";
