@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,14 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Colvar.h"
-#include "ActionRegister.h"
-
-#include <string>
-#include <cmath>
-#include <cassert>
-#include <iostream>
-
-using namespace std;
+#include "core/ActionRegister.h"
 
 namespace PLMD {
 namespace colvar {
@@ -50,6 +43,9 @@ class ColvarFake : public Colvar {
 public:
   static void registerKeywords( Keywords& keys );
   explicit ColvarFake(const ActionOptions&);
+  std::string getOutputComponentDescription( const std::string& cname, const Keywords& keys ) const override {
+    plumed_error();
+  }
 // active methods:
   void calculate() override;
 };
@@ -66,12 +62,11 @@ void ColvarFake::registerKeywords( Keywords& keys ) {
 }
 
 ColvarFake::ColvarFake(const ActionOptions&ao):
-  PLUMED_COLVAR_INIT(ao)
-{
-  vector<AtomNumber> atoms;
+  PLUMED_COLVAR_INIT(ao) {
+  std::vector<AtomNumber> atoms;
   parseAtomList("ATOMS",atoms);
 
-  vector<string> comps;
+  std::vector<std::string> comps;
   // multiple components for this variable
   parseVector("COMPONENTS",comps);
   if(comps.size()!=0) {
@@ -89,7 +84,7 @@ ColvarFake::ColvarFake(const ActionOptions&ao):
     plumed_massert(static_cast<unsigned>(getNumberOfComponents()*2)==period.size(),"the periodicty should coincide with the number of components");
     if(comps.size()!=0) {
       for(int i=0; i<getNumberOfComponents(); i++) {
-        string pp=comps[i];
+        std::string pp=comps[i];
         if(period[i*2]!="none" && period[i*2+1]!="none" ) {
           componentIsPeriodic(pp,period[i*2],period[i*2+1]);
         } else {
