@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2020 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,18 +20,13 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Colvar.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "core/PlumedMain.h"
 
-#include <string>
-#include <cmath>
-
-using namespace std;
-
 namespace PLMD {
 namespace colvar {
 
-//+PLUMEDOC COLVAR GYRATION
+//+PLUMEDOC COLVAR GYRATION_FAST
 /*
 Calculate the radius of gyration, or other properties related to it.
 
@@ -88,68 +83,107 @@ private:
   int rg_type;
   bool use_masses;
   bool nopbc;
+  std::vector<Vector> derivatives;
 public:
   static void registerKeywords(Keywords& keys);
   explicit Gyration(const ActionOptions&);
   void calculate() override;
 };
 
-PLUMED_REGISTER_ACTION(Gyration,"GYRATION")
+PLUMED_REGISTER_ACTION(Gyration,"GYRATION_FAST")
 
 void Gyration::registerKeywords(Keywords& keys) {
   Colvar::registerKeywords(keys);
+  keys.setDisplayName("GYRATION");
   keys.add("atoms","ATOMS","the group of atoms that you are calculating the Gyration Tensor for");
   keys.add("compulsory","TYPE","RADIUS","The type of calculation relative to the Gyration Tensor you want to perform");
   keys.addFlag("MASS_WEIGHTED",false,"set the masses of all the atoms equal to one");
+  keys.setValueDescription("the radius of gyration");
 }
 
 Gyration::Gyration(const ActionOptions&ao):
   PLUMED_COLVAR_INIT(ao),
   use_masses(false),
-  nopbc(false)
-{
+  nopbc(false) {
   std::vector<AtomNumber> atoms;
   parseAtomList("ATOMS",atoms);
-  if(atoms.size()==0) error("no atoms specified");
+  if(atoms.size()==0) {
+    error("no atoms specified");
+  }
   parseFlag("MASS_WEIGHTED",use_masses);
   std::string Type;
   parse("TYPE",Type);
   parseFlag("NOPBC",nopbc);
   checkRead();
 
-  if(Type=="RADIUS") rg_type=RADIUS;
-  else if(Type=="TRACE") rg_type=TRACE;
-  else if(Type=="GTPC_1") rg_type=GTPC_1;
-  else if(Type=="GTPC_2") rg_type=GTPC_2;
-  else if(Type=="GTPC_3") rg_type=GTPC_3;
-  else if(Type=="ASPHERICITY") rg_type=ASPHERICITY;
-  else if(Type=="ACYLINDRICITY") rg_type=ACYLINDRICITY;
-  else if(Type=="KAPPA2") rg_type=KAPPA2;
-  else if(Type=="RGYR_3") rg_type=GYRATION_3;
-  else if(Type=="RGYR_2") rg_type=GYRATION_2;
-  else if(Type=="RGYR_1") rg_type=GYRATION_1;
-  else error("Unknown GYRATION type");
+  if(Type=="RADIUS") {
+    rg_type=RADIUS;
+  } else if(Type=="TRACE") {
+    rg_type=TRACE;
+  } else if(Type=="GTPC_1") {
+    rg_type=GTPC_1;
+  } else if(Type=="GTPC_2") {
+    rg_type=GTPC_2;
+  } else if(Type=="GTPC_3") {
+    rg_type=GTPC_3;
+  } else if(Type=="ASPHERICITY") {
+    rg_type=ASPHERICITY;
+  } else if(Type=="ACYLINDRICITY") {
+    rg_type=ACYLINDRICITY;
+  } else if(Type=="KAPPA2") {
+    rg_type=KAPPA2;
+  } else if(Type=="RGYR_3") {
+    rg_type=GYRATION_3;
+  } else if(Type=="RGYR_2") {
+    rg_type=GYRATION_2;
+  } else if(Type=="RGYR_1") {
+    rg_type=GYRATION_1;
+  } else {
+    error("Unknown GYRATION type");
+  }
 
-  switch(rg_type)
-  {
-  case RADIUS:   log.printf("  GYRATION RADIUS (Rg);"); break;
-  case TRACE:  log.printf("  TRACE OF THE GYRATION TENSOR;"); break;
-  case GTPC_1: log.printf("  THE LARGEST PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_1);"); break;
-  case GTPC_2: log.printf("  THE MIDDLE PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_2);");  break;
-  case GTPC_3: log.printf("  THE SMALLEST PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_3);"); break;
-  case ASPHERICITY: log.printf("  THE ASPHERICITY (b');"); break;
-  case ACYLINDRICITY: log.printf("  THE ACYLINDRICITY (c');"); break;
-  case KAPPA2: log.printf("  THE RELATIVE SHAPE ANISOTROPY (kappa^2);"); break;
-  case GYRATION_3: log.printf("  THE SMALLEST PRINCIPAL RADIUS OF GYRATION (r_g3);"); break;
-  case GYRATION_2: log.printf("  THE MIDDLE PRINCIPAL RADIUS OF GYRATION (r_g2);"); break;
-  case GYRATION_1: log.printf("  THE LARGEST PRINCIPAL RADIUS OF GYRATION (r_g1);"); break;
+  switch(rg_type) {
+  case RADIUS:
+    log.printf("  GYRATION RADIUS (Rg);");
+    break;
+  case TRACE:
+    log.printf("  TRACE OF THE GYRATION TENSOR;");
+    break;
+  case GTPC_1:
+    log.printf("  THE LARGEST PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_1);");
+    break;
+  case GTPC_2:
+    log.printf("  THE MIDDLE PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_2);");
+    break;
+  case GTPC_3:
+    log.printf("  THE SMALLEST PRINCIPAL MOMENT OF THE GYRATION TENSOR (S'_3);");
+    break;
+  case ASPHERICITY:
+    log.printf("  THE ASPHERICITY (b');");
+    break;
+  case ACYLINDRICITY:
+    log.printf("  THE ACYLINDRICITY (c');");
+    break;
+  case KAPPA2:
+    log.printf("  THE RELATIVE SHAPE ANISOTROPY (kappa^2);");
+    break;
+  case GYRATION_3:
+    log.printf("  THE SMALLEST PRINCIPAL RADIUS OF GYRATION (r_g3);");
+    break;
+  case GYRATION_2:
+    log.printf("  THE MIDDLE PRINCIPAL RADIUS OF GYRATION (r_g2);");
+    break;
+  case GYRATION_1:
+    log.printf("  THE LARGEST PRINCIPAL RADIUS OF GYRATION (r_g1);");
+    break;
+  }
+  if(rg_type>TRACE) {
+    log<<"  Bibliography "<<plumed.cite("Jirí Vymetal and Jirí Vondrasek, J. Phys. Chem. A 115, 11455 (2011)");
   }
-  if(rg_type>TRACE) log<<"  Bibliography "<<plumed.cite("Jirí Vymetal and Jirí Vondrasek, J. Phys. Chem. A 115, 11455 (2011)");
   log<<"\n";
 
   log.printf("  atoms involved : ");
   for(unsigned i=0; i<atoms.size(); ++i) {
-    if(i%25==0) log<<"\n";
     log.printf("%d ",atoms[i].serial());
   }
   log.printf("\n");
@@ -160,13 +194,16 @@ Gyration::Gyration(const ActionOptions&ao):
     log<<"  broken molecules will be rebuilt assuming atoms are in the proper order\n";
   }
 
-  addValueWithDerivatives(); setNotPeriodic();
+  addValueWithDerivatives();
+  setNotPeriodic();
   requestAtoms(atoms);
 }
 
 void Gyration::calculate() {
 
-  if(!nopbc) makeWhole();
+  if(!nopbc) {
+    makeWhole();
+  }
 
   Vector com;
   double totmass = 0.;
@@ -184,8 +221,7 @@ void Gyration::calculate() {
   com /= totmass;
 
   double rgyr=0.;
-  vector<Vector> derivatives( getNumberOfAtoms() );
-  Tensor virial;
+  derivatives.resize(getNumberOfAtoms());
 
   if(rg_type==RADIUS||rg_type==TRACE) {
     if( use_masses ) {
@@ -193,27 +229,27 @@ void Gyration::calculate() {
         const Vector diff = delta( com, getPosition(i) );
         rgyr          += getMass(i)*diff.modulo2();
         derivatives[i] = diff*getMass(i);
-        virial        -= Tensor(getPosition(i),derivatives[i]);
       }
     } else {
       for(unsigned i=0; i<getNumberOfAtoms(); i++) {
         const Vector diff = delta( com, getPosition(i) );
         rgyr          += diff.modulo2();
         derivatives[i] = diff;
-        virial        -= Tensor(getPosition(i),derivatives[i]);
       }
     }
     double fact;
     if(rg_type==RADIUS) {
-      rgyr = sqrt(rgyr/totmass);
+      rgyr = std::sqrt(rgyr/totmass);
       fact = 1./(rgyr*totmass);
     } else {
       rgyr = 2.*rgyr;
       fact = 4;
     }
     setValue(rgyr);
-    for(unsigned i=0; i<getNumberOfAtoms(); i++) setAtomsDerivatives(i,fact*derivatives[i]);
-    setBoxDerivatives(fact*virial);
+    for(unsigned i=0; i<getNumberOfAtoms(); i++) {
+      setAtomsDerivatives(i,fact*derivatives[i]);
+    }
+    setBoxDerivativesNoPbc();
     return;
   }
 
@@ -253,39 +289,61 @@ void Gyration::calculate() {
   transf=transpose(ttransf);
   //sort eigenvalues and eigenvectors
   if (princ_comp[0]<princ_comp[1]) {
-    double tmp=princ_comp[0]; princ_comp[0]=princ_comp[1]; princ_comp[1]=tmp;
-    for (unsigned i=0; i<3; i++) {tmp=transf[i][0]; transf[i][0]=transf[i][1]; transf[i][1]=tmp;}
+    double tmp=princ_comp[0];
+    princ_comp[0]=princ_comp[1];
+    princ_comp[1]=tmp;
+    for (unsigned i=0; i<3; i++) {
+      tmp=transf[i][0];
+      transf[i][0]=transf[i][1];
+      transf[i][1]=tmp;
+    }
   }
   if (princ_comp[1]<princ_comp[2]) {
-    double tmp=princ_comp[1]; princ_comp[1]=princ_comp[2]; princ_comp[2]=tmp;
-    for (unsigned i=0; i<3; i++) {tmp=transf[i][1]; transf[i][1]=transf[i][2]; transf[i][2]=tmp;}
+    double tmp=princ_comp[1];
+    princ_comp[1]=princ_comp[2];
+    princ_comp[2]=tmp;
+    for (unsigned i=0; i<3; i++) {
+      tmp=transf[i][1];
+      transf[i][1]=transf[i][2];
+      transf[i][2]=tmp;
+    }
   }
   if (princ_comp[0]<princ_comp[1]) {
-    double tmp=princ_comp[0]; princ_comp[0]=princ_comp[1]; princ_comp[1]=tmp;
-    for (unsigned i=0; i<3; i++) {tmp=transf[i][0]; transf[i][0]=transf[i][1]; transf[i][1]=tmp;}
+    double tmp=princ_comp[0];
+    princ_comp[0]=princ_comp[1];
+    princ_comp[1]=tmp;
+    for (unsigned i=0; i<3; i++) {
+      tmp=transf[i][0];
+      transf[i][0]=transf[i][1];
+      transf[i][1]=tmp;
+    }
   }
   //calculate determinant of transformation matrix
   double det = determinant(transf);
-  // trasformation matrix for rotation must have positive determinant, otherwise multiply one column by (-1)
+  // transformation matrix for rotation must have positive determinant, otherwise multiply one column by (-1)
   if(det<0) {
-    for(unsigned j=0; j<3; j++) transf[j][2]=-transf[j][2];
+    for(unsigned j=0; j<3; j++) {
+      transf[j][2]=-transf[j][2];
+    }
     det = -det;
   }
-  if(fabs(det-1.)>0.0001) error("Plumed Error: Cannot diagonalize gyration tensor\n");
+  if(std::abs(det-1.)>0.0001) {
+    error("Plumed Error: Cannot diagonalize gyration tensor\n");
+  }
   switch(rg_type) {
   case GTPC_1:
   case GTPC_2:
-  case GTPC_3:
-  {
+  case GTPC_3: {
     int pc_index = rg_type-2; //index of principal component
-    rgyr=sqrt(princ_comp[pc_index]/totmass);
+    rgyr=std::sqrt(princ_comp[pc_index]/totmass);
     double rm = rgyr*totmass;
-    if(rm>1e-6) prefactor[pc_index]=1.0/rm; //some parts of derivate
+    if(rm>1e-6) {
+      prefactor[pc_index]=1.0/rm;  //some parts of derivate
+    }
     break;
   }
-  case GYRATION_3:        //the smallest principal radius of gyration
-  {
-    rgyr=sqrt((princ_comp[1]+princ_comp[2])/totmass);
+  case GYRATION_3: {      //the smallest principal radius of gyration
+    rgyr=std::sqrt((princ_comp[1]+princ_comp[2])/totmass);
     double rm = rgyr*totmass;
     if (rm>1e-6) {
       prefactor[1]=1.0/rm;
@@ -293,9 +351,8 @@ void Gyration::calculate() {
     }
     break;
   }
-  case GYRATION_2:       //the midle principal radius of gyration
-  {
-    rgyr=sqrt((princ_comp[0]+princ_comp[2])/totmass);
+  case GYRATION_2: {     //the midle principal radius of gyration
+    rgyr=std::sqrt((princ_comp[0]+princ_comp[2])/totmass);
     double rm = rgyr*totmass;
     if (rm>1e-6) {
       prefactor[0]=1.0/rm;
@@ -303,9 +360,8 @@ void Gyration::calculate() {
     }
     break;
   }
-  case GYRATION_1:      //the largest principal radius of gyration
-  {
-    rgyr=sqrt((princ_comp[0]+princ_comp[1])/totmass);
+  case GYRATION_1: {    //the largest principal radius of gyration
+    rgyr=std::sqrt((princ_comp[0]+princ_comp[1])/totmass);
     double rm = rgyr*totmass;
     if (rm>1e-6) {
       prefactor[0]=1.0/rm;
@@ -313,9 +369,8 @@ void Gyration::calculate() {
     }
     break;
   }
-  case ASPHERICITY:
-  {
-    rgyr=sqrt((princ_comp[0]-0.5*(princ_comp[1]+princ_comp[2]))/totmass);
+  case ASPHERICITY: {
+    rgyr=std::sqrt((princ_comp[0]-0.5*(princ_comp[1]+princ_comp[2]))/totmass);
     double rm = rgyr*totmass;
     if (rm>1e-6) {
       prefactor[0]= 1.0/rm;
@@ -324,9 +379,8 @@ void Gyration::calculate() {
     }
     break;
   }
-  case ACYLINDRICITY:
-  {
-    rgyr=sqrt((princ_comp[1]-princ_comp[2])/totmass);
+  case ACYLINDRICITY: {
+    rgyr=std::sqrt((princ_comp[1]-princ_comp[2])/totmass);
     double rm = rgyr*totmass;
     if (rm>1e-6) {  //avoid division by zero
       prefactor[1]= 1.0/rm;
@@ -334,8 +388,7 @@ void Gyration::calculate() {
     }
     break;
   }
-  case KAPPA2: // relative shape anisotropy
-  {
+  case KAPPA2: { // relative shape anisotropy
     double trace = princ_comp[0]+princ_comp[1]+princ_comp[2];
     double tmp=princ_comp[0]*princ_comp[1]+ princ_comp[1]*princ_comp[2]+ princ_comp[0]*princ_comp[2];
     rgyr=1.0-3*(tmp/(trace*trace));
@@ -353,10 +406,13 @@ void Gyration::calculate() {
       Vector tX;
       const Vector diff=delta( com,getPosition(i) );
       //project atomic postional vectors to diagonalized frame
-      for(unsigned j=0; j<3; j++) tX[j]=transf[0][j]*diff[0]+transf[1][j]*diff[1]+transf[2][j]*diff[2];
-      for(unsigned j=0; j<3; j++) derivatives[i][j]=getMass(i)*(prefactor[0]*transf[j][0]*tX[0]+
-            prefactor[1]*transf[j][1]*tX[1]+
-            prefactor[2]*transf[j][2]*tX[2]);
+      for(unsigned j=0; j<3; j++) {
+        tX[j]=transf[0][j]*diff[0]+transf[1][j]*diff[1]+transf[2][j]*diff[2];
+      }
+      for(unsigned j=0; j<3; j++)
+        derivatives[i][j]=getMass(i)*(prefactor[0]*transf[j][0]*tX[0]+
+                                      prefactor[1]*transf[j][1]*tX[1]+
+                                      prefactor[2]*transf[j][2]*tX[2]);
       setAtomsDerivatives(i,derivatives[i]);
     }
   } else {
@@ -364,10 +420,13 @@ void Gyration::calculate() {
       Vector tX;
       const Vector diff=delta( com,getPosition(i) );
       //project atomic postional vectors to diagonalized frame
-      for(unsigned j=0; j<3; j++) tX[j]=transf[0][j]*diff[0]+transf[1][j]*diff[1]+transf[2][j]*diff[2];
-      for(unsigned j=0; j<3; j++) derivatives[i][j]=prefactor[0]*transf[j][0]*tX[0]+
-            prefactor[1]*transf[j][1]*tX[1]+
-            prefactor[2]*transf[j][2]*tX[2];
+      for(unsigned j=0; j<3; j++) {
+        tX[j]=transf[0][j]*diff[0]+transf[1][j]*diff[1]+transf[2][j]*diff[2];
+      }
+      for(unsigned j=0; j<3; j++)
+        derivatives[i][j]=prefactor[0]*transf[j][0]*tX[0]+
+                          prefactor[1]*transf[j][1]*tX[1]+
+                          prefactor[2]*transf[j][2]*tX[2];
       setAtomsDerivatives(i,derivatives[i]);
     }
   }
