@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -22,8 +22,6 @@
 #include "PathMSDBase.h"
 #include "core/PlumedMain.h"
 
-using namespace std;
-
 namespace PLMD {
 namespace colvar {
 
@@ -101,28 +99,30 @@ PLUMED_REGISTER_ACTION(PathMSD,"PATHMSD")
 
 void PathMSD::registerKeywords(Keywords& keys) {
   PathMSDBase::registerKeywords(keys);
-  componentsAreNotOptional(keys);
   keys.addOutputComponent("sss","default","the position on the path");
   keys.addOutputComponent("zzz","default","the distance from the path");
 }
 
 PathMSD::PathMSD(const ActionOptions&ao):
-  Action(ao),PathMSDBase(ao)
-{
+  Action(ao),PathMSDBase(ao) {
   checkRead();
 
   log<<"  Bibliography "
      <<plumed.cite("Branduardi, Gervasio, Parrinello J. Chem. Phys. 126, 054103 (2007)")
      <<"\n";
   // no need to read anything
-  addComponentWithDerivatives("sss"); componentIsNotPeriodic("sss");
-  addComponentWithDerivatives("zzz"); componentIsNotPeriodic("zzz");
+  addComponentWithDerivatives("sss");
+  componentIsNotPeriodic("sss");
+  addComponentWithDerivatives("zzz");
+  componentIsNotPeriodic("zzz");
   requestAtoms(pdbv[0].getAtomNumbers());
 
   double i=1.;
   for(unsigned it=0 ; it<nframes ; ++it) {
-    vector<double> v; v.push_back(i);
-    indexvec.push_back(v); i+=1.;
+    std::vector<double> v;
+    v.push_back(i);
+    indexvec.push_back(v);
+    i+=1.;
   }
 }
 
