@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -99,7 +99,10 @@ bool hasDlopen();
 
 bool isInstalled();
 
-bool hasCregex();
+/// This will always return true for backward compatibility
+constexpr bool hasCregex() {
+  return true;
+}
 
 bool hasMolfile();
 
@@ -107,7 +110,8 @@ bool hasExternalMolfile();
 
 bool hasZlib();
 
-bool hasXdrfile();
+std::string getLibraryPath();
+
 }
 }
 
