@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -26,6 +26,7 @@
 #include <set>
 #include "tools/Keywords.h"
 #include "tools/Tools.h"
+#include "tools/Units.h"
 #include "tools/Log.h"
 
 namespace PLMD {
@@ -34,6 +35,15 @@ class PDB;
 class PlumedMain;
 class Communicator;
 class ActionWithValue;
+class ActionWithArguments;
+class ActionAtomistic;
+class ActionWithVirtualAtom;
+class PbcAction;
+class ActionToGetData;
+class ActionToPutData;
+class DomainDecomposition;
+class ActionForInterface;
+class ActionShortcut;
 
 /// This class is used to bring the relevant information to the Action constructor.
 /// Only Action and ActionRegister class can access to its content, which is
@@ -48,10 +58,14 @@ class ActionOptions {
 /// The documentation for this action
   const Keywords& keys;
   static Keywords emptyKeys;
+  std::string fullPath;
 public:
 /// Constructor
   ActionOptions(PlumedMain&p,const std::vector<std::string>&);
   ActionOptions(const ActionOptions&,const Keywords& keys);
+  void setFullPath(const std::string & fullPath) {
+    this->fullPath=fullPath;
+  }
 };
 
 /// Base class for all the input Actions.
@@ -77,6 +91,16 @@ class Action {
 /// Update only until this time.
   double update_until;
 
+/// Save the timestep here
+  double timestep;
+
+protected:
+/// Get the units that we are operating in
+  const Units& getUnits() const;
+/// Are we using natural units
+  bool usingNaturalUnits()const;
+/// Get the value of Boltzmann's constant
+  double getKBoltzmann()const;
 public:
 
 /// Check if action should be updated.
@@ -99,6 +123,10 @@ private:
 
   bool doCheckPoint;
 
+  bool never_activate;
+
+/// The set of default arguments that we are using
+  std::string defaults;
 public:
 
 /// Reference to main plumed object
@@ -110,11 +138,19 @@ public:
 /// Specify that this Action depends on another one
   void addDependency(Action*);
 
+/// Check that this action does not depend on the action in the argument
+  bool checkForDependency(Action*);
+
 /// Clear the dependence list for this Action
   void clearDependencies();
 
+/// Get the value of kBT by either reading the TEMP keyword
+/// and multiplying the temperature by Boltzmann's constant
+/// or get it fro the MD code
+  double getkBT();
+
 /// Return the present timestep
-  long int getStep()const;
+  long long int getStep()const;
 
 /// Return the present time
   double getTime()const;
@@ -151,7 +187,7 @@ public:
   void parseFlag(const std::string&key,bool&t);
 
 /// Crash calculation and print documentation
-  void error( const std::string & msg ) const;
+  [[noreturn]] void error( const std::string & msg ) const;
 
 /// Issue a warning
   void warning( const std::string & msg );
@@ -179,6 +215,10 @@ public:
 /// a final Action has been initialized
   void checkRead();
 
+/// This calculates any values that are constant and ensures
+/// that we don't calculate these actions on every timestep
+  void setupConstantValues( const bool& have_atoms );
+
   Communicator& comm;
   Communicator& multi_sim_comm;
 
@@ -228,8 +268,6 @@ public:
 /// Tell to the Action to flush open files
   void fflush();
 
-  virtual std::string getDocumentation()const;
-
 /// Returns the label
   const std::string & getLabel()const;
 
@@ -254,13 +292,19 @@ public:
   bool isOptionOn(const std::string &s)const;
 
 /// Return dependencies
-  const Dependencies & getDependencies()const {return after;}
+  const Dependencies & getDependencies()const {
+    return after;
+  }
 
 /// Check if numerical derivatives should be performed
-  virtual bool checkNumericalDerivatives()const {return false;}
+  virtual bool checkNumericalDerivatives()const {
+    return false;
+  }
 
 /// Check if the action needs gradient
-  virtual bool checkNeedsGradients()const {return false;}
+  virtual bool checkNeedsGradients()const {
+    return false;
+  }
 
 /// Perform calculation using numerical derivatives
 /// N.B. only pass an ActionWithValue to this routine if you know exactly what you
@@ -287,6 +331,46 @@ public:
 
 /// Cite a paper see PlumedMain::cite
   std::string cite(const std::string&s);
+
+/// Get the defaults
+  std::string getDefaultString() const ;
+
+/// Set the timestep that is stored in the action to the correct value
+  void resetStoredTimestep();
+
+/// Get the info on what to calculate
+  virtual std::string writeInGraph() const ;
+/// Specialized casts, to make PlumedMain run faster
+  virtual ActionWithValue* castToActionWithValue() noexcept {
+    return nullptr;
+  }
+  virtual ActionWithArguments* castToActionWithArguments() noexcept {
+    return nullptr;
+  }
+  virtual ActionAtomistic* castToActionAtomistic() noexcept {
+    return nullptr;
+  }
+  virtual ActionWithVirtualAtom* castToActionWithVirtualAtom() noexcept {
+    return nullptr;
+  }
+  virtual PbcAction* castToPbcAction() noexcept {
+    return nullptr;
+  }
+  virtual ActionToPutData* castToActionToPutData() noexcept {
+    return nullptr;
+  }
+  virtual ActionToGetData* castToActionToGetData() noexcept {
+    return nullptr;
+  }
+  virtual DomainDecomposition* castToDomainDecomposition() noexcept {
+    return nullptr;
+  }
+  virtual ActionForInterface* castToActionForInterface() noexcept {
+    return nullptr;
+  }
+  virtual ActionShortcut* castToActionShortcut() noexcept {
+    return nullptr;
+  }
 };
 
 /////////////////////
@@ -304,11 +388,6 @@ const std::string & Action::getName()const {
 
 template<class T>
 void Action::parse(const std::string&key,T&t) {
-//  if(!Tools::parse(line,key,t)){
-//    log.printf("ERROR parsing keyword %s\n",key.c_str());
-//    log.printf("%s\n",getDocumentation().c_str());
-//    this->exit(1);
-//  }
   // Check keyword has been registered
   plumed_massert(keywords.exists(key),"keyword " + key + " has not been registered");
 
@@ -316,15 +395,17 @@ void Action::parse(const std::string&key,T&t) {
   std::string def;
   bool present=Tools::findKeyword(line,key);
   bool found=Tools::parse(line,key,t,replica_index);
-  if(present && !found) error("keyword " + key +" could not be read correctly");
+  if(present && !found) {
+    error("keyword " + key +" could not be read correctly");
+  }
 
   // If it isn't read and it is compulsory see if a default value was specified
   if ( !found && (keywords.style(key,"compulsory") || keywords.style(key,"hidden")) ) {
     if( keywords.getDefaultValue(key,def) ) {
-      if( def.length()==0 || !Tools::convert(def,t) ) {
-        log.printf("ERROR in action %s with label %s : keyword %s has weird default value",name.c_str(),label.c_str(),key.c_str() );
-        this->exit(1);
+      if( def.length()==0 || !Tools::convertNoexcept(def,t) ) {
+        plumed_error() <<"ERROR in action "<<name<<" with label "<<label<<" : keyword "<<key<<" has weird default value";
       }
+      defaults += " " + key + "=" + def;
     } else if( keywords.style(key,"compulsory") ) {
       error("keyword " + key + " is compulsory for this action");
     }
@@ -335,48 +416,62 @@ template<class T>
 bool Action::parseNumbered(const std::string&key, const int no, T&t) {
   // Check keyword has been registered
   plumed_massert(keywords.exists(key),"keyword " + key + " has not been registered");
-  if( !keywords.numbered(key) ) error("numbered keywords are not allowed for " + key );
+  if( !keywords.numbered(key) ) {
+    error("numbered keywords are not allowed for " + key );
+  }
 
   // Now try to read the keyword
-  std::string num; Tools::convert(no,num);
+  std::string num;
+  Tools::convert(no,num);
   return Tools::parse(line,key+num,t,replica_index);
 }
 
 template<class T>
 void Action::parseVector(const std::string&key,std::vector<T>&t) {
-//  if(!Tools::parseVector(line,key,t)){
-//    log.printf("ERROR parsing keyword %s\n",key.c_str());
-//    log.printf("%s\n",getDocumentation().c_str());
-//    this->exit(1);
-//  }
-
   // Check keyword has been registered
   plumed_massert(keywords.exists(key), "keyword " + key + " has not been registered");
-  unsigned size=t.size(); bool skipcheck=false;
-  if(size==0) skipcheck=true;
+  unsigned size=t.size();
+  bool skipcheck=false;
+  if(size==0) {
+    skipcheck=true;
+  }
 
   // Now try to read the keyword
-  std::string def; T val;
+  std::string def;
+  T val;
   bool present=Tools::findKeyword(line,key);
   bool found=Tools::parseVector(line,key,t,replica_index);
-  if(present && !found) error("keyword " + key +" could not be read correctly");
+  if(present && !found) {
+    error("keyword " + key +" could not be read correctly");
+  }
 
   // Check vectors size is correct (not if this is atoms or ARG)
   if( !keywords.style(key,"atoms") && found ) {
 //     bool skipcheck=false;
 //     if( keywords.style(key,"compulsory") ){ keywords.getDefaultValue(key,def); skipcheck=(def=="nosize"); }
-    if( !skipcheck && t.size()!=size ) error("vector read in for keyword " + key + " has the wrong size");
+    if( !skipcheck && t.size()!=size ) {
+      error("vector read in for keyword " + key + " has the wrong size");
+    }
   }
 
   // If it isn't read and it is compulsory see if a default value was specified
   if ( !found && (keywords.style(key,"compulsory") || keywords.style(key,"hidden")) ) {
     if( keywords.getDefaultValue(key,def) ) {
-      if( def.length()==0 || !Tools::convert(def,val) ) {
-        log.printf("ERROR in action %s with label %s : keyword %s has weird default value",name.c_str(),label.c_str(),key.c_str() );
-        this->exit(1);
+      if( def.length()==0 || !Tools::convertNoexcept(def,val) ) {
+        plumed_error() <<"ERROR in action "<<name<<" with label "<<label<<" : keyword "<<key<<" has weird default value";
       } else {
-        if(t.size()>0) for(unsigned i=0; i<t.size(); ++i) t[i]=val;
-        else t.push_back(val);
+        if(t.size()>0) {
+          for(unsigned i=0; i<t.size(); ++i) {
+            t[i]=val;
+          }
+          defaults += " " + key + "=" + def;
+          for(unsigned i=1; i<t.size(); ++i) {
+            defaults += "," + def;
+          }
+        } else {
+          t.push_back(val);
+          defaults += " " + key + "=" + def;
+        }
       }
     } else if( keywords.style(key,"compulsory") ) {
       error("keyword " + key + " is compulsory for this action");
@@ -389,17 +484,27 @@ void Action::parseVector(const std::string&key,std::vector<T>&t) {
 template<class T>
 bool Action::parseNumberedVector(const std::string&key, const int no, std::vector<T>&t) {
   plumed_massert(keywords.exists(key),"keyword " + key + " has not been registered");
-  if( !keywords.numbered(key) ) error("numbered keywords are not allowed for " + key );
+  if( !keywords.numbered(key) ) {
+    error("numbered keywords are not allowed for " + key );
+  }
 
-  unsigned size=t.size(); bool skipcheck=false;
-  if(size==0) skipcheck=true;
-  std::string num; Tools::convert(no,num);
+  unsigned size=t.size();
+  bool skipcheck=false;
+  if(size==0) {
+    skipcheck=true;
+  }
+  std::string num;
+  Tools::convert(no,num);
   bool present=Tools::findKeyword(line,key);
   bool found=Tools::parseVector(line,key+num,t,replica_index);
-  if(present && !found) error("keyword " + key +" could not be read correctly");
+  if(present && !found) {
+    error("keyword " + key +" could not be read correctly");
+  }
 
   if(  keywords.style(key,"compulsory") ) {
-    if (!skipcheck && found && t.size()!=size ) error("vector read in for keyword " + key + num + " has the wrong size");
+    if (!skipcheck && found && t.size()!=size ) {
+      error("vector read in for keyword " + key + num + " has the wrong size");
+    }
   } else if ( !found ) {
     t.resize(0);
   }
@@ -427,6 +532,11 @@ bool Action::getRestart()const {
   return restart;
 }
 
+inline
+std::string Action::getDefaultString() const {
+  return defaults;
+}
+
 }
 #endif
 
