@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -28,15 +28,32 @@ ActionSet::ActionSet(PlumedMain&p):
   (void) plumed; // to suppress warning about "unused plumed"
 }
 
-ActionSet::~ActionSet()
-{
+ActionSet::~ActionSet() {
 // required in order to deallocate in reverse order:
-  for(int i=size()-1; i>=0; i--) (*this)[i].reset();
+  for(int i=size()-1; i>=0; i--) {
+    (*this)[i].reset();
+  }
 }
 
 void ActionSet::clearDelete() {
-  for(int i=size()-1; i>=0; i--) (*this)[i].reset();
+  for(int i=size()-1; i>=0; i--) {
+    (*this)[i].reset();
+  }
   clear();
 }
 
+ActionShortcut* ActionSet::getShortcutActionWithLabel( const std::string& s ) const {
+  ActionShortcut* scf = NULL;
+  for(const auto & p : (*this)) {
+    ActionShortcut* sc=dynamic_cast<ActionShortcut*>(p.get());
+    if( sc && sc->shortcutlabel==s ) {
+      scf = sc;
+    }
+  }
+  if( scf ) {
+    return scf;
+  }
+  return NULL;
+}
+
 }
