@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -39,14 +39,15 @@ This is used in PLMD::Function and PLMD::Bias
  when you use parseArgumentList.
 */
 
+class ActionSet;
+
 class ActionWithArguments:
-  public virtual Action
-{
+  public virtual Action {
   std::vector<Value*> arguments;
   bool lockRequestArguments;
 protected:
 /// This changes the arg keyword in the pdb file
-  void expandArgKeywordInPDB( PDB& pdb );
+  void expandArgKeywordInPDB( const PDB& pdb );
 public:
 /// Get the scalar product between the gradients of two variables
   double getProjection(unsigned i,unsigned j)const;
@@ -55,7 +56,7 @@ public:
 /// Returns the value of an argument
   double getArgument( const unsigned n ) const;
 /// Return a pointer to specific argument
-  Value* getPntrToArgument( const unsigned n );
+  Value* getPntrToArgument( const unsigned n ) const;
 /// Returns the number of arguments
   virtual unsigned getNumberOfArguments() const ;
 /// Takes the difference taking into account pbc for arg i
@@ -68,8 +69,9 @@ public:
   bool parseArgumentList(const std::string&key,int i,std::vector<Value*>&args);
 /// Setup the dependencies
   void requestArguments(const std::vector<Value*> &arg);
+  void requestExtraDependencies(const std::vector<Value*> &extra);
 /// Add forces to arguments (used in apply)
-  void addForcesOnArguments( const std::vector<double>& forces );
+  void addForcesOnArguments( const unsigned& argstart, const std::vector<double>& forces, unsigned& ind, const std::string& c );
 public:
   explicit ActionWithArguments(const ActionOptions&);
   virtual ~ActionWithArguments() {}
@@ -82,12 +84,19 @@ public:
 /// Returns an array of pointers to the arguments
   virtual const std::vector<Value*>    & getArguments() const ;
 /// Convert a list of argument names into a list of pointers to the values
-  void interpretArgumentList(const std::vector<std::string>& c, std::vector<Value*>&arg);
+  static void interpretArgumentList(const std::vector<std::string>& c, const ActionSet& as, Action* action, std::vector<Value*>&arg);
+/// Used to calculate constant values in startup
+  virtual bool calculateConstantValues( const bool& have_atoms );
+/// Get the gradient for this action
+  void setGradients( Value* myval, unsigned& start ) const ;
+  ActionWithArguments* castToActionWithArguments() noexcept final {
+    return this;
+  }
 };
 
 
 inline
-Value* ActionWithArguments::getPntrToArgument( const unsigned n ) {
+Value* ActionWithArguments::getPntrToArgument( const unsigned n ) const {
   return arguments[n];
 }
 
