@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -30,19 +30,16 @@
 namespace PLMD {
 
 class PlumedMain;
-class Atoms;
 class Communicator;
 
 class GREX:
-  public WithCmd
-{
+  public WithCmd {
   bool initialized;
   ForwardDecl<Communicator> intracomm_fwd;
   Communicator& intracomm=*intracomm_fwd;
   ForwardDecl<Communicator> intercomm_fwd;
   Communicator& intercomm=*intercomm_fwd;
   PlumedMain& plumedMain;
-  Atoms&      atoms;
   int partner;
   double localDeltaBias;
   double foreignDeltaBias;
@@ -54,7 +51,7 @@ class GREX:
 public:
   explicit GREX(PlumedMain&);
   ~GREX();
-  void cmd(const std::string&key,void*val=NULL) override;
+  void cmd(std::string_view key,const TypesafePtr & val) override;
   void calculate();
   void savePositions();
 };
