@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -19,12 +19,14 @@
    You should have received a copy of the GNU Lesser General Public License
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
-#include "ActionRegister.h"
-#include "Function.h"
-
-#include "lepton/Lepton.h"
-
-using namespace std;
+#include "Custom.h"
+#include "core/ActionRegister.h"
+#include "FunctionShortcut.h"
+#include "FunctionOfScalar.h"
+#include "FunctionOfVector.h"
+#include "FunctionOfMatrix.h"
+#include "tools/OpenMP.h"
+#include "tools/LeptonCall.h"
 
 namespace PLMD {
 namespace function {
@@ -161,29 +163,86 @@ progression (S) and distance (Z) variables \cite perez2015atp.
 */
 //+ENDPLUMEDOC
 
+//+PLUMEDOC FUNCTION MATHEVAL_SCALAR
+/*
+Calculate a function of a set of input scalars
 
-class Custom :
-  public Function
-{
-  lepton::CompiledExpression expression;
-  std::vector<lepton::CompiledExpression> expression_deriv;
-  vector<string> var;
-  string func;
-  vector<double> values;
-  vector<char*> names;
-  vector<double*> lepton_ref;
-  vector<double*> lepton_ref_deriv;
-public:
-  explicit Custom(const ActionOptions&);
-  void calculate() override;
-  static void registerKeywords(Keywords& keys);
-};
+See \ref MATHEVAL
 
-PLUMED_REGISTER_ACTION(Custom,"CUSTOM")
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+//+PLUMEDOC FUNCTION CUSTOM_SCALAR
+/*
+Calculate a function of a set of input scalars
+
+See \ref CUSTOM
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+//+PLUMEDOC FUNCTION MATHEVAL_VECTOR
+/*
+Calculate a function of a set of input vectors elementwise
+
+See \ref MATHEVAL
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+//+PLUMEDOC FUNCTION CUSTOM_VECTOR
+/*
+Calculate a function of a set of input vectors elementwise
+
+See \ref CUSTOM
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+//+PLUMEDOC COLVAR CUSTOM_MATRIX
+/*
+Calculate an arbitrary function piecewise for one or multiple input matrices.
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+//+PLUMEDOC COLVAR MATHEVAL_MATRIX
+/*
+Calculate an arbitrary function piecewise for one or multiple input matrices.
+
+\par Examples
+
+*/
+//+ENDPLUMEDOC
+
+typedef FunctionShortcut<Custom> CustomShortcut;
+PLUMED_REGISTER_ACTION(CustomShortcut,"CUSTOM")
+PLUMED_REGISTER_ACTION(CustomShortcut,"MATHEVAL")
+typedef FunctionOfScalar<Custom> ScalarCustom;
+PLUMED_REGISTER_ACTION(ScalarCustom,"CUSTOM_SCALAR")
+PLUMED_REGISTER_ACTION(ScalarCustom,"MATHEVAL_SCALAR")
+typedef FunctionOfVector<Custom> VectorCustom;
+PLUMED_REGISTER_ACTION(VectorCustom,"CUSTOM_VECTOR")
+PLUMED_REGISTER_ACTION(VectorCustom,"MATHEVAL_VECTOR")
+typedef FunctionOfMatrix<Custom> MatrixCustom;
+PLUMED_REGISTER_ACTION(MatrixCustom,"CUSTOM_MATRIX")
+PLUMED_REGISTER_ACTION(MatrixCustom,"MATHEVAL_MATRIX")
 
 //+PLUMEDOC FUNCTION MATHEVAL
 /*
-An alias to the \ref CUSTOM function.
+An alias to the CUSTOM function that can also be used to calaculate combinations of variables using a custom expression.
+
+Documentation for this action is identical to that for \ref CUSTOM
 
 This alias is kept in order to maintain compatibility with previous PLUMED versions.
 However, notice that as of PLUMED 2.5 the libmatheval library is not linked anymore,
@@ -205,93 +264,151 @@ RESTRAINT ARG=d AT=0.5 KAPPA=10.0
 */
 //+ENDPLUMEDOC
 
-class Matheval :
-  public Custom {
-};
-
-PLUMED_REGISTER_ACTION(Custom,"MATHEVAL")
-
 void Custom::registerKeywords(Keywords& keys) {
-  Function::registerKeywords(keys);
-  keys.use("ARG"); keys.use("PERIODIC");
+  keys.use("PERIODIC");
   keys.add("compulsory","FUNC","the function you wish to evaluate");
   keys.add("optional","VAR","the names to give each of the arguments in the function.  If you have up to three arguments in your function you can use x, y and z to refer to them.  Otherwise you must use this flag to give your variables names.");
+  keys.setValueDescription("an arbitrary function");
 }
 
-Custom::Custom(const ActionOptions&ao):
-  Action(ao),
-  Function(ao),
-  expression_deriv(getNumberOfArguments()),
-  values(getNumberOfArguments()),
-  names(getNumberOfArguments()),
-  lepton_ref(getNumberOfArguments(),nullptr),
-  lepton_ref_deriv(getNumberOfArguments()*getNumberOfArguments(),nullptr)
-{
-  parseVector("VAR",var);
+void Custom::read( ActionWithArguments* action ) {
+  // Read in the variables
+  std::vector<std::string> var;
+  parseVector(action,"VAR",var);
+  parse(action,"FUNC",func);
   if(var.size()==0) {
-    var.resize(getNumberOfArguments());
-    if(getNumberOfArguments()>3)
-      error("Using more than 3 arguments you should explicitly write their names with VAR");
-    if(var.size()>0) var[0]="x";
-    if(var.size()>1) var[1]="y";
-    if(var.size()>2) var[2]="z";
-  }
-  if(var.size()!=getNumberOfArguments())
-    error("Size of VAR array should be the same as number of arguments");
-  parse("FUNC",func);
-  addValueWithDerivatives();
-  checkRead();
-
-  log.printf("  with function : %s\n",func.c_str());
-  log.printf("  with variables :");
-  for(unsigned i=0; i<var.size(); i++) log.printf(" %s",var[i].c_str());
-  log.printf("\n");
-
-  lepton::ParsedExpression pe=lepton::Parser::parse(func).optimize(lepton::Constants());
-  log<<"  function as parsed by lepton: "<<pe<<"\n";
-  expression=pe.createCompiledExpression();
-  for(auto &p: expression.getVariables()) {
-    if(std::find(var.begin(),var.end(),p)==var.end()) {
-      error("variable " + p + " is not defined");
+    var.resize(action->getNumberOfArguments());
+    if(var.size()>3) {
+      action->error("Using more than 3 arguments you should explicitly write their names with VAR");
+    }
+    if(var.size()>0) {
+      var[0]="x";
+    }
+    if(var.size()>1) {
+      var[1]="y";
+    }
+    if(var.size()>2) {
+      var[2]="z";
     }
   }
-  log<<"  derivatives as computed by lepton:\n";
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {
-    lepton::ParsedExpression pe=lepton::Parser::parse(func).differentiate(var[i]).optimize(lepton::Constants());
-    log<<"    "<<pe<<"\n";
-    expression_deriv[i]=pe.createCompiledExpression();
+  if(var.size()!=action->getNumberOfArguments()) {
+    action->error("Size of VAR array should be the same as number of arguments");
   }
-
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {
-    try {
-      lepton_ref[i]=&expression.getVariableReference(var[i]);
-    } catch(const PLMD::lepton::Exception& exc) {
-// this is necessary since in some cases lepton things a variable is not present even though it is present
-// e.g. func=0*x
+  // Check for operations that are not multiplication (this can probably be done much more cleverly)
+  bool onlymultiplication = func.find("*")!=std::string::npos;
+  // Find first bracket in expression
+  if( func.find("(")!=std::string::npos ) {
+    std::size_t br = func.find_first_of("(");
+    std::string subexpr=func.substr(0,br);
+    onlymultiplication = func.find("*")!=std::string::npos;
+    if( subexpr.find("/")!=std::string::npos ) {
+      std::size_t sl = func.find_first_of("/");
+      std::string aa = subexpr.substr(0,sl);
+      subexpr=aa;
     }
-  }
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {
-    for(unsigned j=0; j<getNumberOfArguments(); j++) {
-      try {
-        lepton_ref_deriv[i*getNumberOfArguments()+j]=&expression_deriv[i].getVariableReference(var[j]);
-      } catch(const PLMD::lepton::Exception& exc) {
-// this is necessary since in some cases lepton things a variable is not present even though it is present
-// e.g. func=0*x
+    if( subexpr.find("+")!=std::string::npos || subexpr.find("-")!=std::string::npos ) {
+      onlymultiplication=false;
+    }
+    // Now work out which vars are in multiplication
+    if( onlymultiplication ) {
+      for(unsigned i=0; i<var.size(); ++i) {
+        if( subexpr.find(var[i])!=std::string::npos &&
+            action->getPntrToArgument(i)->isDerivativeZeroWhenValueIsZero() ) {
+          check_multiplication_vars.push_back(i);
+        }
+      }
+    }
+  } else if( func.find("/")!=std::string::npos ) {
+    onlymultiplication=true;
+    if( func.find("+")!=std::string::npos || func.find("-")!=std::string::npos ) {
+      onlymultiplication=false;
+    }
+    if( onlymultiplication ) {
+      std::size_t br = func.find_first_of("/");
+      std::string subexpr=func.substr(0,br);
+      for(unsigned i=0; i<var.size(); ++i) {
+        if( subexpr.find(var[i])!=std::string::npos &&
+            action->getPntrToArgument(i)->isDerivativeZeroWhenValueIsZero() ) {
+          check_multiplication_vars.push_back(i);
+        }
+      }
+    }
+  } else if( func.find("+")!=std::string::npos || func.find("-")!=std::string::npos ) {
+    onlymultiplication=false;
+  } else {
+    for(unsigned i=0; i<var.size(); ++i) {
+      if( action->getPntrToArgument(i)->isDerivativeZeroWhenValueIsZero() ) {
+        check_multiplication_vars.push_back(i);
       }
     }
   }
+  if( check_multiplication_vars.size()>0 ) {
+    action->log.printf("  optimizing implementation as function only involves multiplication \n");
+  }
+
+  action->log.printf("  with function : %s\n",func.c_str());
+  action->log.printf("  with variables :");
+  for(unsigned i=0; i<var.size(); i++) {
+    action->log.printf(" %s",var[i].c_str());
+  }
+  action->log.printf("\n");
+  function.set( func, var, action );
+  std::vector<double> zeros( action->getNumberOfArguments(), 0 );
+  double fval = abs(function.evaluate(zeros));
+  zerowhenallzero=(fval<epsilon );
+  if( zerowhenallzero ) {
+    action->log.printf("  not calculating when all arguments are zero \n");
+  }
 }
 
-void Custom::calculate() {
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {
-    if(lepton_ref[i]) *lepton_ref[i]=getArgument(i);
+std::string Custom::getGraphInfo( const std::string& name ) const {
+  return FunctionTemplateBase::getGraphInfo( name ) + + "\n" + "FUNC=" + func;
+}
+
+bool Custom::getDerivativeZeroIfValueIsZero() const {
+  return check_multiplication_vars.size()>0;
+}
+
+std::vector<Value*> Custom::getArgumentsToCheck( const std::vector<Value*>& args ) {
+  std::vector<Value*> fargs( check_multiplication_vars.size() );
+  for(unsigned i=0; i<check_multiplication_vars.size(); ++i) {
+    fargs[i] = args[check_multiplication_vars[i]];
   }
-  setValue(expression.evaluate());
-  for(unsigned i=0; i<getNumberOfArguments(); i++) {
-    for(unsigned j=0; j<getNumberOfArguments(); j++) {
-      if(lepton_ref_deriv[i*getNumberOfArguments()+j]) *lepton_ref_deriv[i*getNumberOfArguments()+j]=getArgument(j);
+  return fargs;
+}
+
+void Custom::calc( const ActionWithArguments* action, const std::vector<double>& args, std::vector<double>& vals, Matrix<double>& derivatives ) const {
+  if( args.size()>1 ) {
+    bool allzero=false;
+    if( check_multiplication_vars.size()>0 ) {
+      for(unsigned i=0; i<check_multiplication_vars.size(); ++i) {
+        if( fabs(args[check_multiplication_vars[i]])<epsilon ) {
+          allzero=true;
+          break;
+        }
+      }
+    } else if( zerowhenallzero ) {
+      allzero=(fabs(args[0])<epsilon);
+      for(unsigned i=1; i<args.size(); ++i) {
+        if( fabs(args[i])>epsilon ) {
+          allzero=false;
+          break;
+        }
+      }
+    }
+    if( allzero ) {
+      vals[0]=0;
+      for(unsigned i=0; i<args.size(); i++) {
+        derivatives(0,i) = 0.0;
+      }
+      return;
+    }
+  }
+  vals[0] = function.evaluate( args );
+  if( !noderiv ) {
+    for(unsigned i=0; i<args.size(); i++) {
+      derivatives(0,i) = function.evaluateDeriv( i, args );
     }
-    setDerivative(i,expression_deriv[i].evaluate());
   }
 }
 
