@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2014-2019 The plumed team
+   Copyright (c) 2014-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,11 +20,9 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Function.h"
-#include "ActionRegister.h"
+#include "tools/Communicator.h"
+#include "core/ActionRegister.h"
 #include "core/PlumedMain.h"
-#include "core/Atoms.h"
-
-using namespace std;
 
 namespace PLMD {
 namespace function {
@@ -50,8 +48,7 @@ PRINT ARG=dist,ens.dist
 
 
 class Ensemble :
-  public Function
-{
+  public Function {
   unsigned ens_dim;
   unsigned my_repl;
   unsigned narg;
@@ -65,7 +62,8 @@ class Ensemble :
   double   power;
 public:
   explicit Ensemble(const ActionOptions&);
-  void     calculate();
+  std::string getOutputComponentDescription( const std::string& cname, const Keywords& keys ) const override ;
+  void     calculate() override;
   static void registerKeywords(Keywords& keys);
 };
 
@@ -92,26 +90,37 @@ Ensemble::Ensemble(const ActionOptions&ao):
   do_powers(false),
   kbt(-1.0),
   moment(0),
-  power(0)
-{
+  power(0) {
   parseFlag("REWEIGHT", do_reweight);
-  double temp=0.0;
-  parse("TEMP",temp);
   if(do_reweight) {
-    if(temp>0.0) kbt=plumed.getAtoms().getKBoltzmann()*temp;
-    else kbt=plumed.getAtoms().getKbT();
-    if(kbt==0.0) error("Unless the MD engine passes the temperature to plumed, with REWEIGHT you must specify TEMP");
+    kbt=getkBT();
+    if(kbt==0.0) {
+      error("Unless the MD engine passes the temperature to plumed, with REWEIGHT you must specify TEMP");
+    }
+  } else {
+    double temp=0.0;
+    parse("TEMP",temp);
   }
 
   parse("MOMENT",moment);
-  if(moment==1) error("MOMENT can be any number but for 0 and 1");
-  if(moment!=0) do_moments=true;
+  if(moment==1) {
+    error("MOMENT can be any number but for 0 and 1");
+  }
+  if(moment!=0) {
+    do_moments=true;
+  }
   parseFlag("CENTRAL", do_central);
-  if(!do_moments&&do_central) error("To calculate a CENTRAL moment you need to define for which MOMENT");
+  if(!do_moments&&do_central) {
+    error("To calculate a CENTRAL moment you need to define for which MOMENT");
+  }
 
   parse("POWER",power);
-  if(power==1) error("POWER can be any number but for 0 and 1");
-  if(power!=0) do_powers=true;
+  if(power==1) {
+    error("POWER can be any number but for 0 and 1");
+  }
+  if(power!=0) {
+    do_powers=true;
+  }
 
   checkRead();
 
@@ -124,11 +133,15 @@ Ensemble::Ensemble(const ActionOptions&ao):
   }
   comm.Bcast(ens_dim,0);
   comm.Bcast(my_repl,0);
-  if(ens_dim<2) log.printf("WARNING: ENSEMBLE with one replica is not doing any averaging!\n");
+  if(ens_dim<2) {
+    log.printf("WARNING: ENSEMBLE with one replica is not doing any averaging!\n");
+  }
 
   // prepare output components, the number depending on reweighing or not
   narg = getNumberOfArguments();
-  if(do_reweight) narg--;
+  if(do_reweight) {
+    narg--;
+  }
 
   // these are the averages
   for(unsigned i=0; i<narg; i++) {
@@ -146,23 +159,47 @@ Ensemble::Ensemble(const ActionOptions&ao):
   }
 
   log.printf("  averaging over %u replicas.\n", ens_dim);
-  if(do_reweight) log.printf("  doing simple REWEIGHT using the latest ARGUMENT as energy.\n");
-  if(do_moments&&!do_central)  log.printf("  calculating also the %lf standard moment\n", moment);
-  if(do_moments&&do_central)   log.printf("  calculating also the %lf central moment\n", moment);
-  if(do_powers)                log.printf("  calculating the %lf power of the mean (and moment)\n", power);
+  if(do_reweight) {
+    log.printf("  doing simple REWEIGHT using the latest ARGUMENT as energy.\n");
+  }
+  if(do_moments&&!do_central) {
+    log.printf("  calculating also the %lf standard moment\n", moment);
+  }
+  if(do_moments&&do_central) {
+    log.printf("  calculating also the %lf central moment\n", moment);
+  }
+  if(do_powers) {
+    log.printf("  calculating the %lf power of the mean (and moment)\n", power);
+  }
 }
 
+std::string Ensemble::getOutputComponentDescription( const std::string& cname, const Keywords& keys ) const {
+  for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+    if( cname==getPntrToArgument(i)->getName() ) {
+      return "the average for argument " + cname;
+    }
+    if( cname==getPntrToArgument(i)->getName() + "_m" ) {
+      return "the moment for argument " + cname;
+    }
+  }
+  plumed_error();
+  return "";
+}
+
+
 void Ensemble::calculate() {
   double norm = 0.0;
   double fact = 0.0;
 
   // calculate the weights either from BIAS
   if(do_reweight) {
-    vector<double> bias;
+    std::vector<double> bias;
     bias.resize(ens_dim);
     if(master) {
       bias[my_repl] = getArgument(narg);
-      if(ens_dim>1) multi_sim_comm.Sum(&bias[0], ens_dim);
+      if(ens_dim>1) {
+        multi_sim_comm.Sum(&bias[0], ens_dim);
+      }
     }
     comm.Sum(&bias[0], ens_dim);
     const double maxbias = *(std::max_element(bias.begin(), bias.end()));
@@ -179,16 +216,20 @@ void Ensemble::calculate() {
 
   const double fact_kbt = fact/kbt;
 
-  vector<double> mean(narg);
-  vector<double> dmean(narg,fact);
+  std::vector<double> mean(narg);
+  std::vector<double> dmean(narg,fact);
   // calculate the mean
   if(master) {
-    for(unsigned i=0; i<narg; ++i) mean[i] = fact*getArgument(i);
-    if(ens_dim>1) multi_sim_comm.Sum(&mean[0], narg);
+    for(unsigned i=0; i<narg; ++i) {
+      mean[i] = fact*getArgument(i);
+    }
+    if(ens_dim>1) {
+      multi_sim_comm.Sum(&mean[0], narg);
+    }
   }
   comm.Sum(&mean[0], narg);
 
-  vector<double> v_moment, dv_moment;
+  std::vector<double> v_moment, dv_moment;
   // calculate other moments
   if(do_moments) {
     v_moment.resize(narg);
@@ -197,14 +238,16 @@ void Ensemble::calculate() {
     if(!do_central) {
       if(master) {
         for(unsigned i=0; i<narg; ++i) {
-          const double tmp = fact*pow(getArgument(i),moment-1);
+          const double tmp = fact*std::pow(getArgument(i),moment-1);
           v_moment[i]      = tmp*getArgument(i);
           dv_moment[i]     = moment*tmp;
         }
-        if(ens_dim>1) multi_sim_comm.Sum(&v_moment[0], narg);
+        if(ens_dim>1) {
+          multi_sim_comm.Sum(&v_moment[0], narg);
+        }
       } else {
         for(unsigned i=0; i<narg; ++i) {
-          const double tmp = fact*pow(getArgument(i),moment-1);
+          const double tmp = fact*std::pow(getArgument(i),moment-1);
           dv_moment[i]     = moment*tmp;
         }
       }
@@ -212,14 +255,16 @@ void Ensemble::calculate() {
     } else {
       if(master) {
         for(unsigned i=0; i<narg; ++i) {
-          const double tmp = pow(getArgument(i)-mean[i],moment-1);
+          const double tmp = std::pow(getArgument(i)-mean[i],moment-1);
           v_moment[i]      = fact*tmp*(getArgument(i)-mean[i]);
           dv_moment[i]     = moment*tmp*(fact-fact/norm);
         }
-        if(ens_dim>1) multi_sim_comm.Sum(&v_moment[0], narg);
+        if(ens_dim>1) {
+          multi_sim_comm.Sum(&v_moment[0], narg);
+        }
       } else {
         for(unsigned i=0; i<narg; ++i) {
-          const double tmp = pow(getArgument(i)-mean[i],moment-1);
+          const double tmp = std::pow(getArgument(i)-mean[i],moment-1);
           dv_moment[i]     = moment*tmp*(fact-fact/norm);
         }
       }
@@ -230,11 +275,11 @@ void Ensemble::calculate() {
   // calculate powers of moments
   if(do_powers) {
     for(unsigned i=0; i<narg; ++i) {
-      const double tmp1 = pow(mean[i],power-1);
+      const double tmp1 = std::pow(mean[i],power-1);
       mean[i]          *= tmp1;
       dmean[i]         *= power*tmp1;
       if(do_moments) {
-        const double tmp2 = pow(v_moment[i],power-1);
+        const double tmp2 = std::pow(v_moment[i],power-1);
         v_moment[i]      *= tmp2;
         dv_moment[i]     *= power*tmp2;
       }
