@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -19,7 +19,7 @@
    You should have received a copy of the GNU Lesser General Public License
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "Function.h"
 #include "tools/Exception.h"
 #include "tools/Communicator.h"
@@ -60,8 +60,8 @@ public:
   FilesHandler(const std::vector<std::string> &filenames, const bool &parallelread,  Action &myaction, Log &mylog);
   bool readBunch(BiasRepresentation *br, int stride);
   bool scanOneHill(BiasRepresentation *br, IFile *ifile );
-  void getMinMaxBin(std::vector<Value*> vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin);
-  void getMinMaxBin(std::vector<Value*> vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin, const std::vector<double> &histosigma);
+  void getMinMaxBin(const std::vector<Value*> & vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin);
+  void getMinMaxBin(const std::vector<Value*> & vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin, const std::vector<double> &histosigma);
 };
 FilesHandler::FilesHandler(const std::vector<std::string> &filenames, const bool &parallelread, Action &action, Log &mylog ):filenames(filenames),log(&mylog),parallelread(parallelread),beingread(0),isopen(false) {
   this->action=&action;
@@ -77,7 +77,8 @@ FilesHandler::FilesHandler(const std::vector<std::string> &filenames, const bool
 // note that the FileHandler is completely transparent respect to the biasrepresentation
 // no check are made at this level
 bool FilesHandler::readBunch(BiasRepresentation *br, int stride = -1) {
-  bool morefiles; morefiles=true;
+  bool morefiles;
+  morefiles=true;
   if(parallelread) {
     (*log)<<"  doing parallelread \n";
     plumed_merror("parallelread is not yet implemented !!!");
@@ -89,7 +90,8 @@ bool FilesHandler::readBunch(BiasRepresentation *br, int stride = -1) {
     ff=ifiles[beingread].get();
     if(!isopen) {
       (*log)<<"  opening file "<<filenames[beingread]<<"\n";
-      ff->open(filenames[beingread]); isopen=true;
+      ff->open(filenames[beingread]);
+      isopen=true;
     }
     int n=0;
     while(true) {
@@ -110,7 +112,8 @@ bool FilesHandler::readBunch(BiasRepresentation *br, int stride = -1) {
         (*log)<<"  now total "<<br->getNumberOfKernels()<<" kernels \n";
         beingread++;
         if(beingread<ifiles.size()) {
-          ff=ifiles[beingread].get(); ff->open(filenames[beingread]);
+          ff=ifiles[beingread].get();
+          ff->open(filenames[beingread]);
           (*log)<<"  opening file "<<filenames[beingread]<<"\n";
           isopen=true;
         } else {
@@ -120,15 +123,19 @@ bool FilesHandler::readBunch(BiasRepresentation *br, int stride = -1) {
         }
       }
       // if there are no more files to read and this file is over then quit
-      if(fileisover && !morefiles) {break;}
+      if(fileisover && !morefiles) {
+        break;
+      }
       // if you are in the middle of a file and you are here
       // then means that you read what you need to read
-      if(!fileisover ) {break;}
+      if(!fileisover ) {
+        break;
+      }
     }
   }
   return morefiles;
 }
-void FilesHandler::getMinMaxBin(std::vector<Value*> vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin) {
+void FilesHandler::getMinMaxBin(const std::vector<Value*> & vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin) {
   // create the representation (no grid)
   BiasRepresentation br(vals,cc);
   // read all the kernels
@@ -136,7 +143,7 @@ void FilesHandler::getMinMaxBin(std::vector<Value*> vals, Communicator &cc, std:
   // loop over the kernels and get the support
   br.getMinMaxBin(vmin,vmax,vbin);
 }
-void FilesHandler::getMinMaxBin(std::vector<Value*> vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin, const std::vector<double> &histosigma) {
+void FilesHandler::getMinMaxBin(const std::vector<Value*> & vals, Communicator &cc, std::vector<double> &vmin, std::vector<double> &vmax, std::vector<unsigned> &vbin, const std::vector<double> &histosigma) {
   BiasRepresentation br(vals,cc,histosigma);
   // read all the kernels
   readBunch(&br);
@@ -148,12 +155,18 @@ bool FilesHandler::scanOneHill(BiasRepresentation *br, IFile *ifile ) {
   double dummy;
   if(ifile->scanField("time",dummy)) {
     //(*log)<<"   scanning one hill: "<<dummy<<" \n";
-    if(ifile->FieldExist("biasf")) ifile->scanField("biasf",dummy);
-    if(ifile->FieldExist("clock")) ifile->scanField("clock",dummy);
+    if(ifile->FieldExist("biasf")) {
+      ifile->scanField("biasf",dummy);
+    }
+    if(ifile->FieldExist("clock")) {
+      ifile->scanField("clock",dummy);
+    }
     // keep this intermediate function in case you need to parse more data in the future
     br->pushKernel(ifile);
     //(*log)<<"  read hill\n";
-    if(br->hasSigmaInInput())ifile->allowIgnoredFields();
+    if(br->hasSigmaInInput()) {
+      ifile->allowIgnoredFields();
+    }
     ifile->scanField();
     return true;
   } else {
@@ -173,8 +186,7 @@ double  mylogder( double v1 ) {
 
 
 class FuncSumHills :
-  public Function
-{
+  public Function {
   std::vector<std::string> hillsFiles,histoFiles;
   std::vector<std::string> proj;
   int initstride;
@@ -215,12 +227,13 @@ void FuncSumHills::registerKeywords(Keywords& keys) {
   keys.add("optional","OUTHISTO"," output file for histogram ");
   keys.add("optional","INITSTRIDE"," stride if you want an initial dump ");
   keys.add("optional","STRIDE"," stride when you do it on the fly ");
-  keys.addFlag("ISCLTOOL",true,"use via plumed command line: calculate at read phase and then go");
+  keys.addFlag("ISCLTOOL",false,"use via plumed command line: calculate at read phase and then go");
   keys.addFlag("PARALLELREAD",false,"read parallel HILLS file");
   keys.addFlag("NEGBIAS",false,"dump  negative bias ( -bias )   instead of the free energy: needed in well tempered with flexible hills ");
   keys.addFlag("NOHISTORY",false,"to be used with INITSTRIDE:  it splits the bias/histogram in pieces without previous history  ");
   keys.addFlag("MINTOZERO",false,"translate the resulting bias/histogram to have the minimum to zero  ");
   keys.add("optional","FMT","the format that should be used to output real numbers");
+  keys.setValueDescription("a scalar");
 }
 
 FuncSumHills::FuncSumHills(const ActionOptions&ao):
@@ -238,8 +251,7 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
   lowI_(-1.),
   uppI_(-1.),
   beta(-1.),
-  fmt("%14.9f")
-{
+  fmt("%14.9f") {
 
   // format
   parse("FMT",fmt);
@@ -248,44 +260,62 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
   // Grid Stuff
   std::vector<std::string> gmin;
   parseVector("GRID_MIN",gmin);
-  if(gmin.size()!=getNumberOfArguments() && gmin.size()!=0) error("not enough values for GRID_MIN");
+  if(gmin.size()!=getNumberOfArguments() && gmin.size()!=0) {
+    error("not enough values for GRID_MIN");
+  }
   plumed_massert(gmin.size()==getNumberOfArguments() || gmin.size()==0,"need GRID_MIN argument for this") ;
   std::vector<std::string> gmax;
   parseVector("GRID_MAX",gmax);
-  if(gmax.size()!=getNumberOfArguments() && gmax.size()!=0) error("not enough values for GRID_MAX");
+  if(gmax.size()!=getNumberOfArguments() && gmax.size()!=0) {
+    error("not enough values for GRID_MAX");
+  }
   plumed_massert(gmax.size()==getNumberOfArguments() || gmax.size()==0,"need GRID_MAX argument for this") ;
   std::vector<unsigned> gbin;
   std::vector<double>   gspacing;
   parseVector("GRID_BIN",gbin);
   plumed_massert(gbin.size()==getNumberOfArguments() || gbin.size()==0,"need GRID_BIN argument for this") ;
-  if(gbin.size()!=getNumberOfArguments() && gbin.size()!=0) error("not enough values for GRID_BIN");
+  if(gbin.size()!=getNumberOfArguments() && gbin.size()!=0) {
+    error("not enough values for GRID_BIN");
+  }
   parseVector("GRID_SPACING",gspacing);
   plumed_massert(gspacing.size()==getNumberOfArguments() || gspacing.size()==0,"need GRID_SPACING argument for this") ;
-  if(gspacing.size()!=getNumberOfArguments() && gspacing.size()!=0) error("not enough values for GRID_SPACING");
+  if(gspacing.size()!=getNumberOfArguments() && gspacing.size()!=0) {
+    error("not enough values for GRID_SPACING");
+  }
   if(gspacing.size()!=0 && gbin.size()==0) {
     log<<"  The number of bins will be estimated from GRID_SPACING\n";
   } else if(gspacing.size()!=0 && gbin.size()!=0) {
     log<<"  You specified both GRID_BIN and GRID_SPACING\n";
     log<<"  The more conservative (highest) number of bins will be used for each variable\n";
   }
-  if(gspacing.size()!=0) for(unsigned i=0; i<getNumberOfArguments(); i++) {
-      if(gbin.size()==0) gbin.assign(getNumberOfArguments(),1);
+  if(gspacing.size()!=0)
+    for(unsigned i=0; i<getNumberOfArguments(); i++) {
+      if(gbin.size()==0) {
+        gbin.assign(getNumberOfArguments(),1);
+      }
       double a,b;
       Tools::convert(gmin[i],a);
       Tools::convert(gmax[i],b);
-      unsigned n=((b-a)/gspacing[i])+1;
-      if(gbin[i]<n) gbin[i]=n;
+      unsigned n=std::ceil((b-a)/gspacing[i]);
+      if(gbin[i]<n) {
+        gbin[i]=n;
+      }
     }
 
   // Inteval keyword
   std::vector<double> tmpI(2);
   parseVector("INTERVAL",tmpI);
-  if(tmpI.size()!=2&&tmpI.size()!=0) error("both a lower and an upper limits must be provided with INTERVAL");
-  else if(tmpI.size()==2) {
+  if(tmpI.size()!=2&&tmpI.size()!=0) {
+    error("both a lower and an upper limits must be provided with INTERVAL");
+  } else if(tmpI.size()==2) {
     lowI_=tmpI.at(0);
     uppI_=tmpI.at(1);
-    if(getNumberOfArguments()!=1) error("INTERVAL limits correction works only for monodimensional metadynamics!");
-    if(uppI_<lowI_) error("The Upper limit must be greater than the Lower limit!");
+    if(getNumberOfArguments()!=1) {
+      error("INTERVAL limits correction works only for monodimensional metadynamics!");
+    }
+    if(uppI_<lowI_) {
+      error("The Upper limit must be greater than the Lower limit!");
+    }
     doInt=true;
   }
   if(doInt) {
@@ -294,9 +324,15 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     std::ostringstream strsmin, strsmax;
     strsmin << lowI_;
     strsmax << uppI_;
-    if(gmin.size()==0) gmin.push_back(strsmin.str());
-    if(gmax.size()==0) gmax.push_back(strsmax.str());
-    if(gbin.size()==0) gbin.push_back(200);
+    if(gmin.size()==0) {
+      gmin.push_back(strsmin.str());
+    }
+    if(gmax.size()==0) {
+      gmax.push_back(strsmax.str());
+    }
+    if(gbin.size()==0) {
+      gbin.push_back(200);
+    }
   }
 
 
@@ -306,7 +342,9 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     integratehills=false; // default behaviour
   } else {
     integratehills=true;
-    for(unsigned i=0; i<hillsFiles.size(); i++) log<<"  hillsfile  : "<<hillsFiles[i]<<"\n";
+    for(unsigned i=0; i<hillsFiles.size(); i++) {
+      log<<"  hillsfile  : "<<hillsFiles[i]<<"\n";
+    }
   }
   // histo file:
   parseVector("HISTOFILES",histoFiles);
@@ -314,12 +352,16 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     integratehisto=false;
   } else {
     integratehisto=true;
-    for(unsigned i=0; i<histoFiles.size(); i++) log<<"  histofile  : "<<histoFiles[i]<<"\n";
+    for(unsigned i=0; i<histoFiles.size(); i++) {
+      log<<"  histofile  : "<<histoFiles[i]<<"\n";
+    }
   }
   std::vector<double> histoSigma;
   if(integratehisto) {
     parseVector("HISTOSIGMA",histoSigma);
-    for(unsigned i=0; i<histoSigma.size(); i++) log<<"  histosigma  : "<<histoSigma[i]<<"\n";
+    for(unsigned i=0; i<histoSigma.size(); i++) {
+      log<<"  histosigma  : "<<histoSigma[i]<<"\n";
+    }
   }
 
   // needs a projection?
@@ -332,7 +374,9 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     plumed_massert(proj.size()<=getNumberOfArguments()," The number of projection must be less or equal to the full list of arguments ");
   }
   if(integratehisto&&proj.size()==0) {
-    for(unsigned i=0; i<getNumberOfArguments(); i++) proj.push_back(getPntrToArgument(i)->getName());
+    for(unsigned i=0; i<getNumberOfArguments(); i++) {
+      proj.push_back(getPntrToArgument(i)->getName());
+    }
   }
 
   // add some automatic hills width: not in case stride is defined
@@ -342,13 +386,17 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     log<<"  No boundaries defined: need to do a prescreening of hills \n";
     std::vector<Value*> tmphillsvalues, tmphistovalues;
     if(integratehills) {
-      for(unsigned i=0; i<getNumberOfArguments(); i++)tmphillsvalues.push_back( getPntrToArgument(i) );
+      for(unsigned i=0; i<getNumberOfArguments(); i++) {
+        tmphillsvalues.push_back( getPntrToArgument(i) );
+      }
     }
     if(integratehisto) {
       for(unsigned i=0; i<getNumberOfArguments(); i++) {
         std::string ss = getPntrToArgument(i)->getName();
         for(unsigned j=0; j<proj.size(); j++) {
-          if(proj[j]==ss) tmphistovalues.push_back( getPntrToArgument(i) );
+          if(proj[j]==ss) {
+            tmphistovalues.push_back( getPntrToArgument(i) );
+          }
         }
       }
     }
@@ -399,7 +447,9 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
 
   if( proj.size() != 0 || integratehisto==true  ) {
     parse("KT",beta);
-    for(unsigned i=0; i<proj.size(); i++) log<<"  projection "<<i<<" : "<<proj[i]<<"\n";
+    for(unsigned i=0; i<proj.size(); i++) {
+      log<<"  projection "<<i<<" : "<<proj[i]<<"\n";
+    }
     // this should be only for projection or free energy from histograms
     plumed_massert(beta>0.,"if you make a projection or a histogram correction then you need KT flag!");
     beta=1./beta;
@@ -416,16 +466,21 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
   // output suffix or names
   if(initstride<0) {
     log<<"  Doing only one integration: no stride \n";
-    outhills="fes.dat"; outhisto="histo.dat";
-  }
-  else {
-    outhills="fes_"; outhisto="histo_";
+    outhills="fes.dat";
+    outhisto="histo.dat";
+  } else {
+    outhills="fes_";
+    outhisto="histo_";
     log<<"  Doing integration slices every "<<initstride<<" kernels\n";
     parseFlag("NOHISTORY",nohistory);
-    if(nohistory)log<<"  nohistory: each stride block has no memory of the previous block\n";
+    if(nohistory) {
+      log<<"  nohistory: each stride block has no memory of the previous block\n";
+    }
   }
   parseFlag("MINTOZERO",minTOzero);
-  if(minTOzero)log<<"  mintozero: bias/histogram will be translated to have the minimum value equal to zero\n";
+  if(minTOzero) {
+    log<<"  mintozero: bias/histogram will be translated to have the minimum value equal to zero\n";
+  }
   //what might it be this?
   // here start
   // want something right now?? do it and return
@@ -446,7 +501,9 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
       for(unsigned i=0; i<getNumberOfArguments(); i++) {
         std::string ss = getPntrToArgument(i)->getName();
         for(unsigned j=0; j<proj.size(); j++) {
-          if(proj[j]==ss) tmphistovalues.push_back( getPntrToArgument(i) );
+          if(proj[j]==ss) {
+            tmphistovalues.push_back( getPntrToArgument(i) );
+          }
         }
       }
     }
@@ -458,15 +515,22 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
       if(negativebias) {
         biasrep->setRescaledToBias(true);
         log<<"  required the -bias instead of the free energy \n";
-        if(initstride<0) {outhills="negativebias.dat";}
-        else {outhills="negativebias_";}
+        if(initstride<0) {
+          outhills="negativebias.dat";
+        } else {
+          outhills="negativebias_";
+        }
       }
     }
 
     parse("OUTHILLS",outhills);
     parse("OUTHISTO",outhisto);
-    if(integratehills)log<<"  output file for fes/bias  is :  "<<outhills<<"\n";
-    if(integratehisto)log<<"  output file for histogram is :  "<<outhisto<<"\n";
+    if(integratehills) {
+      log<<"  output file for fes/bias  is :  "<<outhills<<"\n";
+    }
+    if(integratehisto) {
+      log<<"  output file for histogram is :  "<<outhisto<<"\n";
+    }
     checkRead();
 
     log<<"\n";
@@ -490,8 +554,12 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
     std::unique_ptr<FilesHandler> hillsHandler;
     std::unique_ptr<FilesHandler> histoHandler;
 
-    if(integratehills)	hillsHandler=Tools::make_unique<FilesHandler>(hillsFiles,parallelread,*this, log);
-    if(integratehisto)	histoHandler=Tools::make_unique<FilesHandler>(histoFiles,parallelread,*this, log);
+    if(integratehills)	{
+      hillsHandler=Tools::make_unique<FilesHandler>(hillsFiles,parallelread,*this, log);
+    }
+    if(integratehisto)	{
+      histoHandler=Tools::make_unique<FilesHandler>(histoFiles,parallelread,*this, log);
+    }
 
 // Stopwatch is logged when it goes out of scope
     Stopwatch sw(log);
@@ -501,18 +569,27 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
 
     // read a number of hills and put in the bias representation
     int nfiles=0;
-    bool ibias=integratehills; bool ihisto=integratehisto;
+    bool ibias=integratehills;
+    bool ihisto=integratehisto;
     while(true) {
       if(  integratehills  && ibias  ) {
-        if(nohistory) {biasrep->clear(); log<<"  clearing history before reading a new block\n";};
+        if(nohistory) {
+          biasrep->clear();
+          log<<"  clearing history before reading a new block\n";
+        };
         log<<"  reading hills: \n";
-        ibias=hillsHandler->readBunch(biasrep.get(),initstride) ; log<<"\n";
+        ibias=hillsHandler->readBunch(biasrep.get(),initstride) ;
+        log<<"\n";
       }
 
       if(  integratehisto  && ihisto ) {
-        if(nohistory) {historep->clear(); log<<"  clearing history before reading a new block\n";};
+        if(nohistory) {
+          historep->clear();
+          log<<"  clearing history before reading a new block\n";
+        };
         log<<"  reading histogram: \n";
-        ihisto=histoHandler->readBunch(historep.get(),initstride) ;  log<<"\n";
+        ihisto=histoHandler->readBunch(historep.get(),initstride) ;
+        log<<"\n";
       }
 
       // dump: need to project?
@@ -524,17 +601,27 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
           BiasWeight Bw(beta);
           Grid biasGrid=*(biasrep->getGridPtr());
           Grid smallGrid=biasGrid.project(proj,&Bw);
-          OFile gridfile; gridfile.link(*this);
-          std::ostringstream ostr; ostr<<nfiles;
+          OFile gridfile;
+          gridfile.link(*this);
+          std::ostringstream ostr;
+          ostr<<nfiles;
           std::string myout;
-          if(initstride>0) { myout=outhills+ostr.str()+".dat" ;} else {myout=outhills;}
+          if(initstride>0) {
+            myout=outhills+ostr.str()+".dat" ;
+          } else {
+            myout=outhills;
+          }
           log<<"  Bias: Writing subgrid on file "<<myout<<" \n";
           gridfile.open(myout);
-          if(minTOzero) smallGrid.setMinToZero();
+          if(minTOzero) {
+            smallGrid.setMinToZero();
+          }
           smallGrid.setOutputFmt(fmt);
           smallGrid.writeToFile(gridfile);
           gridfile.close();
-          if(!ibias)integratehills=false;// once you get to the final bunch just give up
+          if(!ibias) {
+            integratehills=false;  // once you get to the final bunch just give up
+          }
         }
         // this should be removed
         if(integratehisto) {
@@ -542,20 +629,30 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
           log<<"  Histo: Projecting on subgrid... \n";
           Grid histoGrid=*(historep->getGridPtr());
 
-          OFile gridfile; gridfile.link(*this);
-          std::ostringstream ostr; ostr<<nfiles;
+          OFile gridfile;
+          gridfile.link(*this);
+          std::ostringstream ostr;
+          ostr<<nfiles;
           std::string myout;
-          if(initstride>0) { myout=outhisto+ostr.str()+".dat" ;} else {myout=outhisto;}
+          if(initstride>0) {
+            myout=outhisto+ostr.str()+".dat" ;
+          } else {
+            myout=outhisto;
+          }
           log<<"  Histo: Writing subgrid on file "<<myout<<" \n";
           gridfile.open(myout);
 
           histoGrid.applyFunctionAllValuesAndDerivatives(&mylog,&mylogder);
           histoGrid.scaleAllValuesAndDerivatives(-1./beta);
-          if(minTOzero) histoGrid.setMinToZero();
+          if(minTOzero) {
+            histoGrid.setMinToZero();
+          }
           histoGrid.setOutputFmt(fmt);
           histoGrid.writeToFile(gridfile);
 
-          if(!ihisto)integratehisto=false;// once you get to the final bunch just give up
+          if(!ihisto) {
+            integratehisto=false;  // once you get to the final bunch just give up
+          }
         }
 
       } else {
@@ -565,18 +662,28 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
           Grid biasGrid=*(biasrep->getGridPtr());
           biasGrid.scaleAllValuesAndDerivatives(-1.);
 
-          OFile gridfile; gridfile.link(*this);
-          std::ostringstream ostr; ostr<<nfiles;
+          OFile gridfile;
+          gridfile.link(*this);
+          std::ostringstream ostr;
+          ostr<<nfiles;
           std::string myout;
-          if(initstride>0) { myout=outhills+ostr.str()+".dat" ;} else {myout=outhills;}
+          if(initstride>0) {
+            myout=outhills+ostr.str()+".dat" ;
+          } else {
+            myout=outhills;
+          }
           log<<"  Writing full grid on file "<<myout<<" \n";
           gridfile.open(myout);
 
-          if(minTOzero) biasGrid.setMinToZero();
+          if(minTOzero) {
+            biasGrid.setMinToZero();
+          }
           biasGrid.setOutputFmt(fmt);
           biasGrid.writeToFile(gridfile);
           // rescale back prior to accumulate
-          if(!ibias)integratehills=false;// once you get to the final bunch just give up
+          if(!ibias) {
+            integratehills=false;  // once you get to the final bunch just give up
+          }
         }
         if(integratehisto) {
 
@@ -585,22 +692,34 @@ FuncSumHills::FuncSumHills(const ActionOptions&ao):
           histoGrid.applyFunctionAllValuesAndDerivatives(&mylog,&mylogder);
           histoGrid.scaleAllValuesAndDerivatives(-1./beta);
 
-          OFile gridfile; gridfile.link(*this);
-          std::ostringstream ostr; ostr<<nfiles;
+          OFile gridfile;
+          gridfile.link(*this);
+          std::ostringstream ostr;
+          ostr<<nfiles;
           std::string myout;
-          if(initstride>0) { myout=outhisto+ostr.str()+".dat" ;} else {myout=outhisto;}
+          if(initstride>0) {
+            myout=outhisto+ostr.str()+".dat" ;
+          } else {
+            myout=outhisto;
+          }
           log<<"  Writing full grid on file "<<myout<<" \n";
           gridfile.open(myout);
 
           // also this is useful only for free energy
-          if(minTOzero) histoGrid.setMinToZero();
+          if(minTOzero) {
+            histoGrid.setMinToZero();
+          }
           histoGrid.setOutputFmt(fmt);
           histoGrid.writeToFile(gridfile);
 
-          if(!ihisto)integratehisto=false; // once you get to the final bunch just give up
+          if(!ihisto) {
+            integratehisto=false;  // once you get to the final bunch just give up
+          }
         }
       }
-      if ( !ibias && !ihisto) break; //when both are over then just quit
+      if ( !ibias && !ihisto) {
+        break;  //when both are over then just quit
+      }
 
       nfiles++;
     }
