@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -36,8 +36,7 @@ This is the abstract base class to use for implementing new CV function, within
 
 class Function:
   public ActionWithValue,
-  public ActionWithArguments
-{
+  public ActionWithArguments {
 protected:
   void setDerivative(int,double);
   void setDerivative(Value*,int,double);
@@ -46,6 +45,7 @@ protected:
 public:
   explicit Function(const ActionOptions&);
   virtual ~Function() {}
+  double getArgument( const unsigned& iarg );
   void apply() override;
   static void registerKeywords(Keywords&);
   unsigned getNumberOfDerivatives() override;
@@ -63,7 +63,18 @@ void Function::setDerivative(int i,double d) {
 
 inline
 unsigned Function::getNumberOfDerivatives() {
-  return getNumberOfArguments();
+  unsigned narg=0;
+  for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+    if( getPntrToArgument(i)->getRank()==0 ) {
+      narg++;
+    }
+  }
+  return narg;
+}
+
+inline
+double Function::getArgument( const unsigned& iarg ) {
+  return getPntrToArgument(iarg)->get();
 }
 
 }
