@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2015-2021 The plumed team
+   Copyright (c) 2015-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,7 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "Function.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 
 namespace PLMD {
 namespace function {
@@ -54,8 +54,7 @@ PRINT ARG=d1,d2,d3,st.*
 
 
 class Stats :
-  public Function
-{
+  public Function {
   std::vector<double> parameters;
   bool sqdonly;
   bool components;
@@ -89,46 +88,65 @@ Stats::Stats(const ActionOptions&ao):
   Function(ao),
   sqdonly(false),
   components(false),
-  upperd(false)
-{
+  upperd(false) {
   parseVector("PARAMETERS",parameters);
-  if(parameters.size()!=static_cast<unsigned>(getNumberOfArguments())&&!parameters.empty())
+  if(parameters.size()!=static_cast<unsigned>(getNumberOfArguments())&&!parameters.empty()) {
     error("Size of PARAMETERS array should be either 0 or the same as of the number of arguments in ARG1");
+  }
 
   std::vector<Value*> arg2;
   parseArgumentList("PARARG",arg2);
 
   if(!arg2.empty()) {
-    if(parameters.size()>0) error("It is not possible to use PARARG and PARAMETERS together");
-    if(arg2.size()!=getNumberOfArguments()) error("Size of PARARG array should be the same as number for arguments in ARG");
+    if(parameters.size()>0) {
+      error("It is not possible to use PARARG and PARAMETERS together");
+    }
+    if(arg2.size()!=getNumberOfArguments()) {
+      error("Size of PARARG array should be the same as number for arguments in ARG");
+    }
     for(unsigned i=0; i<arg2.size(); i++) {
       parameters.push_back(arg2[i]->get());
-      if(arg2[i]->hasDerivatives()==true) error("PARARG can only accept arguments without derivatives");
+      if(arg2[i]->hasDerivatives()==true) {
+        error("PARARG can only accept arguments without derivatives");
+      }
     }
   }
 
-  if(parameters.size()!=getNumberOfArguments())
+  if(parameters.size()!=getNumberOfArguments()) {
     error("PARARG or PARAMETERS arrays should include the same number of elements as the arguments in ARG");
+  }
 
-  if(getNumberOfArguments()<2) error("STATS need at least two arguments to be used");
+  if(getNumberOfArguments()<2) {
+    error("STATS need at least two arguments to be used");
+  }
 
   parseFlag("SQDEVSUM",sqdonly);
   parseFlag("SQDEV",components);
   parseFlag("UPPERDISTS",upperd);
 
-  if(sqdonly&&components) error("You cannot used SQDEVSUM and SQDEV at the sametime");
+  if(sqdonly&&components) {
+    error("You cannot used SQDEVSUM and SQDEV at the sametime");
+  }
 
-  if(components) sqdonly = true;
+  if(components) {
+    sqdonly = true;
+  }
 
-  if(!arg2.empty()) log.printf("  using %zu parameters from inactive actions:", arg2.size());
-  else              log.printf("  using %zu parameters:", arg2.size());
-  for(unsigned i=0; i<parameters.size(); i++) log.printf(" %f",parameters[i]);
+  if(!arg2.empty()) {
+    log.printf("  using %zu parameters from inactive actions:", arg2.size());
+  } else {
+    log.printf("  using %zu parameters:", arg2.size());
+  }
+  for(unsigned i=0; i<parameters.size(); i++) {
+    log.printf(" %f",parameters[i]);
+  }
   log.printf("\n");
 
   if(sqdonly) {
     if(components) {
       for(unsigned i=0; i<parameters.size(); i++) {
-        std::string num; Tools::convert(i,num);
+        std::string num;
+        Tools::convert(i,num);
         addComponentWithDerivatives("sqd-"+num);
         componentIsNotPeriodic("sqd-"+num);
       }
@@ -150,16 +168,19 @@ Stats::Stats(const ActionOptions&ao):
   checkRead();
 }
 
-void Stats::calculate()
-{
+void Stats::calculate() {
   if(sqdonly) {
 
     double nsqd = 0.;
     Value* val;
-    if(!components) val=getPntrToComponent("sqdevsum");
+    if(!components) {
+      val=getPntrToComponent("sqdevsum");
+    }
     for(unsigned i=0; i<parameters.size(); ++i) {
       double dev = getArgument(i)-parameters[i];
-      if(upperd&&dev<0) dev=0.;
+      if(upperd&&dev<0) {
+        dev=0.;
+      }
       if(components) {
         val=getPntrToComponent(i);
         val->set(dev*dev);
@@ -168,7 +189,9 @@ void Stats::calculate()
       }
       setDerivative(val,i,2.*dev);
     }
-    if(!components) val->set(nsqd);
+    if(!components) {
+      val->set(nsqd);
+    }
 
   } else {
 
