@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -25,8 +25,6 @@
 #include "core/ActionRegister.h"
 #include "tools/File.h"
 
-using namespace std;
-
 namespace PLMD {
 namespace generic {
 
@@ -56,10 +54,9 @@ DUMPDERIVATIVES ARG=distance,distanceN STRIDE=1 FILE=deriv
 
 class DumpDerivatives :
   public ActionPilot,
-  public ActionWithArguments
-{
-  string file;
-  string fmt;
+  public ActionWithArguments {
+  std::string file;
+  std::string fmt;
   OFile of;
 public:
   void calculate() override {}
@@ -89,10 +86,11 @@ DumpDerivatives::DumpDerivatives(const ActionOptions&ao):
   Action(ao),
   ActionPilot(ao),
   ActionWithArguments(ao),
-  fmt("%15.10f")
-{
+  fmt("%15.10f") {
   parse("FILE",file);
-  if( file.length()==0 ) error("name of output file was not specified");
+  if( file.length()==0 ) {
+    error("name of output file was not specified");
+  }
   parse("FMT",fmt);
   fmt=" "+fmt;
   of.link(*this);
@@ -100,13 +98,25 @@ DumpDerivatives::DumpDerivatives(const ActionOptions&ao):
   log.printf("  on file %s\n",file.c_str());
   log.printf("  with format %s\n",fmt.c_str());
   unsigned nargs=getNumberOfArguments();
-  if( nargs==0 ) error("no arguments specified");
+  if( nargs==0 ) {
+    error("no arguments specified");
+  }
   (getPntrToArgument(0)->getPntrToAction())->turnOnDerivatives();
+  if( getPntrToArgument(0)->getRank()>0 ) {
+    error("cannot dump derivatives of non-scalar objects");
+  }
   unsigned npar=getPntrToArgument(0)->getNumberOfDerivatives();
-  if( npar==0 ) error("one or more arguments has no derivatives");
+  if( npar==0 ) {
+    error("one or more arguments has no derivatives");
+  }
   for(unsigned i=1; i<nargs; i++) {
     (getPntrToArgument(i)->getPntrToAction())->turnOnDerivatives();
-    if( npar!=getPntrToArgument(i)->getNumberOfDerivatives() ) error("the number of derivatives must be the same in all values being dumped");
+    if( getPntrToArgument(i)->getRank()>0 ) {
+      error("cannot dump derivatives of non-scalar objects");
+    }
+    if( npar!=getPntrToArgument(i)->getNumberOfDerivatives() ) {
+      error("the number of derivatives must be the same in all values being dumped");
+    }
   }
   checkRead();
 }
