@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2015-2020 The plumed team
+   Copyright (c) 2015-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -24,12 +24,8 @@
 #include "core/ActionRegister.h"
 #include "tools/File.h"
 #include "core/PlumedMain.h"
-#include "core/Atoms.h"
 
-using namespace std;
-
-namespace PLMD
-{
+namespace PLMD {
 namespace generic {
 
 //+PLUMEDOC PRINTANALYSIS DUMPMASSCHARGE
@@ -65,35 +61,21 @@ plumed driver --mc mcfile --plumed plumed.dat --ixyz traj.xyz
 \endverbatim
 
 With the following input you can dump only the charges for a specific
-group.
+group:
+
 \plumedfile
 solute_ions: GROUP ATOMS=1-121,200-2012
 DUMPATOMS FILE=traj.gro ATOMS=solute_ions STRIDE=100
 DUMPMASSCHARGE FILE=mcfile ATOMS=solute_ions
 \endplumedfile
-Notice however that if you want to process the charges
-with the driver (e.g. reading traj.gro) you have to fix atom
-numbers first, e.g. with the script
-\verbatim
-awk 'BEGIN{c=0}{
-  if(match($0,"#")) print ; else {print c,$2,$3; c++}
-}' < mc > newmc
-}'
-\endverbatim
-then
-\verbatim
-plumed driver --mc newmc --plumed plumed.dat --ixyz traj.gro
-\endverbatim
-
 
 */
 //+ENDPLUMEDOC
 
 class DumpMassCharge:
   public ActionAtomistic,
-  public ActionPilot
-{
-  string file;
+  public ActionPilot {
+  std::string file;
   bool first;
   bool second;
   bool print_masses;
@@ -102,6 +84,9 @@ public:
   explicit DumpMassCharge(const ActionOptions&);
   ~DumpMassCharge();
   static void registerKeywords( Keywords& keys );
+  bool actionHasForces() override {
+    return false;
+  }
   void prepare() override;
   void calculate() override {}
   void apply() override {}
@@ -128,19 +113,20 @@ DumpMassCharge::DumpMassCharge(const ActionOptions&ao):
   first(true),
   second(true),
   print_masses(true),
-  print_charges(true)
-{
-  vector<AtomNumber> atoms;
+  print_charges(true) {
+  std::vector<AtomNumber> atoms;
   parse("FILE",file);
-  if(file.length()==0) error("name of output file was not specified");
+  if(file.length()==0) {
+    error("name of output file was not specified");
+  }
   log.printf("  output written to file %s\n",file.c_str());
 
   parseAtomList("ATOMS",atoms);
 
   if(atoms.size()==0) {
-    for(int i=0; i<plumed.getAtoms().getNatoms(); i++) {
-      atoms.push_back(AtomNumber::index(i));
-    }
+    std::vector<std::string> strvec(1);
+    strvec[0]="@mdatoms";
+    interpretAtomList( strvec,atoms );
   }
 
   bool only_masses = false;
@@ -161,7 +147,9 @@ DumpMassCharge::DumpMassCharge(const ActionOptions&ao):
   checkRead();
 
   log.printf("  printing the following atoms:" );
-  for(unsigned i=0; i<atoms.size(); ++i) log.printf(" %d",atoms[i].serial() );
+  for(unsigned i=0; i<atoms.size(); ++i) {
+    log.printf(" %d",atoms[i].serial() );
+  }
   log.printf("\n");
   requestAtoms(atoms);
 
@@ -173,13 +161,15 @@ DumpMassCharge::DumpMassCharge(const ActionOptions&ao):
 
 void DumpMassCharge::prepare() {
   if(!first && second) {
-    requestAtoms(vector<AtomNumber>());
+    requestAtoms(std::vector<AtomNumber>());
     second=false;
   }
 }
 
 void DumpMassCharge::update() {
-  if(!first) return;
+  if(!first) {
+    return;
+  }
   first=false;
 
   OFile of;
@@ -189,8 +179,12 @@ void DumpMassCharge::update() {
   for(unsigned i=0; i<getNumberOfAtoms(); i++) {
     int ii=getAbsoluteIndex(i).index();
     of.printField("index",ii);
-    if(print_masses) {of.printField("mass",getMass(i));}
-    if(print_charges) {of.printField("charge",getCharge(i));}
+    if(print_masses) {
+      of.printField("mass",getMass(i));
+    }
+    if(print_charges) {
+      of.printField("charge",getCharge(i));
+    }
     of.printField();
   }
 }
