@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -25,8 +25,6 @@
 #include "core/ActionRegister.h"
 #include "tools/File.h"
 
-using namespace std;
-
 namespace PLMD {
 namespace generic {
 
@@ -51,10 +49,9 @@ DUMPPROJECTIONS ARG=d FILE=proj STRIDE=20
 
 class DumpProjections :
   public ActionPilot,
-  public ActionWithArguments
-{
-  string file;
-  string fmt;
+  public ActionWithArguments {
+  std::string file;
+  std::string fmt;
   OFile of;
 public:
   void calculate() override {}
@@ -62,7 +59,9 @@ public:
   static void registerKeywords(Keywords& keys);
   void apply() override {}
   void update() override;
-  bool checkNeedsGradients()const override {return true;}
+  bool checkNeedsGradients()const override {
+    return true;
+  }
   ~DumpProjections();
 };
 
@@ -85,10 +84,11 @@ DumpProjections::DumpProjections(const ActionOptions&ao):
   Action(ao),
   ActionPilot(ao),
   ActionWithArguments(ao),
-  fmt("%15.10f")
-{
+  fmt("%15.10f") {
   parse("FILE",file);
-  if( file.length()==0 ) error("filename not specified");
+  if( file.length()==0 ) {
+    error("filename not specified");
+  }
   parse("FMT",fmt);
   fmt=" "+fmt;
   of.open(file);
