@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -23,8 +23,6 @@
 #include "core/ActionWithArguments.h"
 #include "core/ActionRegister.h"
 
-using namespace std;
-
 namespace PLMD {
 namespace generic {
 
@@ -69,11 +67,10 @@ only when required.
 
 class Print :
   public ActionPilot,
-  public ActionWithArguments
-{
-  string file;
+  public ActionWithArguments {
+  std::string file;
   OFile ofile;
-  string fmt;
+  std::string fmt;
 // small internal utility
 /////////////////////////////////////////
 // these are crazy things just for debug:
@@ -82,11 +79,12 @@ class Print :
   int rotate;
   int rotateCountdown;
   int rotateLast;
-  vector<Value*> rotateArguments;
+  std::vector<Value*> rotateArguments;
 /////////////////////////////////////////
 public:
   void calculate() override {}
   void prepare() override;
+  std::string writeInGraph() const override;
   explicit Print(const ActionOptions&);
   static void registerKeywords(Keywords& keys);
   void apply() override {}
@@ -115,8 +113,7 @@ Print::Print(const ActionOptions&ao):
   ActionPilot(ao),
   ActionWithArguments(ao),
   fmt("%f"),
-  rotate(0)
-{
+  rotate(0) {
   ofile.link(*this);
   parse("FILE",file);
   if(file.length()>0) {
@@ -129,7 +126,10 @@ Print::Print(const ActionOptions&ao):
   parse("FMT",fmt);
   fmt=" "+fmt;
   log.printf("  with format %s\n",fmt.c_str());
-  for(unsigned i=0; i<getNumberOfArguments(); ++i) ofile.setupPrintValue( getPntrToArgument(i) );
+  for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+    ofile.setupPrintValue( getPntrToArgument(i) );
+    getPntrToArgument(i)->buildDataStore(true);
+  }
 /////////////////////////////////////////
 // these are crazy things just for debug:
 // they allow to change regularly the
@@ -137,15 +137,21 @@ Print::Print(const ActionOptions&ao):
   parse("_ROTATE",rotate);
   if(rotate>0) {
     rotateCountdown=rotate;
-    for(unsigned i=0; i<getNumberOfArguments(); ++i) rotateArguments.push_back( getPntrToArgument(i) );
-    vector<Value*> a(1,rotateArguments[0]);
-    requestArguments(vector<Value*>(1,rotateArguments[0]));
+    for(unsigned i=0; i<getNumberOfArguments(); ++i) {
+      rotateArguments.push_back( getPntrToArgument(i) );
+    }
+    std::vector<Value*> a(1,rotateArguments[0]);
+    requestArguments(std::vector<Value*>(1,rotateArguments[0]));
     rotateLast=0;
   }
 /////////////////////////////////////////
   checkRead();
 }
 
+std::string Print::writeInGraph() const {
+  return getName() + "\n" + "FILE=" + file;
+}
+
 void Print::prepare() {
 /////////////////////////////////////////
 // these are crazy things just for debug:
@@ -157,7 +163,7 @@ void Print::prepare() {
       rotateCountdown=rotate;
       rotateLast++;
       rotateLast%=rotateArguments.size();
-      requestArguments(vector<Value*>(1,rotateArguments[rotateLast]));
+      requestArguments(std::vector<Value*>(1,rotateArguments[rotateLast]));
     }
   }
 /////////////////////////////////////////
@@ -168,7 +174,7 @@ void Print::update() {
   ofile.printField("time",getTime());
   for(unsigned i=0; i<getNumberOfArguments(); i++) {
     ofile.fmtField(fmt);
-    ofile.printField( getPntrToArgument(i), getArgument(i) );
+    getPntrToArgument(i)->print( ofile );
   }
   ofile.printField();
 }
