@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2014-2021 The plumed team
+   Copyright (c) 2014-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -23,13 +23,8 @@
 #include "core/ActionRegister.h"
 #include "tools/NeighborList.h"
 #include "tools/Pbc.h"
-
-#include <string>
-#include <cmath>
 #include <memory>
 
-using namespace std;
-
 namespace PLMD {
 namespace isdb {
 
@@ -70,11 +65,10 @@ PRINT ARG=noes.* FILE=colvar
 //+ENDPLUMEDOC
 
 class NOE :
-  public MetainferenceBase
-{
+  public MetainferenceBase {
 private:
   bool             pbc;
-  vector<unsigned> nga;
+  std::vector<unsigned> nga;
   std::unique_ptr<NeighborList> nl;
   unsigned         tot_size;
 public:
@@ -87,7 +81,6 @@ public:
 PLUMED_REGISTER_ACTION(NOE,"NOE")
 
 void NOE::registerKeywords( Keywords& keys ) {
-  componentsAreNotOptional(keys);
   MetainferenceBase::registerKeywords(keys);
   keys.addFlag("NOPBC",false,"ignore the periodic boundary conditions when calculating distances");
   keys.add("numbered","GROUPA","the atoms involved in each of the contacts you wish to calculate. "
@@ -105,46 +98,65 @@ void NOE::registerKeywords( Keywords& keys ) {
 
 NOE::NOE(const ActionOptions&ao):
   PLUMED_METAINF_INIT(ao),
-  pbc(true)
-{
+  pbc(true) {
   bool nopbc=!pbc;
   parseFlag("NOPBC",nopbc);
   pbc=!nopbc;
 
   // Read in the atoms
-  vector<AtomNumber> t, ga_lista, gb_lista;
+  std::vector<AtomNumber> t, ga_lista, gb_lista;
   for(int i=1;; ++i ) {
     parseAtomList("GROUPA", i, t );
-    if( t.empty() ) break;
-    for(unsigned j=0; j<t.size(); j++) ga_lista.push_back(t[j]);
+    if( t.empty() ) {
+      break;
+    }
+    for(unsigned j=0; j<t.size(); j++) {
+      ga_lista.push_back(t[j]);
+    }
     nga.push_back(t.size());
     t.resize(0);
   }
-  vector<unsigned> ngb;
+  std::vector<unsigned> ngb;
   for(int i=1;; ++i ) {
     parseAtomList("GROUPB", i, t );
-    if( t.empty() ) break;
-    for(unsigned j=0; j<t.size(); j++) gb_lista.push_back(t[j]);
+    if( t.empty() ) {
+      break;
+    }
+    for(unsigned j=0; j<t.size(); j++) {
+      gb_lista.push_back(t[j]);
+    }
     ngb.push_back(t.size());
-    if(ngb[i-1]!=nga[i-1]) error("The same number of atoms is expected for the same GROUPA-GROUPB couple");
+    if(ngb[i-1]!=nga[i-1]) {
+      error("The same number of atoms is expected for the same GROUPA-GROUPB couple");
+    }
     t.resize(0);
   }
-  if(nga.size()!=ngb.size()) error("There should be the same number of GROUPA and GROUPB keywords");
+  if(nga.size()!=ngb.size()) {
+    error("There should be the same number of GROUPA and GROUPB keywords");
+  }
   // Create neighbour lists
-  nl.reset( new NeighborList(ga_lista,gb_lista,false,true,pbc,getPbc(),comm) );
+  nl=Tools::make_unique<NeighborList>(ga_lista,gb_lista,false,true,pbc,getPbc(),comm);
 
   // Optionally add an experimental value (like with RDCs)
-  vector<double> noedist;
+  std::vector<double> noedist;
   noedist.resize( nga.size() );
   unsigned ntarget=0;
   for(unsigned i=0; i<nga.size(); ++i) {
-    if( !parseNumbered( "NOEDIST", i+1, noedist[i] ) ) break;
+    if( !parseNumbered( "NOEDIST", i+1, noedist[i] ) ) {
+      break;
+    }
     ntarget++;
   }
   bool addexp=false;
-  if(ntarget!=nga.size() && ntarget!=0) error("found wrong number of NOEDIST values");
-  if(ntarget==nga.size()) addexp=true;
-  if(getDoScore()&&!addexp) error("with DOSCORE you need to set the NOEDIST values");
+  if(ntarget!=nga.size() && ntarget!=0) {
+    error("found wrong number of NOEDIST values");
+  }
+  if(ntarget==nga.size()) {
+    addexp=true;
+  }
+  if(getDoScore()&&!addexp) {
+    error("with DOSCORE you need to set the NOEDIST values");
+  }
 
   // Output details of all contacts
   unsigned index=0;
@@ -157,20 +169,25 @@ NOE::NOE(const ActionOptions&ao):
   }
   tot_size = index;
 
-  if(pbc)      log.printf("  using periodic boundary conditions\n");
-  else         log.printf("  without periodic boundary conditions\n");
+  if(pbc) {
+    log.printf("  using periodic boundary conditions\n");
+  } else {
+    log.printf("  without periodic boundary conditions\n");
+  }
 
   log << " Bibliography" << plumed.cite("Bonomi, Camilloni, Bioinformatics, 33, 3999 (2017)") << "\n";
 
   if(!getDoScore()) {
     for(unsigned i=0; i<nga.size(); i++) {
-      string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponentWithDerivatives("noe-"+num);
       componentIsNotPeriodic("noe-"+num);
     }
     if(addexp) {
       for(unsigned i=0; i<nga.size(); i++) {
-        string num; Tools::convert(i,num);
+        std::string num;
+        Tools::convert(i,num);
         addComponent("exp-"+num);
         componentIsNotPeriodic("exp-"+num);
         Value* comp=getPntrToComponent("exp-"+num);
@@ -179,12 +196,14 @@ NOE::NOE(const ActionOptions&ao):
     }
   } else {
     for(unsigned i=0; i<nga.size(); i++) {
-      string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponent("noe-"+num);
       componentIsNotPeriodic("noe-"+num);
     }
     for(unsigned i=0; i<nga.size(); i++) {
-      string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponent("exp-"+num);
       componentIsNotPeriodic("exp-"+num);
       Value* comp=getPntrToComponent("exp-"+num);
@@ -201,18 +220,20 @@ NOE::NOE(const ActionOptions&ao):
   checkRead();
 }
 
-void NOE::calculate()
-{
+void NOE::calculate() {
   const unsigned ngasz=nga.size();
-  vector<Vector> deriv(tot_size, Vector{0,0,0});
+  std::vector<Vector> deriv(tot_size, Vector{0,0,0});
 
   #pragma omp parallel for num_threads(OpenMP::getNumThreads())
   for(unsigned i=0; i<ngasz; i++) {
     Tensor dervir;
     double noe=0;
     unsigned index=0;
-    for(unsigned k=0; k<i; k++) index+=nga[k];
-    string num; Tools::convert(i,num);
+    for(unsigned k=0; k<i; k++) {
+      index+=nga[k];
+    }
+    std::string num;
+    Tools::convert(i,num);
     Value* val=getPntrToComponent("noe-"+num);
     // cycle over equivalent atoms
     for(unsigned j=0; j<nga[i]; j++) {
@@ -220,8 +241,11 @@ void NOE::calculate()
       const unsigned i1=nl->getClosePair(index+j).second;
 
       Vector distance;
-      if(pbc) distance=pbcDistance(getPosition(i0),getPosition(i1));
-      else    distance=delta(getPosition(i0),getPosition(i1));
+      if(pbc) {
+        distance=pbcDistance(getPosition(i0),getPosition(i1));
+      } else {
+        distance=delta(getPosition(i0),getPosition(i1));
+      }
 
       const double ir2=1./distance.modulo2();
       const double ir6=ir2*ir2*ir2;
@@ -238,7 +262,9 @@ void NOE::calculate()
     val->set(noe);
     if(!getDoScore()) {
       setBoxDerivatives(val, dervir);
-    } else setCalcData(i, noe);
+    } else {
+      setCalcData(i, noe);
+    }
   }
 
   if(getDoScore()) {
@@ -251,15 +277,20 @@ void NOE::calculate()
     Value* val=getPntrToComponent("score");
     for(unsigned i=0; i<ngasz; i++) {
       unsigned index=0;
-      for(unsigned k=0; k<i; k++) index+=nga[k];
+      for(unsigned k=0; k<i; k++) {
+        index+=nga[k];
+      }
       // cycle over equivalent atoms
       for(unsigned j=0; j<nga[i]; j++) {
         const unsigned i0=nl->getClosePair(index+j).first;
         const unsigned i1=nl->getClosePair(index+j).second;
 
         Vector distance;
-        if(pbc) distance=pbcDistance(getPosition(i0),getPosition(i1));
-        else    distance=delta(getPosition(i0),getPosition(i1));
+        if(pbc) {
+          distance=pbcDistance(getPosition(i0),getPosition(i1));
+        } else {
+          distance=delta(getPosition(i0),getPosition(i1));
+        }
 
         dervir += Tensor(distance,deriv[index+j]*getMetaDer(i));
         setAtomsDerivatives(val, i0,  deriv[index+j]*getMetaDer(i));
@@ -272,7 +303,9 @@ void NOE::calculate()
 
 void NOE::update() {
   // write status file
-  if(getWstride()>0&& (getStep()%getWstride()==0 || getCPT()) ) writeStatus();
+  if(getWstride()>0&& (getStep()%getWstride()==0 || getCPT()) ) {
+    writeStatus();
+  }
 }
 
 }
