@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2014-2021 The plumed team
+   Copyright (c) 2014-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -30,8 +30,6 @@
 #include <gsl/gsl_blas.h>
 #endif
 
-using namespace std;
-
 namespace PLMD {
 namespace isdb {
 
@@ -174,13 +172,12 @@ PRINT ARG=st.corr,pcse.bias FILE=colvar
 //+ENDPLUMEDOC
 
 class RDC :
-  public MetainferenceBase
-{
+  public MetainferenceBase {
 private:
   double         Const;
   double         mu_s;
   double         scale;
-  vector<double> coupl;
+  std::vector<double> coupl;
   bool           svd;
   bool           pbc;
 
@@ -223,7 +220,6 @@ PLUMED_REGISTER_ACTION(RDC,"RDC")
 PLUMED_REGISTER_ACTION(RDC,"PCS")
 
 void RDC::registerKeywords( Keywords& keys ) {
-  componentsAreNotOptional(keys);
   MetainferenceBase::registerKeywords(keys);
   keys.addFlag("NOPBC",false,"ignore the periodic boundary conditions when calculating distances");
   keys.add("numbered","ATOMS","the couple of atoms involved in each of the bonds for which you wish to calculate the RDC. "
@@ -233,7 +229,7 @@ void RDC::registerKeywords( Keywords& keys ) {
   keys.add("compulsory","GYROM","1.","Add the product of the gyromagnetic constants for the bond. ");
   keys.add("compulsory","SCALE","1.","Add the scaling factor to take into account concentration and other effects. ");
   keys.addFlag("SVD",false,"Set to TRUE if you want to back calculate using Single Value Decomposition (need GSL at compilation time).");
-  keys.add("numbered","COUPLING","Add an experimental value for each coupling (needed by SVD and useful for \\ref STATS).");
+  keys.add("numbered","COUPLING","Add an experimental value for each coupling (needed by SVD and useful for STATS).");
   keys.addOutputComponent("rdc","default","the calculated # RDC");
   keys.addOutputComponent("exp","SVD/COUPLING","the experimental # RDC");
   keys.addOutputComponent("Sxx","SVD","Tensor component");
@@ -249,8 +245,7 @@ RDC::RDC(const ActionOptions&ao):
   Const(1.),
   mu_s(1.),
   scale(1.),
-  pbc(true)
-{
+  pbc(true) {
   bool nopbc=!pbc;
   parseFlag("NOPBC",nopbc);
   pbc=!nopbc;
@@ -258,16 +253,22 @@ RDC::RDC(const ActionOptions&ao):
   const double RDCConst = 0.3356806;
   const double PCSConst = 1.0;
 
-  if( getName().find("RDC")!=std::string::npos) { Const *= RDCConst; }
-  else if( getName().find("PCS")!=std::string::npos) { Const *= PCSConst; }
+  if( getName().find("RDC")!=std::string::npos) {
+    Const *= RDCConst;
+  } else if( getName().find("PCS")!=std::string::npos) {
+    Const *= PCSConst;
+  }
 
   // Read in the atoms
-  vector<AtomNumber> t, atoms;
+  std::vector<AtomNumber> t, atoms;
   for(int i=1;; ++i ) {
     parseAtomList("ATOMS", i, t );
-    if( t.empty() ) break;
+    if( t.empty() ) {
+      break;
+    }
     if( t.size()!=2 ) {
-      std::string ss; Tools::convert(i,ss);
+      std::string ss;
+      Tools::convert(i,ss);
       error("ATOMS" + ss + " keyword has the wrong number of atoms");
     }
     atoms.push_back(t[0]);
@@ -279,38 +280,58 @@ RDC::RDC(const ActionOptions&ao):
 
   // Read in GYROMAGNETIC constants
   parse("GYROM", mu_s);
-  if(mu_s==0.) error("GYROM cannot be 0");
+  if(mu_s==0.) {
+    error("GYROM cannot be 0");
+  }
 
   // Read in SCALING factors
   parse("SCALE", scale);
-  if(scale==0.) error("SCALE cannot be 0");
+  if(scale==0.) {
+    error("SCALE cannot be 0");
+  }
 
   svd=false;
   parseFlag("SVD",svd);
 #ifndef __PLUMED_HAS_GSL
-  if(svd) error("You CANNOT use SVD without GSL. Recompile PLUMED with GSL!\n");
+  if(svd) {
+    error("You CANNOT use SVD without GSL. Recompile PLUMED with GSL!\n");
+  }
 #endif
-  if(svd&&getDoScore()) error("It is not possible to use SVD and METAINFERENCE together");
+  if(svd&&getDoScore()) {
+    error("It is not possible to use SVD and METAINFERENCE together");
+  }
 
   // Optionally add an experimental value
   coupl.resize( ndata );
   unsigned ntarget=0;
   for(unsigned i=0; i<ndata; ++i) {
-    if( !parseNumbered( "COUPLING", i+1, coupl[i] ) ) break;
+    if( !parseNumbered( "COUPLING", i+1, coupl[i] ) ) {
+      break;
+    }
     ntarget++;
   }
   bool addexp=false;
-  if(ntarget!=ndata && ntarget!=0) error("found wrong number of COUPLING values");
-  if(ntarget==ndata) addexp=true;
-  if(getDoScore()&&!addexp) error("with DOSCORE you need to set the COUPLING values");
-  if(svd&&!addexp) error("with SVD you need to set the COUPLING values");
+  if(ntarget!=ndata && ntarget!=0) {
+    error("found wrong number of COUPLING values");
+  }
+  if(ntarget==ndata) {
+    addexp=true;
+  }
+  if(getDoScore()&&!addexp) {
+    error("with DOSCORE you need to set the COUPLING values");
+  }
+  if(svd&&!addexp) {
+    error("with SVD you need to set the COUPLING values");
+  }
 
 
   // Output details of all contacts
   log.printf("  Gyromagnetic moment is %f. Scaling factor is %f.",mu_s,scale);
   for(unsigned i=0; i<ndata; ++i) {
     log.printf("  The %uth Bond Dipolar Coupling is calculated from atoms : %d %d.", i+1, atoms[2*i].serial(), atoms[2*i+1].serial());
-    if(addexp) log.printf(" Experimental coupling is %f.", coupl[i]);
+    if(addexp) {
+      log.printf(" Experimental coupling is %f.", coupl[i]);
+    }
     log.printf("\n");
   }
 
@@ -322,13 +343,15 @@ RDC::RDC(const ActionOptions&ao):
 
   if(!getDoScore()&&!svd) {
     for(unsigned i=0; i<ndata; i++) {
-      std::string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponentWithDerivatives("rdc-"+num);
       componentIsNotPeriodic("rdc-"+num);
     }
     if(addexp) {
       for(unsigned i=0; i<ndata; i++) {
-        std::string num; Tools::convert(i,num);
+        std::string num;
+        Tools::convert(i,num);
         addComponent("exp-"+num);
         componentIsNotPeriodic("exp-"+num);
         Value* comp=getPntrToComponent("exp-"+num);
@@ -337,12 +360,14 @@ RDC::RDC(const ActionOptions&ao):
     }
   } else {
     for(unsigned i=0; i<ndata; i++) {
-      std::string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponentWithDerivatives("rdc-"+num);
       componentIsNotPeriodic("rdc-"+num);
     }
     for(unsigned i=0; i<ndata; i++) {
-      std::string num; Tools::convert(i,num);
+      std::string num;
+      Tools::convert(i,num);
       addComponent("exp-"+num);
       componentIsNotPeriodic("exp-"+num);
       Value* comp=getPntrToComponent("exp-"+num);
@@ -351,12 +376,18 @@ RDC::RDC(const ActionOptions&ao):
   }
 
   if(svd) {
-    addComponent("Sxx"); componentIsNotPeriodic("Sxx");
-    addComponent("Syy"); componentIsNotPeriodic("Syy");
-    addComponent("Szz"); componentIsNotPeriodic("Szz");
-    addComponent("Sxy"); componentIsNotPeriodic("Sxy");
-    addComponent("Sxz"); componentIsNotPeriodic("Sxz");
-    addComponent("Syz"); componentIsNotPeriodic("Syz");
+    addComponent("Sxx");
+    componentIsNotPeriodic("Sxx");
+    addComponent("Syy");
+    componentIsNotPeriodic("Syy");
+    addComponent("Szz");
+    componentIsNotPeriodic("Szz");
+    addComponent("Sxy");
+    componentIsNotPeriodic("Sxy");
+    addComponent("Sxz");
+    componentIsNotPeriodic("Sxz");
+    addComponent("Syz");
+    componentIsNotPeriodic("Syz");
   }
 
   requestAtoms(atoms, false);
@@ -368,8 +399,7 @@ RDC::RDC(const ActionOptions&ao):
   checkRead();
 }
 
-void RDC::do_svd()
-{
+void RDC::do_svd() {
 #ifdef __PLUMED_HAS_GSL
   gsl_vector_unique_ptr rdc_vec(gsl_vector_alloc(coupl.size())),
                         S(gsl_vector_alloc(5)),
@@ -385,11 +415,14 @@ void RDC::do_svd()
   gsl_vector_set_zero(bc.get());
 
   unsigned index=0;
-  vector<double> dmax(coupl.size());
+  std::vector<double> dmax(coupl.size());
   for(unsigned r=0; r<getNumberOfAtoms(); r+=2) {
     Vector  distance;
-    if(pbc) distance = pbcDistance(getPosition(r),getPosition(r+1));
-    else    distance = delta(getPosition(r),getPosition(r+1));
+    if(pbc) {
+      distance = pbcDistance(getPosition(r),getPosition(r+1));
+    } else {
+      distance = delta(getPosition(r),getPosition(r+1));
+    }
     double d    = distance.modulo();
     double d2   = d*d;
     double d3   = d2*d;
@@ -440,8 +473,7 @@ void RDC::do_svd()
 #endif
 }
 
-void RDC::calculate()
-{
+void RDC::calculate() {
   if(svd) {
     do_svd();
     return;
@@ -449,20 +481,22 @@ void RDC::calculate()
 
   const double max  = -Const*scale*mu_s;
   const unsigned N=getNumberOfAtoms();
-  vector<Vector> dRDC(N/2, Vector{0.,0.,0.});
+  std::vector<Vector> dRDC(N/2, Vector{0.,0.,0.});
 
   /* RDC Calculations and forces */
   #pragma omp parallel num_threads(OpenMP::getNumThreads())
   {
     #pragma omp for
-    for(unsigned r=0; r<N; r+=2)
-    {
+    for(unsigned r=0; r<N; r+=2) {
       const unsigned index=r/2;
       Vector  distance;
-      if(pbc) distance   = pbcDistance(getPosition(r),getPosition(r+1));
-      else    distance   = delta(getPosition(r),getPosition(r+1));
+      if(pbc) {
+        distance   = pbcDistance(getPosition(r),getPosition(r+1));
+      } else {
+        distance   = delta(getPosition(r),getPosition(r+1));
+      }
       const double d2    = distance.modulo2();
-      const double ind   = 1./sqrt(d2);
+      const double ind   = 1./std::sqrt(d2);
       const double ind2  = 1./d2;
       const double ind3  = ind2*ind;
       const double x2    = distance[0]*distance[0]*ind2;
@@ -480,14 +514,17 @@ void RDC::calculate()
       dRDC[index][1] *= prod_xy;
       dRDC[index][2] *= prod_z;
 
-      string num; Tools::convert(index,num);
+      std::string num;
+      Tools::convert(index,num);
       Value* val=getPntrToComponent("rdc-"+num);
       val->set(rdc);
       if(!getDoScore()) {
         setBoxDerivatives(val, Tensor(distance,dRDC[index]));
         setAtomsDerivatives(val, r,  dRDC[index]);
         setAtomsDerivatives(val, r+1, -dRDC[index]);
-      } else setCalcData(index, rdc);
+      } else {
+        setCalcData(index, rdc);
+      }
     }
   }
 
@@ -499,12 +536,14 @@ void RDC::calculate()
 
     /* calculate final derivatives */
     Value* val=getPntrToComponent("score");
-    for(unsigned r=0; r<N; r+=2)
-    {
+    for(unsigned r=0; r<N; r+=2) {
       const unsigned index=r/2;
       Vector  distance;
-      if(pbc) distance   = pbcDistance(getPosition(r),getPosition(r+1));
-      else    distance   = delta(getPosition(r),getPosition(r+1));
+      if(pbc) {
+        distance   = pbcDistance(getPosition(r),getPosition(r+1));
+      } else {
+        distance   = delta(getPosition(r),getPosition(r+1));
+      }
       const Vector der = dRDC[index]*getMetaDer(index);
       dervir += Tensor(distance, der);
       setAtomsDerivatives(val, r,  der);
@@ -516,7 +555,9 @@ void RDC::calculate()
 
 void RDC::update() {
   // write status file
-  if(getWstride()>0&& (getStep()%getWstride()==0 || getCPT()) ) writeStatus();
+  if(getWstride()>0&& (getStep()%getWstride()==0 || getCPT()) ) {
+    writeStatus();
+  }
 }
 
 }
