@@ -34,10 +34,10 @@ OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
 OTHER DEALINGS WITH THE SOFTWARE.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
-#ifdef __PLUMED_INTERNAL_MOLFILE_PLUGINS
+#if defined(__PLUMED_HAS_MOLFILE_PLUGINS) && ! defined(__PLUMED_HAS_EXTERNAL_MOLFILE_PLUGINS)
 /***************************************************************************
  *cr
- *cr            (C) Copyright 1995-2009 The Board of Trustees of the
+ *cr            (C) Copyright 1995-2016 The Board of Trustees of the
  *cr                        University of Illinois
  *cr                         All Rights Reserved
  *cr
@@ -48,7 +48,7 @@ OTHER DEALINGS WITH THE SOFTWARE.
  *
  *      $RCSfile: pdbplugin.c,v $
  *      $Author: johns $       $Locker:  $             $State: Exp $
- *      $Revision: 1.72 $       $Date: 2009/04/29 15:45:32 $
+ *      $Revision: 1.73 $       $Date: 2016/11/28 05:01:54 $
  *
  ***************************************************************************/
 
@@ -69,7 +69,6 @@ OTHER DEALINGS WITH THE SOFTWARE.
 namespace PLMD{
 namespace molfile{
 
-
 /*
  * API functions start here
  */
@@ -579,7 +578,7 @@ static int write_timestep(void *v, const molfile_timestep_t *ts) {
         pos[0], pos[1], pos[2], 
         atom->occupancy, atom->bfactor, atom->chain, atom->segid)) {
       fprintf(stderr, 
-          "PDB: Error encoutered writing atom %d; file may be incomplete.\n", 
+          "PDB: Error encountered writing atom %d; file may be incomplete.\n",
           i+1);
       return MOLFILE_ERROR;
     }
