@@ -15,15 +15,16 @@ You should have received a copy of the GNU Lesser General Public License
 along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "colvar/Colvar.h"
-#include "colvar/ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "core/PlumedMain.h"
 #include "core/ActionWithVirtualAtom.h"
 #include "tools/NeighborList.h"
 #include "tools/SwitchingFunction.h"
-//#include "tools/Tools.h"
 #include "tools/PDB.h"
 #include "tools/Pbc.h"
+#include "tools/Communicator.h"
 #include "tools/Stopwatch.h"
+#include "core/ActionSet.h"
 
 #include <string>
 #include <cmath>
@@ -31,10 +32,8 @@ along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 
 using namespace std;
 
-namespace PLMD
-{
-namespace piv
-{
+namespace PLMD {
+namespace piv {
 
 //+PLUMEDOC PIVMOD_COLVAR PIV
 /*
@@ -182,20 +181,17 @@ When using PIV please cite \cite pipolo2017navigating .
 */
 //+ENDPLUMEDOC
 
-class PIV      : public Colvar
-{
+class PIV      : public Colvar {
 private:
   bool pbc, serial, timer;
   ForwardDecl<Stopwatch> stopwatch_fwd;
-  /// The stopwatch that times the different parts of the calculation
   Stopwatch& stopwatch=*stopwatch_fwd;
   int updatePIV;
-  unsigned Nprec,Natm,Nlist,NLsize;
-  // Fvol: volume scaling factor for distances
+  size_t Nprec;
+  unsigned Natm,Nlist,NLsize;
   double Fvol,Vol0,m_PIVdistance;
   std::string ref_file;
-  // std:: vector<string> atype;
-  NeighborList *nlall;
+  std::unique_ptr<NeighborList> nlall;
   std::vector<SwitchingFunction> sfs;
   std::vector<std:: vector<double> > rPIV;
   std::vector<double> scaling,r00;
@@ -204,16 +200,30 @@ private:
   std::vector<bool> dosort;
   std::vector<Vector> compos;
   std::vector<string> sw;
-  //std::vector<std:: vector<unsigned> > com2atoms;
-  std::vector<NeighborList *> nl;
-  std::vector<NeighborList *> nlcom;
+  std::vector<std::unique_ptr<NeighborList>> nl;
+  std::vector<std::unique_ptr<NeighborList>> nlcom;
   std::vector<Vector> m_deriv;
   Tensor m_virial;
-  bool Svol,Sfac,cross,direct,doneigh,test,CompDer,com;
+  bool Svol,cross,direct,doneigh,test,CompDer,com;
+
+  /// Local structure, used to store data that should be
+  /// shared across multiple PIV instances
+  struct SharedData {
+    int prev_stp=-1;
+    int init_stp=1;
+    std:: vector<std:: vector<Vector> > prev_pos;
+    std:: vector<std:: vector<double> > cPIV;
+    std:: vector<std:: vector<int> > Atom0;
+    std:: vector<std:: vector<int> > Atom1;
+  };
+  /// Owning pointer. Will only be allocated by the first PIV instance
+  std::unique_ptr<SharedData> sharedData_unique;
+  /// Raw pointer. Will have the same value for all PIV instances
+  SharedData* sharedData=nullptr;
+
 public:
   static void registerKeywords( Keywords& keys );
-  PIV(const ActionOptions&);
-  ~PIV();
+  explicit PIV(const ActionOptions&);
   // active methods:
   virtual void calculate();
   void checkFieldsAllowed() {}
@@ -221,15 +231,14 @@ public:
 
 PLUMED_REGISTER_ACTION(PIV,"PIV")
 
-void PIV::registerKeywords( Keywords& keys )
-{
+void PIV::registerKeywords( Keywords& keys ) {
   Colvar::registerKeywords( keys );
   keys.add("numbered","SWITCH","The switching functions parameter."
            "You should specify a Switching function for all PIV blocks."
            "Details of the various switching "
-           "functions you can use are provided on \\ref switchingfunction.");
+           "functions you can use are provided on switchingfunction.");
   keys.add("compulsory","PRECISION","the precision for approximating reals with integers in sorting.");
-  keys.add("compulsory","REF_FILE","PDB file name that contains the \\f$i\\f$th reference structure.");
+  keys.add("compulsory","REF_FILE","PDB file name that contains the ith reference structure.");
   keys.add("compulsory","PIVATOMS","Number of atoms to use for PIV.");
   keys.add("compulsory","SORT","Whether to sort or not the PIV block.");
   keys.add("compulsory","ATOMTYPES","The atom types to use for PIV.");
@@ -248,47 +257,69 @@ void PIV::registerKeywords( Keywords& keys )
   keys.add("optional","NL_STRIDE","Update neighbor lists every NL_STRIDE steps.");
   keys.add("optional","NL_SKIN","The maximum atom displacement tolerated for the neighbor lists update.");
   keys.reset_style("SWITCH","compulsory");
+  keys.setValueDescription("the PIV-distance");
 }
 
 PIV::PIV(const ActionOptions&ao):
   PLUMED_COLVAR_INIT(ao),
   pbc(true),
-  timer(false),
   serial(false),
+  timer(false),
   updatePIV(1),
-  Svol(false),
-  Sfac(false),
-  cross(true),
-  direct(true),
-  doneigh(false),
-  CompDer(false),
-  com(false),
-  test(false),
   Nprec(1000),
   Natm(1),
-  NLsize(1),
   Nlist(1),
+  NLsize(1),
   Fvol(1.),
   Vol0(0.),
   m_PIVdistance(0.),
-  m_deriv(std:: vector<Vector>(1)),
-  nl(std:: vector<NeighborList *>(Nlist)),
   rPIV(std:: vector<std:: vector<double> >(Nlist)),
   scaling(std:: vector<double>(Nlist)),
   r00(std:: vector<double>(Nlist)),
-  sw(std:: vector<string>(Nlist)),
   nl_skin(std:: vector<double>(Nlist)),
   fmass(std:: vector<double>(Nlist)),
   dosort(std:: vector<bool>(Nlist)),
-  nlcom(std:: vector<NeighborList *>(NLsize)),
-  compos(std:: vector<Vector>(NLsize))
-//com2atoms(std:: vector<std:: vector<unsigned> >(Nlist))
-{
+  compos(std:: vector<Vector>(NLsize)),
+  sw(std:: vector<string>(Nlist)),
+  nl(Nlist),
+  nlcom(NLsize),
+  m_deriv(std:: vector<Vector>(1)),
+  Svol(false),
+  cross(true),
+  direct(true),
+  doneigh(false),
+  test(false),
+  CompDer(false),
+  com(false) {
   log << "Starting PIV Constructor\n";
 
+  {
+    // look for another PIV instance previously allocated
+    auto* previous=plumed.getActionSet().selectLatest<PIV*>(this);
+
+    // Uncommenting the following line, it is possible to force
+    // a separate object per instance of the PIB object.
+    // Results are unaffected, but performance is worse.
+    // I think this is the expected behavior. GB
+    // previous=nullptr;
+
+    if(!previous) {
+      // if not found, allocate the shared data struct
+      sharedData_unique=Tools::make_unique<SharedData>();
+      // then set the raw pointer
+      sharedData=sharedData_unique.get();
+    } else {
+      // if found, use the previous raw pointer
+      sharedData=previous->sharedData;
+      log << "(a previous PIV action was found)\n";
+    }
+  }
+
   // Precision on the real-to-integer transformation for the sorting
   parse("PRECISION",Nprec);
-  if(Nprec<2) error("Precision must be => 2");
+  if(Nprec<2) {
+    error("Precision must be => 2");
+  }
 
   // PBC
   bool nopbc=!pbc;
@@ -306,12 +337,13 @@ PIV::PIV(const ActionOptions&ao):
     log << "Serial PIV construction\n";
   } else     {
     log << "Parallel PIV construction\n";
-    unsigned rank=comm.Get_rank();
   }
 
   // Derivatives
   parseFlag("DERIVATIVES",CompDer);
-  if(CompDer) log << "Computing Derivatives\n";
+  if(CompDer) {
+    log << "Computing Derivatives\n";
+  }
 
   // Timing
   parseFlag("TIMER",timer);
@@ -331,7 +363,9 @@ PIV::PIV(const ActionOptions&ao):
 
   // Test
   parseFlag("COM",com);
-  if(com) log << "Building PIV using COMs\n";
+  if(com) {
+    log << "Building PIV using COMs\n";
+  }
 
   // Volume Scaling
   parse("VOLUME",Vol0);
@@ -367,7 +401,7 @@ PIV::PIV(const ActionOptions&ao):
   FILE* fp=fopen(ref_file.c_str(),"r");
   if (fp!=NULL) {
     log<<"Opening PDB file with reference frame: "<<ref_file.c_str()<<"\n";
-    mypdb.readFromFilepointer(fp,plumed.getAtoms().usingNaturalUnits(),0.1/atoms.getUnits().getLength());
+    mypdb.readFromFilepointer(fp,usingNaturalUnits(),0.1/getUnits().getLength());
     fclose (fp);
   } else {
     error("Error in reference PDB file");
@@ -382,9 +416,8 @@ PIV::PIV(const ActionOptions&ao):
   NLsize=mypdb.getAtomNumbers().size();
   // In the following P stands for Point (either an Atom or a COM)
   unsigned resnum=0;
-  unsigned Pnum=0;
   // Presind (array size: number of residues) contains the contains the residue number
-  //   this is because the residue numbers may not alwyas be ordered from 1 to resnum
+  //   this is because the residue numbers may not always be ordered from 1 to resnum
   std:: vector<unsigned> Presind;
   // Build Presind
   for (unsigned i=0; i<mypdb.getAtomNumbers().size(); i++) {
@@ -514,26 +547,32 @@ PIV::PIV(const ActionOptions&ao):
     parseVector("NL_SKIN",nl_skin);
     //if(nl_skin.size()!=getNumberOfArguments() && nl_skin.size()!=0) error("not enough values for NL_SKIN");
     for (unsigned j=0; j<Nlist; j++) {
-      if(nl_cut[j]<=0.0) error("NL_CUTOFF should be explicitly specified and positive");
-      if(nl_st[j]<=0) error("NL_STRIDE should be explicitly specified and positive");
-      if(nl_skin[j]<=0.) error("NL_SKIN should be explicitly specified and positive");
+      if(nl_cut[j]<=0.0) {
+        error("NL_CUTOFF should be explicitly specified and positive");
+      }
+      if(nl_st[j]<=0) {
+        error("NL_STRIDE should be explicitly specified and positive");
+      }
+      if(nl_skin[j]<=0.) {
+        error("NL_SKIN should be explicitly specified and positive");
+      }
       nl_cut[j]=nl_cut[j]+nl_skin[j];
     }
     log << "Creating Neighbor Lists \n";
     // WARNING: is nl_cut meaningful here?
-    nlall= new NeighborList(listall,pbc,getPbc(),nl_cut[0],nl_st[0]);
+    nlall= Tools::make_unique<NeighborList>(listall,true,pbc,getPbc(),comm,nl_cut[0],nl_st[0]);
     if(com) {
       //Build lists of Atoms for every COM
       for (unsigned i=0; i<compos.size(); i++) {
         // WARNING: is nl_cut meaningful here?
-        nlcom[i]= new NeighborList(comatm[i],pbc,getPbc(),nl_cut[0],nl_st[0]);
+        nlcom[i] = Tools::make_unique<NeighborList>(comatm[i],true,pbc,getPbc(),comm,nl_cut[0],nl_st[0]);
       }
     }
     unsigned ncnt=0;
     // Direct blocks AA, BB, CC, ...
     if(direct) {
       for (unsigned j=0; j<Natm; j++) {
-        nl[ncnt]= new NeighborList(Plist[j],pbc,getPbc(),nl_cut[j],nl_st[j]);
+        nl[ncnt]= Tools::make_unique<NeighborList>(Plist[j],true,pbc,getPbc(),comm,nl_cut[j],nl_st[j]);
         ncnt+=1;
       }
     }
@@ -541,16 +580,16 @@ PIV::PIV(const ActionOptions&ao):
     if(cross) {
       for (unsigned j=0; j<Natm; j++) {
         for (unsigned i=j+1; i<Natm; i++) {
-          nl[ncnt]= new NeighborList(Plist[i],Plist[j],false,pbc,getPbc(),nl_cut[ncnt],nl_st[ncnt]);
+          nl[ncnt]= Tools::make_unique<NeighborList>(Plist[i],Plist[j],true,false,pbc,getPbc(),comm,nl_cut[ncnt],nl_st[ncnt]);
           ncnt+=1;
         }
       }
     }
   } else {
     log << "WARNING: Neighbor List not activated this has not been tested!!  \n";
-    nlall= new NeighborList(listall,pbc,getPbc());
+    nlall= Tools::make_unique<NeighborList>(listall,true,pbc,getPbc(),comm);
     for (unsigned j=0; j<Nlist; j++) {
-      nl[j]= new NeighborList(Plist[j],Plist[j],true,pbc,getPbc());
+      nl[j]= Tools::make_unique<NeighborList>(Plist[j],Plist[j],true,true,pbc,getPbc(),comm);
     }
   }
   // Output Nlist
@@ -560,8 +599,6 @@ PIV::PIV(const ActionOptions&ao):
   }
   // Calculate COM masses once and for all from lists
   if(com) {
-    unsigned count=0;
-    //log << "Computing COM masses  \n";
     for(unsigned j=0; j<compos.size(); j++) {
       double commass=0.;
       for(unsigned i=0; i<nlcom[j]->getFullAtomList().size(); i++) {
@@ -614,7 +651,9 @@ PIV::PIV(const ActionOptions&ao):
   r00.resize(Nlist);
   sw.resize(Nlist);
   for (unsigned j=0; j<Nlist; j++) {
-    if( !parseNumbered( "SWITCH", j+1, sw[j] ) ) break;
+    if( !parseNumbered( "SWITCH", j+1, sw[j] ) ) {
+      break;
+    }
   }
   if(CompDer) {
     // Set switching function parameters here only if computing derivatives
@@ -625,19 +664,23 @@ PIV::PIV(const ActionOptions&ao):
     for (unsigned j=0; j<Nlist; j++) {
       if(Svol) {
         double r0;
+        std::string old_r0;
         vector<string> data=Tools::getWords(sw[j]);
         data.erase(data.begin());
-        bool tmp=Tools::parse(data,"R_0",r0);
-        std::string old_r0; Tools::convert(r0,old_r0);
+        Tools::parse(data,"R_0",old_r0);
+        Tools::convert(old_r0,r0);
         r0*=Fvol;
-        std::string new_r0; Tools::convert(r0,new_r0);
+        std::string new_r0;
+        Tools::convert(r0,new_r0);
         std::size_t pos = sw[j].find("R_0");
         sw[j].replace(pos+4,old_r0.size(),new_r0);
       }
       sfs[j].set(sw[j],errors);
       std::string num;
       Tools::convert(j+1, num);
-      if( errors.length()!=0 ) error("problem reading SWITCH" + num + " keyword : " + errors );
+      if( errors.length()!=0 ) {
+        error("problem reading SWITCH" + num + " keyword : " + errors );
+      }
       r00[j]=sfs[j].get_r0();
       log << "  Swf: " << j << "  r0=" << (sfs[j].description()).c_str() << " \n";
     }
@@ -715,34 +758,30 @@ PIV::PIV(const ActionOptions&ao):
   m_deriv.resize(getNumberOfAtoms());
 }
 
-// The following deallocates pointers
-PIV::~PIV()
-{
-  for (unsigned j=0; j<Nlist; j++) {
-    delete nl[j];
-  }
-  if(com) {
-    for (unsigned j=0; j<NLsize; j++) {
-      delete nlcom[j];
-    }
-  }
-  delete nlall;
-}
+void PIV::calculate() {
 
-void PIV::calculate()
-{
+  // Local variables
+
+  if(sharedData_unique) {
+    // This is executed by the first PIV instance.
+    // We initialize variables with the correct Nlist.
+    sharedData_unique->prev_pos.resize(Nlist);
+    sharedData_unique->cPIV.resize(Nlist);
+    sharedData_unique->Atom0.resize(Nlist);
+    sharedData_unique->Atom1.resize(Nlist);
+  }
+
+  // create references to minimize the impact of the code below
+  auto & prev_stp(sharedData->prev_stp);
+  auto & init_stp(sharedData->init_stp);
+  auto & prev_pos(sharedData->prev_pos);
+  auto & cPIV(sharedData->cPIV);
+  auto & Atom0(sharedData->Atom0);
+  auto & Atom1(sharedData->Atom1);
 
-  // Local varaibles
-  // The following are probably needed as static arrays
-  static int prev_stp=-1;
-  static int init_stp=1;
-  static std:: vector<std:: vector<Vector> > prev_pos(Nlist);
-  static std:: vector<std:: vector<double> > cPIV(Nlist);
-  static std:: vector<std:: vector<int> > Atom0(Nlist);
-  static std:: vector<std:: vector<int> > Atom1(Nlist);
   std:: vector<std:: vector<int> > A0(Nprec);
   std:: vector<std:: vector<int> > A1(Nprec);
-  unsigned stride=1;
+  size_t stride=1;
   unsigned rank=0;
 
   if(!serial) {
@@ -755,7 +794,9 @@ void PIV::calculate()
 
   // Transform (and sort) the rPIV before starting the dynamics
   if (((prev_stp==-1) || (init_stp==1)) &&!CompDer) {
-    if(prev_stp!=-1) {init_stp=0;}
+    if(prev_stp!=-1) {
+      init_stp=0;
+    }
     // Calculate the volume scaling factor
     if(Svol) {
       Fvol=cbrt(Vol0/getBox().determinant());
@@ -771,19 +812,23 @@ void PIV::calculate()
     for (unsigned j=0; j<Nlist; j++) {
       if(Svol) {
         double r0;
+        std::string old_r0;
         vector<string> data=Tools::getWords(sw[j]);
         data.erase(data.begin());
-        bool tmp=Tools::parse(data,"R_0",r0);
-        std::string old_r0; Tools::convert(r0,old_r0);
+        Tools::parse(data,"R_0",old_r0);
+        Tools::convert(old_r0,r0);
         r0*=Fvol;
-        std::string new_r0; Tools::convert(r0,new_r0);
+        std::string new_r0;
+        Tools::convert(r0,new_r0);
         std::size_t pos = sw[j].find("R_0");
         sw[j].replace(pos+4,old_r0.size(),new_r0);
       }
       sfs[j].set(sw[j],errors);
       std::string num;
       Tools::convert(j+1, num);
-      if( errors.length()!=0 ) error("problem reading SWITCH" + num + " keyword : " + errors );
+      if( errors.length()!=0 ) {
+        error("problem reading SWITCH" + num + " keyword : " + errors );
+      }
       r00[j]=sfs[j].get_r0();
       log << "  Swf: " << j << "  r0=" << (sfs[j].description()).c_str() << " \n";
     }
@@ -814,11 +859,15 @@ void PIV::calculate()
   }
   // Do the sorting only once per timestep to avoid building the PIV N times for N rPIV PDB structures!
   if ((getStep()>prev_stp&&getStep()%updatePIV==0)||CompDer) {
-    if (CompDer) log << " Step " << getStep() << "  Computing Derivatives NON-SORTED PIV \n";
+    if (CompDer) {
+      log << " Step " << getStep() << "  Computing Derivatives NON-SORTED PIV \n";
+    }
     //
     // build COMs from positions if requested
     if(com) {
-      if(pbc) makeWhole();
+      if(pbc) {
+        makeWhole();
+      }
       for(unsigned j=0; j<compos.size(); j++) {
         compos[j][0]=0.;
         compos[j][1]=0.;
@@ -897,7 +946,9 @@ void PIV::calculate()
         Atom0[j].resize(0);
         Atom1[j].resize(0);
         // Building distances for the PIV vector at time t
-        if(timer) stopwatch.start("1 Build cPIV");
+        if(timer) {
+          stopwatch.start("1 Build cPIV");
+        }
         for(unsigned i=rank; i<nl[j]->size(); i+=stride) {
           unsigned i0=(nl[j]->getClosePairAtomNumber(i).first).index();
           unsigned i1=(nl[j]->getClosePairAtomNumber(i).second).index();
@@ -924,15 +975,19 @@ void PIV::calculate()
           A0[Vint].push_back(i0);
           A1[Vint].push_back(i1);
         }
-        if(timer) stopwatch.stop("1 Build cPIV");
-        if(timer) stopwatch.start("2 Sort cPIV");
+        if(timer) {
+          stopwatch.stop("1 Build cPIV");
+        }
+        if(timer) {
+          stopwatch.start("2 Sort cPIV");
+        }
         if(!doserial && comm.initialized()) {
           // Vectors keeping track of the dimension and the starting-position of the rank-specific pair vector in the big pair vector.
           std:: vector<int> Vdim(stride,0);
           std:: vector<int> Vpos(stride,0);
           // Vectors collecting occupancies: OrdVec one rank, OrdVecAll all ranks
           std:: vector<int> OrdVecAll(stride*Nprec);
-          // Big vectors contining all Atom indexes for every occupancy (Atom0O(Nprec,n) and Atom1O(Nprec,n) matrices in one vector)
+          // Big vectors containing all Atom indexes for every occupancy (Atom0O(Nprec,n) and Atom1O(Nprec,n) matrices in one vector)
           std:: vector<int> Atom0F;
           std:: vector<int> Atom1F;
           // Vector used to reconstruct arrays
@@ -974,22 +1029,26 @@ void PIV::calculate()
           // build big vectors for atom pairs on all ranks for all ranks
           std:: vector<int> Atom0FAll(Fdim);
           std:: vector<int> Atom1FAll(Fdim);
-          // TO BE IMPROVED: Allgathers may be substituded by gathers by proc 0
+          // TO BE IMPROVED: Allgathers may be substituted by gathers by proc 0
           //   Moreover vectors are gathered head-to-tail and assembled later-on in a serial step.
           // Gather the full Ordering Vector (occupancies). This is what we need to build the PIV
           comm.Allgather(&OrdVec[0],Nprec,&OrdVecAll[0],Nprec);
           // Gather the vectors of atom pairs to keep track of the idexes for the forces
-          comm.Allgatherv(&Atom0F[0],Atom0F.size(),&Atom0FAll[0],&Vdim[0],&Vpos[0]);
-          comm.Allgatherv(&Atom1F[0],Atom1F.size(),&Atom1FAll[0],&Vdim[0],&Vpos[0]);
+          comm.Allgatherv(Atom0F.data(),Atom0F.size(),&Atom0FAll[0],&Vdim[0],&Vpos[0]);
+          comm.Allgatherv(Atom1F.data(),Atom1F.size(),&Atom1FAll[0],&Vdim[0],&Vpos[0]);
 
           // Reconstruct the full vectors from collections of Allgathered parts (this is a serial step)
-          // This is the tricky serial step, to assemble toghether PIV and atom-pair info from head-tail big vectors
+          // This is the tricky serial step, to assemble together PIV and atom-pair info from head-tail big vectors
           // Loop before on l and then on i would be better but the allgather should be modified
           // Loop on blocks
           //for(unsigned m=0;m<Nlist;m++) {
           // Loop on Ordering Vector size excluding zeros (i=1)
-          if(timer) stopwatch.stop("2 Sort cPIV");
-          if(timer) stopwatch.start("3 Reconstruct cPIV");
+          if(timer) {
+            stopwatch.stop("2 Sort cPIV");
+          }
+          if(timer) {
+            stopwatch.start("3 Reconstruct cPIV");
+          }
           for(unsigned i=1; i<Nprec; i++) {
             // Loop on the ranks
             for(unsigned l=0; l<stride; l++) {
@@ -1003,7 +1062,9 @@ void PIV::calculate()
               }
             }
           }
-          if(timer) stopwatch.stop("3 Reconstruct cPIV");
+          if(timer) {
+            stopwatch.stop("3 Reconstruct cPIV");
+          }
         } else {
           for(unsigned i=1; i<Nprec; i++) {
             for(unsigned m=0; m<OrdVec[i]; m++) {
@@ -1074,14 +1135,18 @@ void PIV::calculate()
     exit();
   }
 
-  if(timer) stopwatch.start("4 Build For Derivatives");
+  if(timer) {
+    stopwatch.start("4 Build For Derivatives");
+  }
   // non-global variables Nder and Scalevol defined to speedup if structures in cycles
   bool Nder=CompDer;
   bool Scalevol=Svol;
   if(getStep()%updatePIV==0) {
     // set to zero PIVdistance, derivatives and virial when they are calculated
     for(unsigned j=0; j<m_deriv.size(); j++) {
-      for(unsigned k=0; k<3; k++) {m_deriv[j][k]=0.;}
+      for(unsigned k=0; k<3; k++) {
+        m_deriv[j][k]=0.;
+      }
     }
     for(unsigned j=0; j<3; j++) {
       for(unsigned k=0; k<3; k++) {
@@ -1211,21 +1276,27 @@ void PIV::calculate()
     if (!serial && comm.initialized()) {
       comm.Barrier();
       comm.Sum(&m_PIVdistance,1);
-      if(!m_deriv.empty()) comm.Sum(&m_deriv[0][0],3*m_deriv.size());
+      if(!m_deriv.empty()) {
+        comm.Sum(&m_deriv[0][0],3*m_deriv.size());
+      }
       comm.Sum(&m_virial[0][0],9);
     }
   }
   prev_stp=getStep();
 
   //Timing
-  if(timer) stopwatch.stop("4 Build For Derivatives");
+  if(timer) {
+    stopwatch.stop("4 Build For Derivatives");
+  }
   if(timer) {
     log.printf("Timings for action %s with label %s \n", getName().c_str(), getLabel().c_str() );
     log<<stopwatch;
   }
 
   // Update derivatives, virial, and variable (PIV-distance^2)
-  for(unsigned i=0; i<m_deriv.size(); ++i) setAtomsDerivatives(i,m_deriv[i]);
+  for(unsigned i=0; i<m_deriv.size(); ++i) {
+    setAtomsDerivatives(i,m_deriv[i]);
+  }
   setValue           (m_PIVdistance);
   setBoxDerivatives  (m_virial);
 }
