@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -28,8 +28,13 @@ namespace PLMD {
 
 std::string Citations::cite(const std::string & item) {
   unsigned i;
-  for(i=0; i<items.size(); ++i) if(items[i]==item) break;
-  if(i==items.size()) items.push_back(item);
+  for(i=0; i<items.size(); ++i)
+    if(items[i]==item) {
+      break;
+    }
+  if(i==items.size()) {
+    items.push_back(item);
+  }
   plumed_assert(i<items.size());
   std::string ret;
   Tools::convert(i+1,ret);
@@ -38,8 +43,9 @@ std::string Citations::cite(const std::string & item) {
 }
 
 std::ostream & operator<<(std::ostream &log,const Citations&cit) {
-  for(unsigned i=0; i<cit.items.size(); ++i)
+  for(unsigned i=0; i<cit.items.size(); ++i) {
     log<<"  ["<<i+1<<"] "<<cit.items[i]<<"\n";
+  }
   return log;
 }
 
