@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -24,11 +24,18 @@
 #include "AtomNumber.h"
 #include <cstdlib>
 #include <cstring>
-
-using namespace std;
+#include <cstdio>
 
 namespace PLMD {
 
+bool Communicator::plumedHasMPI() {
+#ifdef __PLUMED_HAS_MPI
+  return true;
+#else
+  return false;
+#endif
+}
+
 Communicator::Communicator()
 #ifdef __PLUMED_HAS_MPI
   : communicator(MPI_COMM_SELF)
@@ -52,7 +59,9 @@ Communicator& Communicator::operator=(const Communicator&pc) {
 int Communicator::Get_rank()const {
   int r=0;
 #ifdef __PLUMED_HAS_MPI
-  if(initialized()) MPI_Comm_rank(communicator,&r);
+  if(initialized()) {
+    MPI_Comm_rank(communicator,&r);
+  }
 #endif
   return r;
 }
@@ -60,7 +69,9 @@ int Communicator::Get_rank()const {
 int Communicator::Get_size()const {
   int s=1;
 #ifdef __PLUMED_HAS_MPI
-  if(initialized()) MPI_Comm_size(communicator,&s);
+  if(initialized()) {
+    MPI_Comm_size(communicator,&s);
+  }
 #endif
   return s;
 }
@@ -68,8 +79,12 @@ int Communicator::Get_size()const {
 void Communicator::Set_comm(MPI_Comm c) {
 #ifdef __PLUMED_HAS_MPI
   if(initialized()) {
-    if(communicator!=MPI_COMM_SELF && communicator!=MPI_COMM_WORLD) MPI_Comm_free(&communicator);
-    if(c!=MPI_COMM_SELF) MPI_Comm_dup(c,&communicator);
+    if(communicator!=MPI_COMM_SELF && communicator!=MPI_COMM_WORLD) {
+      MPI_Comm_free(&communicator);
+    }
+    if(c!=MPI_COMM_SELF) {
+      MPI_Comm_dup(c,&communicator);
+    }
   }
 #else
   (void) c;
@@ -78,25 +93,29 @@ void Communicator::Set_comm(MPI_Comm c) {
 
 Communicator::~Communicator() {
 #ifdef __PLUMED_HAS_MPI
-  if(initialized() && communicator!=MPI_COMM_SELF && communicator!=MPI_COMM_WORLD) MPI_Comm_free(&communicator);
+  if(initialized() && communicator!=MPI_COMM_SELF && communicator!=MPI_COMM_WORLD) {
+    MPI_Comm_free(&communicator);
+  }
 #endif
 }
 
-void Communicator::Set_comm(void*val) {
+void Communicator::Set_comm(const TypesafePtr & val) {
 #ifdef __PLUMED_HAS_MPI
   plumed_massert(initialized(),"you are trying to use an MPI function, but MPI is not initialized");
-  if(val) Set_comm(*(MPI_Comm*)val);
+  if(val) {
+    Set_comm(*(const MPI_Comm*)val.get<const void*>());
+  }
 #else
   (void) val;
   plumed_merror("you are trying to use an MPI function, but PLUMED has been compiled without MPI support");
 #endif
 }
 
-void Communicator::Set_fcomm(void*val) {
+void Communicator::Set_fcomm(const TypesafePtr & val) {
 #ifdef __PLUMED_HAS_MPI
   plumed_massert(initialized(),"you are trying to use an MPI function, but MPI is not initialized");
   if(val) {
-    MPI_Comm comm=MPI_Comm_f2c(*(MPI_Fint*)val);
+    MPI_Comm comm=MPI_Comm_f2c(*(const MPI_Fint*)val.get<const void*>());
     Set_comm(comm);
   }
 #else
@@ -110,15 +129,16 @@ void Communicator::Abort(int errorcode) {
   if(initialized()) {
     MPI_Abort(communicator,errorcode);
   }
-  std::exit(errorcode);
-#else
-  std::exit(errorcode);
 #endif
+  std::fprintf(stderr,"aborting with error code %d\n",errorcode);
+  std::abort();
 }
 
 void Communicator::Bcast(Data data,int root) {
 #if defined(__PLUMED_HAS_MPI)
-  if(initialized()) MPI_Bcast(data.pointer,data.size,data.type,root,communicator);
+  if(initialized()) {
+    MPI_Bcast(data.pointer,data.size,data.type,root,communicator);
+  }
 #else
   (void) data;
   (void) root;
@@ -127,7 +147,9 @@ void Communicator::Bcast(Data data,int root) {
 
 void Communicator::Sum(Data data) {
 #if defined(__PLUMED_HAS_MPI)
-  if(initialized()) MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_SUM,communicator);
+  if(initialized()) {
+    MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_SUM,communicator);
+  }
 #else
   (void) data;
 #endif
@@ -135,7 +157,9 @@ void Communicator::Sum(Data data) {
 
 void Communicator::Prod(Data data) {
 #if defined(__PLUMED_HAS_MPI)
-  if(initialized()) MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_PROD,communicator);
+  if(initialized()) {
+    MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_PROD,communicator);
+  }
 #else
   (void) data;
 #endif
@@ -143,7 +167,9 @@ void Communicator::Prod(Data data) {
 
 void Communicator::Max(Data data) {
 #if defined(__PLUMED_HAS_MPI)
-  if(initialized()) MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_MAX,communicator);
+  if(initialized()) {
+    MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_MAX,communicator);
+  }
 #else
   (void) data;
 #endif
@@ -151,7 +177,9 @@ void Communicator::Max(Data data) {
 
 void Communicator::Min(Data data) {
 #if defined(__PLUMED_HAS_MPI)
-  if(initialized()) MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_MIN,communicator);
+  if(initialized()) {
+    MPI_Allreduce(MPI_IN_PLACE,data.pointer,data.size,data.type,MPI_MIN,communicator);
+  }
 #else
   (void) data;
 #endif
@@ -179,7 +207,9 @@ void Communicator::Allgatherv(ConstData in,Data out,const int*recvcounts,const i
   int*di=const_cast<int*>(displs);
 #if defined(__PLUMED_HAS_MPI)
   if(initialized()) {
-    if(s==NULL)s=MPI_IN_PLACE;
+    if(s==NULL) {
+      s=MPI_IN_PLACE;
+    }
     MPI_Allgatherv(s,in.size,in.type,r,rc,di,out.type,communicator);
   } else {
     plumed_assert(in.nbytes==out.nbytes);
@@ -187,7 +217,9 @@ void Communicator::Allgatherv(ConstData in,Data out,const int*recvcounts,const i
     plumed_assert(rc);
     plumed_assert(rc[0]==in.size);
     plumed_assert(di);
-    if(s) std::memcpy(static_cast<char*>(r)+displs[0]*in.nbytes,s,in.size*in.nbytes);
+    if(s) {
+      std::memcpy(static_cast<char*>(r)+displs[0]*in.nbytes,s,size_t(in.size)*in.nbytes);
+    }
   }
 #else
   plumed_assert(in.nbytes==out.nbytes);
@@ -195,7 +227,9 @@ void Communicator::Allgatherv(ConstData in,Data out,const int*recvcounts,const i
   plumed_assert(rc);
   plumed_assert(rc[0]==in.size);
   plumed_assert(di);
-  if(s) std::memcpy(static_cast<char*>(r)+displs[0]*in.nbytes,s,in.size*in.nbytes);
+  if(s) {
+    std::memcpy(static_cast<char*>(r)+displs[0]*in.nbytes,s,size_t(in.size)*in.nbytes);
+  }
 #endif
 }
 
@@ -204,25 +238,34 @@ void Communicator::Allgather(ConstData in,Data out) {
   void*r=const_cast<void*>((const void*)out.pointer);
 #if defined(__PLUMED_HAS_MPI)
   if(initialized()) {
-    if(s==NULL)s=MPI_IN_PLACE;
+    if(s==NULL) {
+      s=MPI_IN_PLACE;
+    }
     MPI_Allgather(s,in.size,in.type,r,out.size/Get_size(),out.type,communicator);
   } else {
     plumed_assert(in.nbytes==out.nbytes);
     plumed_assert(in.size==out.size);
-    if(s) std::memcpy(r,s,in.size*in.nbytes);
+    if(s) {
+      std::memcpy(r,s,size_t(in.size)*in.nbytes);
+    }
   }
 #else
   plumed_assert(in.nbytes==out.nbytes);
   plumed_assert(in.size==out.size);
-  if(s) std::memcpy(r,s,in.size*in.nbytes);
+  if(s) {
+    std::memcpy(r,s,size_t(in.size)*in.nbytes);
+  }
 #endif
 }
 
 void Communicator::Recv(Data data,int source,int tag,Status&status) {
 #ifdef __PLUMED_HAS_MPI
   plumed_massert(initialized(),"you are trying to use an MPI function, but MPI is not initialized");
-  if(&status==&StatusIgnore) MPI_Recv(data.pointer,data.size,data.type,source,tag,communicator,MPI_STATUS_IGNORE);
-  else                       MPI_Recv(data.pointer,data.size,data.type,source,tag,communicator,&status.s);
+  if(&status==&StatusIgnore) {
+    MPI_Recv(data.pointer,data.size,data.type,source,tag,communicator,MPI_STATUS_IGNORE);
+  } else {
+    MPI_Recv(data.pointer,data.size,data.type,source,tag,communicator,&status.s);
+  }
 #else
   (void) data;
   (void) source;
@@ -232,13 +275,11 @@ void Communicator::Recv(Data data,int source,int tag,Status&status) {
 #endif
 }
 
-
-
-
-
 void Communicator::Barrier()const {
 #ifdef __PLUMED_HAS_MPI
-  if(initialized()) MPI_Barrier(communicator);
+  if(initialized()) {
+    MPI_Barrier(communicator);
+  }
 #endif
 }
 
@@ -250,8 +291,11 @@ bool Communicator::initialized() {
 #if defined(__PLUMED_HAS_MPI)
   int flag=0;
   MPI_Initialized(&flag);
-  if(flag) return true;
-  else return false;
+  if(flag) {
+    return true;
+  } else {
+    return false;
+  }
 #endif
   return false;
 }
@@ -259,8 +303,11 @@ bool Communicator::initialized() {
 void Communicator::Request::wait(Status&s) {
 #ifdef __PLUMED_HAS_MPI
   plumed_massert(initialized(),"you are trying to use an MPI function, but MPI is not initialized");
-  if(&s==&StatusIgnore) MPI_Wait(&r,MPI_STATUS_IGNORE);
-  else MPI_Wait(&r,&s.s);
+  if(&s==&StatusIgnore) {
+    MPI_Wait(&r,MPI_STATUS_IGNORE);
+  } else {
+    MPI_Wait(&r,&s.s);
+  }
 #else
   (void) s;
   plumed_merror("you are trying to use an MPI function, but PLUMED has been compiled without MPI support");
@@ -268,26 +315,63 @@ void Communicator::Request::wait(Status&s) {
 }
 
 #ifdef __PLUMED_HAS_MPI
-template<> MPI_Datatype Communicator::getMPIType<float>() { return MPI_FLOAT;}
-template<> MPI_Datatype Communicator::getMPIType<double>() { return MPI_DOUBLE;}
-template<> MPI_Datatype Communicator::getMPIType<int>()   { return MPI_INT;}
-template<> MPI_Datatype Communicator::getMPIType<char>()   { return MPI_CHAR;}
-template<> MPI_Datatype Communicator::getMPIType<unsigned>()   { return MPI_UNSIGNED;}
-template<> MPI_Datatype Communicator::getMPIType<AtomNumber>()   { return MPI_UNSIGNED;}
-template<> MPI_Datatype Communicator::getMPIType<long unsigned>()   { return MPI_UNSIGNED_LONG;}
-template<> MPI_Datatype Communicator::getMPIType<long double>()   { return MPI_LONG_DOUBLE;}
+template<> MPI_Datatype Communicator::getMPIType<float>() {
+  return MPI_FLOAT;
+}
+template<> MPI_Datatype Communicator::getMPIType<double>() {
+  return MPI_DOUBLE;
+}
+template<> MPI_Datatype Communicator::getMPIType<int>()   {
+  return MPI_INT;
+}
+template<> MPI_Datatype Communicator::getMPIType<char>()   {
+  return MPI_CHAR;
+}
+template<> MPI_Datatype Communicator::getMPIType<unsigned>()   {
+  return MPI_UNSIGNED;
+}
+template<> MPI_Datatype Communicator::getMPIType<AtomNumber>()   {
+  return MPI_UNSIGNED;
+}
+template<> MPI_Datatype Communicator::getMPIType<long unsigned>()   {
+  return MPI_UNSIGNED_LONG;
+}
+template<> MPI_Datatype Communicator::getMPIType<long long unsigned>() {
+  return MPI_UNSIGNED_LONG_LONG;
+}
+template<> MPI_Datatype Communicator::getMPIType<long double>()   {
+  return MPI_LONG_DOUBLE;
+}
 #else
-template<> MPI_Datatype Communicator::getMPIType<float>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<double>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<int>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<char>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<unsigned>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<AtomNumber>()   { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<long unsigned>() { return MPI_Datatype();}
-template<> MPI_Datatype Communicator::getMPIType<long double>() { return MPI_Datatype();}
+template<> MPI_Datatype Communicator::getMPIType<float>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<double>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<int>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<char>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<unsigned>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<AtomNumber>()   {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<long unsigned>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<long long unsigned>() {
+  return MPI_Datatype();
+}
+template<> MPI_Datatype Communicator::getMPIType<long double>() {
+  return MPI_Datatype();
+}
 #endif
 
-
 void Communicator::Split(int color,int key,Communicator&pc)const {
 #ifdef __PLUMED_HAS_MPI
   MPI_Comm_split(communicator,color,key,&pc.communicator);
