@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -47,7 +47,9 @@ FileBase& FileBase::link(FILE*fp) {
 }
 
 FileBase& FileBase::flush() {
-  if(fp) fflush(fp);
+  if(fp) {
+    fflush(fp);
+  }
   return *this;
 }
 
@@ -75,20 +77,36 @@ bool FileBase::FileExist(const std::string& path) {
   bool do_exist=false;
   this->path=appendSuffix(path,getSuffix());
   mode="r";
+  // first try with suffix
   FILE *ff=std::fopen(const_cast<char*>(this->path.c_str()),"r");
+// call fclose when ff goes out of scope
+  auto deleter=[](auto f) {
+    if(f) {
+      std::fclose(f);
+    }
+  };
+  std::unique_ptr<FILE,decltype(deleter)> fp_deleter(ff,deleter);
+
   if(!ff) {
     this->path=path;
+    // then try without suffic
     ff=std::fopen(const_cast<char*>(this->path.c_str()),"r");
     mode="r";
   }
-  if(ff) {do_exist=true; fclose(ff);}
-  if(comm) comm->Barrier();
+  if(ff) {
+    do_exist=true;
+  }
+  if(comm) {
+    comm->Barrier();
+  }
   return do_exist;
 }
 
 bool FileBase::isOpen() {
   bool isopen=false;
-  if(fp) isopen=true;
+  if(fp) {
+    isopen=true;
+  }
   return isopen;
 }
 
@@ -96,9 +114,13 @@ void        FileBase::close() {
   plumed_assert(!cloned);
   eof=false;
   err=false;
-  if(fp)   std::fclose(fp);
+  if(fp) {
+    std::fclose(fp);
+  }
 #ifdef __PLUMED_HAS_ZLIB
-  if(gzfp) gzclose(gzFile(gzfp));
+  if(gzfp) {
+    gzclose(gzFile(gzfp));
+  }
 #endif
   fp=NULL;
   gzfp=NULL;
@@ -114,16 +136,20 @@ FileBase::FileBase():
   eof(false),
   err(false),
   heavyFlush(false),
-  enforcedSuffix_(false)
-{
+  enforcedSuffix_(false) {
 }
 
-FileBase::~FileBase()
-{
-  if(plumed) plumed->eraseFile(*this);
-  if(!cloned && fp)   fclose(fp);
+FileBase::~FileBase() {
+  if(plumed) {
+    plumed->eraseFile(*this);
+  }
+  if(!cloned && fp) {
+    std::fclose(fp);
+  }
 #ifdef __PLUMED_HAS_ZLIB
-  if(!cloned && gzfp) gzclose(gzFile(gzfp));
+  if(!cloned && gzfp) {
+    gzclose(gzFile(gzfp));
+  }
 #endif
 }
 
@@ -132,7 +158,9 @@ FileBase::operator bool()const {
 }
 
 std::string FileBase::appendSuffix(const std::string&path,const std::string&suffix) {
-  if(path=="/dev/null") return path; // do not append a suffix to /dev/null
+  if(path=="/dev/null") {
+    return path;  // do not append a suffix to /dev/null
+  }
   std::string ret=path;
   std::string ext=Tools::extension(path);
 
@@ -147,10 +175,12 @@ std::string FileBase::appendSuffix(const std::string&path,const std::string&suff
   if(ext.length()>0) {
     int l=path.length()-(ext.length()+1);
     plumed_assert(l>=0);
-    ret=ret.substr(0,l);
+    ret.resize(l);
   }
   ret+=suffix;
-  if(ext.length()>0)ret+="."+ext;
+  if(ext.length()>0) {
+    ret+="."+ext;
+  }
   return ret;
 }
 
@@ -161,8 +191,12 @@ FileBase& FileBase::enforceSuffix(const std::string&suffix) {
 }
 
 std::string FileBase::getSuffix()const {
-  if(enforcedSuffix_) return enforcedSuffix;
-  if(plumed) return plumed->getSuffix();
+  if(enforcedSuffix_) {
+    return enforcedSuffix;
+  }
+  if(plumed) {
+    return plumed->getSuffix();
+  }
   return "";
 }
 
