@@ -1,8 +1,8 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2014 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
-   See http://www.plumed-code.org for more information.
+   See http://www.plumed.org for more information.
 
    This file is part of plumed, version 2.
 
@@ -24,7 +24,7 @@
 
 #include "OFile.h"
 
-namespace PLMD{
+namespace PLMD {
 
 /// Class containing the log stream.
 ///
@@ -33,8 +33,7 @@ namespace PLMD{
 /// lines with the "PLUMED:" prefix, useful to grep out plumed
 /// log from output
 class Log :
-  public OFile
-{
+  public OFile {
 };
 
 }
