@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2013-2020 The plumed team
+   Copyright (c) 2013-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -27,134 +27,269 @@
 namespace PLMD {
 
 unsigned MolDataClass::numberOfAtomsPerResidueInBackbone( const std::string& type ) {
-  if( type=="protein" ) return 5;
-  else if( type=="dna" ) return 6;
-  else if( type=="rna" ) return 6;
-  else return 0;
+  if( type=="protein" ) {
+    return 5;
+  } else if( type=="dna" ) {
+    return 6;
+  } else if( type=="rna" ) {
+    return 6;
+  } else {
+    return 0;
+  }
 }
 
 bool MolDataClass::allowedResidue( const std::string& type, const std::string& residuename ) {
   if( type=="protein" ) {
-    if(residuename=="ALA") return true;
-    else if(residuename=="ARG") return true;
-    else if(residuename=="ASN") return true;
-    else if(residuename=="ASP") return true;
-    else if(residuename=="CYS") return true;
-    else if(residuename=="GLN") return true;
-    else if(residuename=="GLU") return true;
-    else if(residuename=="GLY") return true;
-    else if(residuename=="HIS") return true;
-    else if(residuename=="ILE") return true;
-    else if(residuename=="LEU") return true;
-    else if(residuename=="LYS") return true;
-    else if(residuename=="MET") return true;
-    else if(residuename=="PHE") return true;
-    else if(residuename=="PRO") return true;
-    else if(residuename=="SER") return true;
-    else if(residuename=="THR") return true;
-    else if(residuename=="TRP") return true;
-    else if(residuename=="TYR") return true;
-    else if(residuename=="VAL") return true;
+    if(residuename=="ALA") {
+      return true;
+    } else if(residuename=="ARG") {
+      return true;
+    } else if(residuename=="ASN") {
+      return true;
+    } else if(residuename=="ASP") {
+      return true;
+    } else if(residuename=="CYS") {
+      return true;
+    } else if(residuename=="GLN") {
+      return true;
+    } else if(residuename=="GLU") {
+      return true;
+    } else if(residuename=="GLY") {
+      return true;
+    } else if(residuename=="HIS") {
+      return true;
+    } else if(residuename=="ILE") {
+      return true;
+    } else if(residuename=="LEU") {
+      return true;
+    } else if(residuename=="LYS") {
+      return true;
+    } else if(residuename=="MET") {
+      return true;
+    } else if(residuename=="PHE") {
+      return true;
+    } else if(residuename=="PRO") {
+      return true;
+    } else if(residuename=="SER") {
+      return true;
+    } else if(residuename=="THR") {
+      return true;
+    } else if(residuename=="TRP") {
+      return true;
+    } else if(residuename=="TYR") {
+      return true;
+    } else if(residuename=="VAL") {
+      return true;
+    }
 // Terminal groups
-    else if(residuename=="ACE") return true;
-    else if(residuename=="NME") return true;
-    else if(residuename=="NH2") return true;
-// Alternative residue names in common force fiels
-    else if(residuename=="GLH") return true; // neutral GLU
-    else if(residuename=="ASH") return true; // neutral ASP
-    else if(residuename=="HID") return true; // HIS-D amber
-    else if(residuename=="HSD") return true; // HIS-D charmm
-    else if(residuename=="HIE") return true; // HIS-E amber
-    else if(residuename=="HSE") return true; // HIS-E charmm
-    else if(residuename=="HIP") return true; // HIS-P amber
-    else if(residuename=="HSP") return true; // HIS-P charmm
+    else if(residuename=="ACE") {
+      return true;
+    } else if(residuename=="NME") {
+      return true;
+    } else if(residuename=="NH2") {
+      return true;
+    }
+// Alternative residue names in common force fields
+    else if(residuename=="GLH") {
+      return true;  // neutral GLU
+    } else if(residuename=="ASH") {
+      return true;  // neutral ASP
+    } else if(residuename=="HID") {
+      return true;  // HIS-D amber
+    } else if(residuename=="HSD") {
+      return true;  // HIS-D charmm
+    } else if(residuename=="HIE") {
+      return true;  // HIS-E amber
+    } else if(residuename=="HSE") {
+      return true;  // HIS-E charmm
+    } else if(residuename=="HIP") {
+      return true;  // HIS-P amber
+    } else if(residuename=="HSP") {
+      return true;  // HIS-P charmm
+    }
 // Weird amino acids
-    else if(residuename=="NLE") return true;
-    else if(residuename=="SFO") return true;
-    else return false;
+    else if(residuename=="NLE") {
+      return true;
+    } else if(residuename=="SFO") {
+      return true;
+    } else {
+      return false;
+    }
   } else if( type=="dna" ) {
-    if(residuename=="A") return true;
-    else if(residuename=="A5") return true;
-    else if(residuename=="A3") return true;
-    else if(residuename=="AN") return true;
-    else if(residuename=="G") return true;
-    else if(residuename=="G5") return true;
-    else if(residuename=="G3") return true;
-    else if(residuename=="GN") return true;
-    else if(residuename=="T") return true;
-    else if(residuename=="T5") return true;
-    else if(residuename=="T3") return true;
-    else if(residuename=="TN") return true;
-    else if(residuename=="C") return true;
-    else if(residuename=="C5") return true;
-    else if(residuename=="C3") return true;
-    else if(residuename=="CN") return true;
-    else if(residuename=="DA") return true;
-    else if(residuename=="DA5") return true;
-    else if(residuename=="DA3") return true;
-    else if(residuename=="DAN") return true;
-    else if(residuename=="DG") return true;
-    else if(residuename=="DG5") return true;
-    else if(residuename=="DG3") return true;
-    else if(residuename=="DGN") return true;
-    else if(residuename=="DT") return true;
-    else if(residuename=="DT5") return true;
-    else if(residuename=="DT3") return true;
-    else if(residuename=="DTN") return true;
-    else if(residuename=="DC") return true;
-    else if(residuename=="DC5") return true;
-    else if(residuename=="DC3") return true;
-    else if(residuename=="DCN") return true;
-    else return false;
+    if(residuename=="A") {
+      return true;
+    } else if(residuename=="A5") {
+      return true;
+    } else if(residuename=="A3") {
+      return true;
+    } else if(residuename=="AN") {
+      return true;
+    } else if(residuename=="G") {
+      return true;
+    } else if(residuename=="G5") {
+      return true;
+    } else if(residuename=="G3") {
+      return true;
+    } else if(residuename=="GN") {
+      return true;
+    } else if(residuename=="T") {
+      return true;
+    } else if(residuename=="T5") {
+      return true;
+    } else if(residuename=="T3") {
+      return true;
+    } else if(residuename=="TN") {
+      return true;
+    } else if(residuename=="C") {
+      return true;
+    } else if(residuename=="C5") {
+      return true;
+    } else if(residuename=="C3") {
+      return true;
+    } else if(residuename=="CN") {
+      return true;
+    } else if(residuename=="DA") {
+      return true;
+    } else if(residuename=="DA5") {
+      return true;
+    } else if(residuename=="DA3") {
+      return true;
+    } else if(residuename=="DAN") {
+      return true;
+    } else if(residuename=="DG") {
+      return true;
+    } else if(residuename=="DG5") {
+      return true;
+    } else if(residuename=="DG3") {
+      return true;
+    } else if(residuename=="DGN") {
+      return true;
+    } else if(residuename=="DT") {
+      return true;
+    } else if(residuename=="DT5") {
+      return true;
+    } else if(residuename=="DT3") {
+      return true;
+    } else if(residuename=="DTN") {
+      return true;
+    } else if(residuename=="DC") {
+      return true;
+    } else if(residuename=="DC5") {
+      return true;
+    } else if(residuename=="DC3") {
+      return true;
+    } else if(residuename=="DCN") {
+      return true;
+    } else {
+      return false;
+    }
   } else if( type=="rna" ) {
-    if(residuename=="A") return true;
-    else if(residuename=="A5") return true;
-    else if(residuename=="A3") return true;
-    else if(residuename=="AN") return true;
-    else if(residuename=="G") return true;
-    else if(residuename=="G5") return true;
-    else if(residuename=="G3") return true;
-    else if(residuename=="GN") return true;
-    else if(residuename=="U") return true;
-    else if(residuename=="U5") return true;
-    else if(residuename=="U3") return true;
-    else if(residuename=="UN") return true;
-    else if(residuename=="C") return true;
-    else if(residuename=="C5") return true;
-    else if(residuename=="C3") return true;
-    else if(residuename=="CN") return true;
-    else if(residuename=="RA") return true;
-    else if(residuename=="RA5") return true;
-    else if(residuename=="RA3") return true;
-    else if(residuename=="RAN") return true;
-    else if(residuename=="RG") return true;
-    else if(residuename=="RG5") return true;
-    else if(residuename=="RG3") return true;
-    else if(residuename=="RGN") return true;
-    else if(residuename=="RU") return true;
-    else if(residuename=="RU5") return true;
-    else if(residuename=="RU3") return true;
-    else if(residuename=="RUN") return true;
-    else if(residuename=="RC") return true;
-    else if(residuename=="RC5") return true;
-    else if(residuename=="RC3") return true;
-    else if(residuename=="RCN") return true;
-    else return false;
+    if(residuename=="A") {
+      return true;
+    } else if(residuename=="A5") {
+      return true;
+    } else if(residuename=="A3") {
+      return true;
+    } else if(residuename=="AN") {
+      return true;
+    } else if(residuename=="G") {
+      return true;
+    } else if(residuename=="G5") {
+      return true;
+    } else if(residuename=="G3") {
+      return true;
+    } else if(residuename=="GN") {
+      return true;
+    } else if(residuename=="U") {
+      return true;
+    } else if(residuename=="U5") {
+      return true;
+    } else if(residuename=="U3") {
+      return true;
+    } else if(residuename=="UN") {
+      return true;
+    } else if(residuename=="C") {
+      return true;
+    } else if(residuename=="C5") {
+      return true;
+    } else if(residuename=="C3") {
+      return true;
+    } else if(residuename=="CN") {
+      return true;
+    } else if(residuename=="RA") {
+      return true;
+    } else if(residuename=="RA5") {
+      return true;
+    } else if(residuename=="RA3") {
+      return true;
+    } else if(residuename=="RAN") {
+      return true;
+    } else if(residuename=="RG") {
+      return true;
+    } else if(residuename=="RG5") {
+      return true;
+    } else if(residuename=="RG3") {
+      return true;
+    } else if(residuename=="RGN") {
+      return true;
+    } else if(residuename=="RU") {
+      return true;
+    } else if(residuename=="RU5") {
+      return true;
+    } else if(residuename=="RU3") {
+      return true;
+    } else if(residuename=="RUN") {
+      return true;
+    } else if(residuename=="RC") {
+      return true;
+    } else if(residuename=="RC5") {
+      return true;
+    } else if(residuename=="RC3") {
+      return true;
+    } else if(residuename=="RCN") {
+      return true;
+    } else {
+      return false;
+    }
   } else if( type=="water" ) {
-    if(residuename=="SOL") return true;
-    if(residuename=="WAT") return true;
+    if(residuename=="SOL") {
+      return true;
+    }
+    if(residuename=="WAT") {
+      return true;
+    }
     return false;
   } else if( type=="ion" ) {
-    if(residuename=="IB+") return true;
-    if(residuename=="CA") return true;
-    if(residuename=="CL") return true;
-    if(residuename=="NA") return true;
-    if(residuename=="MG") return true;
-    if(residuename=="K") return true;
-    if(residuename=="RB") return true;
-    if(residuename=="CS") return true;
-    if(residuename=="LI") return true;
-    if(residuename=="ZN") return true;
+    if(residuename=="IB+") {
+      return true;
+    }
+    if(residuename=="CA") {
+      return true;
+    }
+    if(residuename=="CL") {
+      return true;
+    }
+    if(residuename=="NA") {
+      return true;
+    }
+    if(residuename=="MG") {
+      return true;
+    }
+    if(residuename=="K") {
+      return true;
+    }
+    if(residuename=="RB") {
+      return true;
+    }
+    if(residuename=="CS") {
+      return true;
+    }
+    if(residuename=="LI") {
+      return true;
+    }
+    if(residuename=="ZN") {
+      return true;
+    }
     return false;
   }
   return false;
@@ -193,18 +328,22 @@ void MolDataClass::getBackboneForResidue( const std::string& type, const unsigne
     atoms[3]=mypdb.getNamedAtomFromResidue("C4\'",residuenum);
     atoms[4]=mypdb.getNamedAtomFromResidue("C3\'",residuenum);
     atoms[5]=mypdb.getNamedAtomFromResidue("O3\'",residuenum);
-  }
-  else {
+  } else {
     plumed_merror(type + " is not a valid molecule type");
   }
 }
 
 bool MolDataClass::isTerminalGroup( const std::string& type, const std::string& residuename ) {
   if( type=="protein" ) {
-    if( residuename=="ACE" ) return true;
-    else if( residuename=="NME" ) return true;
-    else if( residuename=="NH2" ) return true;
-    else return false;
+    if( residuename=="ACE" ) {
+      return true;
+    } else if( residuename=="NME" ) {
+      return true;
+    } else if( residuename=="NH2" ) {
+      return true;
+    } else {
+      return false;
+    }
   } else {
     plumed_merror(type + " is not a valid molecule type");
   }
@@ -226,7 +365,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
       for(auto a : all) {
         auto resname=mypdb.getResidueName(a);
         Tools::stripLeadingAndTrailingBlanks(resname);
-        if(allowedResidue("protein",resname)) numbers.push_back(a);
+        if(allowedResidue("protein",resname)) {
+          numbers.push_back(a);
+        }
       }
       return;
     }
@@ -236,7 +377,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
       for(auto a : all) {
         auto resname=mypdb.getResidueName(a);
         Tools::stripLeadingAndTrailingBlanks(resname);
-        if(allowedResidue("dna",resname) || allowedResidue("rna",resname)) numbers.push_back(a);
+        if(allowedResidue("dna",resname) || allowedResidue("rna",resname)) {
+          numbers.push_back(a);
+        }
       }
       return;
     }
@@ -246,7 +389,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
       for(auto a : all) {
         auto resname=mypdb.getResidueName(a);
         Tools::stripLeadingAndTrailingBlanks(resname);
-        if(allowedResidue("ion",resname)) numbers.push_back(a);
+        if(allowedResidue("ion",resname)) {
+          numbers.push_back(a);
+        }
       }
       return;
     }
@@ -256,7 +401,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
       for(auto a : all) {
         auto resname=mypdb.getResidueName(a);
         Tools::stripLeadingAndTrailingBlanks(resname);
-        if(allowedResidue("water",resname)) numbers.push_back(a);
+        if(allowedResidue("water",resname)) {
+          numbers.push_back(a);
+        }
       }
       return;
     }
@@ -267,7 +414,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         auto atomname=mypdb.getAtomName(a);
         Tools::stripLeadingAndTrailingBlanks(atomname);
         auto notnumber=atomname.find_first_not_of("0123456789");
-        if(notnumber!=std::string::npos && atomname[notnumber]=='H') numbers.push_back(a);
+        if(notnumber!=std::string::npos && atomname[notnumber]=='H') {
+          numbers.push_back(a);
+        }
       }
       return;
     }
@@ -278,14 +427,18 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         auto atomname=mypdb.getAtomName(a);
         Tools::stripLeadingAndTrailingBlanks(atomname);
         auto notnumber=atomname.find_first_not_of("0123456789");
-        if(!(notnumber!=std::string::npos && atomname[notnumber]=='H')) numbers.push_back(a);
+        if(!(notnumber!=std::string::npos && atomname[notnumber]=='H')) {
+          numbers.push_back(a);
+        }
       }
       return;
     }
 
 
     std::size_t dash=symbol.find_first_of('-');
-    if(dash==std::string::npos) plumed_error() << "Unrecognized symbol "<<symbol;
+    if(dash==std::string::npos) {
+      plumed_error() << "Unrecognized symbol "<<symbol;
+    }
 
     std::size_t firstunderscore=symbol.find_first_of('_',dash+1);
     std::size_t firstnum=symbol.find_first_of("0123456789",dash+1);
@@ -318,12 +471,14 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N",resnum+1,chainid));
       } else if( name=="omega" && !isTerminalGroup("protein",resname) ) {
+        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CA",resnum-1,chainid));
+        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C",resnum-1,chainid));
+        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CA",resnum,chainid));
-        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C",resnum,chainid));
-        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N",resnum+1,chainid));
-        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CA",resnum+1,chainid));
       } else if( name=="chi1" && !isTerminalGroup("protein",resname) ) {
-        if ( resname=="GLY" || resname=="ALA" || resname=="SFO" ) plumed_merror("chi-1 is not defined for ALA, GLY and SFO");
+        if ( resname=="GLY" || resname=="ALA" || resname=="SFO" ) {
+          plumed_merror("chi-1 is not defined for ALA, GLY and SFO");
+        }
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CA",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CB",resnum,chainid));
@@ -340,7 +495,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         }
       } else if( name=="chi2" && !isTerminalGroup("protein",resname) ) {
         if ( resname=="GLY" || resname=="ALA" || resname=="SFO" || resname=="CYS" || resname=="SER" ||
-             resname=="THR" || resname=="VAL" ) plumed_merror("chi-2 is not defined for ALA, GLY, CYS, SER, THR, VAL and SFO");
+             resname=="THR" || resname=="VAL" ) {
+          plumed_merror("chi-2 is not defined for ALA, GLY, CYS, SER, THR, VAL and SFO");
+        }
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CA",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CB",resnum,chainid));
 
@@ -362,7 +519,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         }
       } else if( name=="chi3" && !isTerminalGroup("protein",resname) ) {
         if (!( resname=="ARG" || resname=="GLN" || resname=="GLU" || resname=="LYS" ||
-               resname=="MET" )) plumed_merror("chi-3 is defined only for ARG, GLN, GLU, LYS and MET");
+               resname=="MET" )) {
+          plumed_merror("chi-3 is defined only for ARG, GLN, GLU, LYS and MET");
+        }
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CB",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CG",resnum,chainid));
 
@@ -379,7 +538,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("NE",resnum,chainid));
         }
       } else if( name=="chi4" && !isTerminalGroup("protein",resname) ) {
-        if (!( resname=="ARG" || resname=="LYS" )) plumed_merror("chi-4 is defined only for ARG and LYS");
+        if (!( resname=="ARG" || resname=="LYS" )) {
+          plumed_merror("chi-4 is defined only for ARG and LYS");
+        }
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CG",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CD",resnum,chainid));
 
@@ -391,13 +552,17 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("NZ",resnum,chainid));
         }
       } else if( name=="chi5" && !isTerminalGroup("protein",resname) ) {
-        if (!( resname=="ARG" )) plumed_merror("chi-5 is defined only for ARG");
+        if (!( resname=="ARG" )) {
+          plumed_merror("chi-5 is defined only for ARG");
+        }
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CD",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("NE",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("CZ",resnum,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("NH1",resnum,chainid));
       } else if( name=="sidechain" && !isTerminalGroup("protein",resname) ) {
-        if(resname=="GLY") plumed_merror("sidechain is not defined for GLY");
+        if(resname=="GLY") {
+          plumed_merror("sidechain is not defined for GLY");
+        }
         std::vector<AtomNumber> tmpnum1(mypdb.getAtomsInResidue(resnum,chainid));
         for(unsigned i=0; i<tmpnum1.size(); i++) {
           if(mypdb.getAtomName(tmpnum1[i])!="N"&&mypdb.getAtomName(tmpnum1[i])!="CA"&&
@@ -426,15 +591,27 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
             numbers.push_back( tmpnum1[i] );
           }
         }
-      } else numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
+      } else {
+        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
+      }
 
     } else if( allowedResidue("rna",resname) || allowedResidue("dna",resname)) {
       std::string basetype;
-      if(resname.find_first_of("A")!=std::string::npos) basetype+="A";
-      if(resname.find_first_of("U")!=std::string::npos) basetype+="U";
-      if(resname.find_first_of("T")!=std::string::npos) basetype+="T";
-      if(resname.find_first_of("C")!=std::string::npos) basetype+="C";
-      if(resname.find_first_of("G")!=std::string::npos) basetype+="G";
+      if(resname.find_first_of("A")!=std::string::npos) {
+        basetype+="A";
+      }
+      if(resname.find_first_of("U")!=std::string::npos) {
+        basetype+="U";
+      }
+      if(resname.find_first_of("T")!=std::string::npos) {
+        basetype+="T";
+      }
+      if(resname.find_first_of("C")!=std::string::npos) {
+        basetype+="C";
+      }
+      if(resname.find_first_of("G")!=std::string::npos) {
+        basetype+="G";
+      }
       plumed_massert(basetype.length()==1,"cannot find type of rna/dna residue "+resname+" "+basetype);
       if( name=="chi" ) {
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("O4\'",resnum,chainid));
@@ -445,7 +622,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         } else if(basetype=="G" || basetype=="A") {
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N9",resnum,chainid));
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C4",resnum,chainid));
-        } else plumed_error();
+        } else {
+          plumed_error();
+        }
       } else if( name=="alpha" ) {
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("O3\'",resnum-1,chainid));
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("P",resnum,chainid));
@@ -566,7 +745,9 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C5",resnum,chainid));
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("N7",resnum,chainid));
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C8",resnum,chainid));
-        } else plumed_error();
+        } else {
+          plumed_error();
+        }
       } else if( name=="lcs" ) {
         numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C2",resnum,chainid));
         if(basetype=="T" || basetype=="U" || basetype=="C") {
@@ -575,11 +756,16 @@ void MolDataClass::specialSymbol( const std::string& type, const std::string& sy
         } else if(basetype=="G" || basetype=="A") {
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C6",resnum,chainid));
           numbers.push_back(mypdb.getNamedAtomFromResidueAndChain("C4",resnum,chainid));
-        } else plumed_error();
-      } else numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
-    } else numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
-  }
-  else {
+        } else {
+          plumed_error();
+        }
+      } else {
+        numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
+      }
+    } else {
+      numbers.push_back(mypdb.getNamedAtomFromResidueAndChain(name,resnum,chainid));
+    }
+  } else {
     plumed_merror(type + " is not a valid molecule type");
   }
 }
