@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -45,9 +45,13 @@ namespace PLMD {
 
 size_t OFile::llwrite(const char*ptr,size_t s) {
   size_t r;
-  if(linked) return linked->llwrite(ptr,s);
+  if(linked) {
+    return linked->llwrite(ptr,s);
+  }
   if(! (comm && comm->Get_rank()>0)) {
-    if(!fp) plumed_merror("writing on uninitialized File");
+    if(!fp) {
+      plumed_merror("writing on uninitialized File");
+    }
     if(gzfp) {
 #ifdef __PLUMED_HAS_ZLIB
       r=gzwrite(gzFile(gzfp),ptr,s);
@@ -58,16 +62,17 @@ size_t OFile::llwrite(const char*ptr,size_t s) {
       r=std::fwrite(ptr,1,s,fp);
     }
   }
+  if(comm) {
 //  This barrier is apparently useless since it comes
 //  just before a Bcast.
 //
 //  Anyway, it looks like it is solving an issue that appeared on
 //  TRAVIS (at least on my laptop) so I add it here.
 //  GB
-  if(comm) comm->Barrier();
+    comm->Barrier();
+    comm->Bcast(r,0);
+  }
 
-
-  if(comm) comm->Bcast(r,0);
   return r;
 }
 
@@ -76,17 +81,17 @@ OFile::OFile():
   fieldChanged(false),
   backstring("bck"),
   enforceRestart_(false),
-  enforceBackup_(false)
-{
+  enforceBackup_(false) {
   fmtField();
   buflen=1;
   actual_buffer_length=0;
-  buffer=Tools::make_unique<char[]>(buflen);
+  buffer.resize(buflen);
 // these are set to zero to avoid valgrind errors
-  for(int i=0; i<buflen; ++i) buffer[i]=0;
-  buffer_string=Tools::make_unique<char[]>(1000);
+  for(int i=0; i<buflen; ++i) {
+    buffer[i]=0;
+  }
 // these are set to zero to avoid valgrind errors
-  for(unsigned i=0; i<1000; ++i) buffer_string[i]=0;
+  buffer_string.resize(1000,0);
 }
 
 OFile& OFile::link(OFile&l) {
@@ -108,11 +113,15 @@ int OFile::printf(const char*fmt,...) {
   va_end(arg);
   if(r>=buflen-actual_buffer_length) {
     int newlen=buflen;
-    while(newlen<=r+actual_buffer_length) newlen*=2;
-    auto newbuf=Tools::make_unique<char[]>(newlen);
-    std::memmove(newbuf.get(),buffer.get(),buflen);
-    for(int k=buflen; k<newlen; k++) newbuf[k]=0;
-    buffer=std::move(newbuf);
+    while(newlen<=r+actual_buffer_length) {
+      newlen*=2;
+    }
+    std::vector<char> newbuf(newlen);
+    std::memmove(newbuf.data(),buffer.data(),buflen);
+    for(int k=buflen; k<newlen; k++) {
+      newbuf[k]=0;
+    }
+    std::swap(buffer,newbuf);
     buflen=newlen;
     va_list arg;
     va_start(arg, fmt);
@@ -122,19 +131,23 @@ int OFile::printf(const char*fmt,...) {
   plumed_massert(r>-1 && r<buflen-actual_buffer_length,"error using fmt string " + std::string(fmt));
 
 // Line is buffered until newline, then written with a PLUMED: prefix
-  char*p1=buffer.get();
+  char*p1=buffer.data();
   char*p2;
 // newline is only searched in the just added portion:
   char*psearch=p1+actual_buffer_length;
   actual_buffer_length+=r;
   while((p2=std::strchr(psearch,'\n'))) {
-    if(linePrefix.length()>0) llwrite(linePrefix.c_str(),linePrefix.length());
+    if(linePrefix.length()>0) {
+      llwrite(linePrefix.c_str(),linePrefix.length());
+    }
     llwrite(p1,p2-p1+1);
     actual_buffer_length-=(p2-p1)+1;
     p1=p2+1;
     psearch=p1;
   };
-  if(buffer.get()!=p1) std::memmove(buffer.get(),p1,actual_buffer_length);
+  if(buffer.data()!=p1) {
+    std::memmove(buffer.data(),p1,actual_buffer_length);
+  }
   return r;
 }
 
@@ -167,46 +180,65 @@ OFile& OFile::printField(const std::string&name,double v) {
 // When one tries to print -nan we print nan instead.
 // The distinction between +nan and -nan is not well defined
 // Always printing nan simplifies some regtest (special functions computed our of range).
-  if(std::isnan(v)) v=std::numeric_limits<double>::quiet_NaN();
-  std::sprintf(buffer_string.get(),fieldFmt.c_str(),v);
-  printField(name,buffer_string.get());
+  if(std::isnan(v)) {
+    v=std::numeric_limits<double>::quiet_NaN();
+  }
+  std::snprintf(buffer_string.data(),buffer_string.size(),fieldFmt.c_str(),v);
+  printField(name,buffer_string.data());
   return *this;
 }
 
 OFile& OFile::printField(const std::string&name,int v) {
-  std::sprintf(buffer_string.get()," %d",v);
-  printField(name,buffer_string.get());
+  std::snprintf(buffer_string.data(),buffer_string.size()," %d",v);
+  printField(name,buffer_string.data());
   return *this;
 }
 
 OFile& OFile::printField(const std::string&name,long int v) {
-  std::sprintf(buffer_string.get()," %ld",v);
-  printField(name,buffer_string.get());
+  std::snprintf(buffer_string.data(),buffer_string.size()," %ld",v);
+  printField(name,buffer_string.data());
+  return *this;
+}
+
+OFile& OFile::printField(const std::string&name,long long int v) {
+  std::snprintf(buffer_string.data(),buffer_string.size()," %lld",v);
+  printField(name,buffer_string.data());
   return *this;
 }
 
 OFile& OFile::printField(const std::string&name,unsigned v) {
-  std::sprintf(buffer_string.get()," %u",v);
-  printField(name,buffer_string.get());
+  std::snprintf(buffer_string.data(),buffer_string.size()," %u",v);
+  printField(name,buffer_string.data());
   return *this;
 }
 
 OFile& OFile::printField(const std::string&name,long unsigned v) {
-  std::sprintf(buffer_string.get()," %lu",v);
-  printField(name,buffer_string.get());
+  std::snprintf(buffer_string.data(),buffer_string.size()," %lu",v);
+  printField(name,buffer_string.data());
+  return *this;
+}
+
+OFile& OFile::printField(const std::string&name,long long unsigned v) {
+  std::snprintf(buffer_string.data(),buffer_string.size()," %llu",v);
+  printField(name,buffer_string.data());
   return *this;
 }
 
 OFile& OFile::printField(const std::string&name,const std::string & v) {
   unsigned i;
-  for(i=0; i<const_fields.size(); i++) if(const_fields[i].name==name) break;
+  for(i=0; i<const_fields.size(); i++)
+    if(const_fields[i].name==name) {
+      break;
+    }
   if(i>=const_fields.size()) {
     Field field;
     field.name=name;
     field.value=v;
     fields.push_back(field);
   } else {
-    if(const_fields[i].value!=v) fieldChanged=true;
+    if(const_fields[i].value!=v) {
+      fieldChanged=true;
+    }
     const_fields[i].value=v;
   }
   return *this;
@@ -223,7 +255,8 @@ OFile& OFile::setupPrintValue( Value *val ) {
 OFile& OFile::printField( Value* val, const double& v ) {
   printField( val->getName(), v );
   if( val->isPeriodic() ) {
-    std::string min, max; val->getDomain( min, max );
+    std::string min, max;
+    val->getDomain( min, max );
     printField( "min_" + val->getName(), min );
     printField("max_" + val->getName(), max );
   }
@@ -234,7 +267,8 @@ OFile& OFile::printField() {
   bool reprint=false;
   if(fieldChanged || fields.size()!=previous_fields.size()) {
     reprint=true;
-  } else for(unsigned i=0; i<fields.size(); i++) {
+  } else
+    for(unsigned i=0; i<fields.size(); i++) {
       if( previous_fields[i].name!=fields[i].name ||
           (fields[i].constant && fields[i].value!=previous_fields[i].value) ) {
         reprint=true;
@@ -243,14 +277,18 @@ OFile& OFile::printField() {
     }
   if(reprint) {
     printf("#! FIELDS");
-    for(unsigned i=0; i<fields.size(); i++) printf(" %s",fields[i].name.c_str());
+    for(unsigned i=0; i<fields.size(); i++) {
+      printf(" %s",fields[i].name.c_str());
+    }
     printf("\n");
     for(unsigned i=0; i<const_fields.size(); i++) {
       printf("#! SET %s %s",const_fields[i].name.c_str(),const_fields[i].value.c_str());
       printf("\n");
     }
   }
-  for(unsigned i=0; i<fields.size(); i++) printf("%s",fields[i].value.c_str());
+  for(unsigned i=0; i<fields.size(); i++) {
+    printf("%s",fields[i].value.c_str());
+  }
   printf("\n");
   previous_fields=fields;
   fields.clear();
@@ -263,28 +301,40 @@ void OFile::setBackupString( const std::string& str ) {
 }
 
 void OFile::backupAllFiles( const std::string& str ) {
-  if(str=="/dev/null") return;
+  if(str=="/dev/null") {
+    return;
+  }
   plumed_assert( backstring!="bck" && !checkRestart());
   size_t found=str.find_last_of("/\\");
   std::string filename = appendSuffix(str,getSuffix());
   std::string directory=filename.substr(0,found+1);
   std::string file=filename.substr(found+1);
-  if( FileExist(filename) ) backupFile("bck", filename);
+  if( FileExist(filename) ) {
+    backupFile("bck", filename);
+  }
   for(int i=0;; i++) {
-    std::string num; Tools::convert(i,num);
+    std::string num;
+    Tools::convert(i,num);
     std::string filestr = directory + backstring + "." + num + "." + file;
-    if( !FileExist(filestr) ) break;
+    if( !FileExist(filestr) ) {
+      break;
+    }
     backupFile( "bck", filestr);
   }
 }
 
 void OFile::backupFile( const std::string& bstring, const std::string& fname ) {
-  if(fname=="/dev/null") return;
+  if(fname=="/dev/null") {
+    return;
+  }
   int maxbackup=100;
-  if(std::getenv("PLUMED_MAXBACKUP")) Tools::convert(std::getenv("PLUMED_MAXBACKUP"),maxbackup);
+  if(std::getenv("PLUMED_MAXBACKUP")) {
+    Tools::convert(std::getenv("PLUMED_MAXBACKUP"),maxbackup);
+  }
   if(maxbackup>0 && (!comm || comm->Get_rank()==0)) {
     FILE* ff=std::fopen(const_cast<char*>(fname.c_str()),"r");
     if(ff) {
+      // no exception here
       std::fclose(ff);
       std::string backup;
       size_t found=fname.find_last_of("/\\");
@@ -293,11 +343,17 @@ void OFile::backupFile( const std::string& bstring, const std::string& fname ) {
       for(int i=0;; i++) {
         std::string num;
         Tools::convert(i,num);
-        if(i>maxbackup) plumed_merror("cannot backup file "+file+" maximum number of backup is "+num+"\n");
+        if(i>maxbackup) {
+          plumed_merror("cannot backup file "+file+" maximum number of backup is "+num+"\n");
+        }
         backup=directory+bstring +"."+num+"."+file;
         FILE* fff=std::fopen(backup.c_str(),"r");
-        if(!fff) break;
-        else std::fclose(fff);
+        // no exception here
+        if(!fff) {
+          break;
+        } else {
+          std::fclose(fff);
+        }
       }
       int check=rename(fname.c_str(),backup.c_str());
       plumed_massert(check==0,"renaming "+fname+" into "+backup+" failed for reason: "+std::strerror(errno));
@@ -325,7 +381,9 @@ OFile& OFile::open(const std::string&path) {
     }
   } else {
     backupFile( backstring, this->path );
-    if(comm)comm->Barrier();
+    if(comm) {
+      comm->Barrier();
+    }
     fp=std::fopen(const_cast<char*>(this->path.c_str()),"w");
     mode="w";
     if(Tools::extension(this->path)=="gz") {
@@ -336,7 +394,9 @@ OFile& OFile::open(const std::string&path) {
 #endif
     }
   }
-  if(plumed) plumed->insertFile(*this);
+  if(plumed) {
+    plumed->insertFile(*this);
+  }
   return *this;
 }
 
@@ -346,11 +406,6 @@ OFile& OFile::rewind() {
 // moreover, we can take a backup of the file
   plumed_assert(fp);
   clearFields();
-  if(gzfp) {
-#ifdef __PLUMED_HAS_ZLIB
-    gzclose((gzFile)gzfp);
-#endif
-  } else fclose(fp);
 
   if(!comm || comm->Get_rank()==0) {
     std::string fname=this->path;
@@ -362,13 +417,21 @@ OFile& OFile::rewind() {
     plumed_massert(check==0,"renaming "+fname+" into "+backup+" failed for reason: "+std::strerror(errno));
   }
 
-  if(comm) comm->Barrier();
+  if(comm) {
+    comm->Barrier();
+  }
 
   if(gzfp) {
 #ifdef __PLUMED_HAS_ZLIB
+    gzclose((gzFile)gzfp);
+    // no exception here
     gzfp=(void*)gzopen(const_cast<char*>(this->path.c_str()),"w9");
 #endif
-  } else fp=std::fopen(const_cast<char*>(path.c_str()),"w");
+  } else {
+    std::fclose(fp);
+    // no exception here
+    fp=std::fopen(const_cast<char*>(path.c_str()),"w");
+  }
   return *this;
 }
 
@@ -377,10 +440,12 @@ FileBase& OFile::flush() {
     if(gzfp) {
 #ifdef __PLUMED_HAS_ZLIB
       gzclose(gzFile(gzfp));
+      // no exception here
       gzfp=(void*)gzopen(const_cast<char*>(path.c_str()),"a");
 #endif
     } else {
-      fclose(fp);
+      std::fclose(fp);
+      // no exception here
       fp=std::fopen(const_cast<char*>(path.c_str()),"a");
     }
   } else {
@@ -389,18 +454,26 @@ FileBase& OFile::flush() {
     // for some reason flushing with Z_FINISH has problems on linux
     // I thus use this (incomplete) flush
 #ifdef __PLUMED_HAS_ZLIB
-    if(gzfp) gzflush(gzFile(gzfp),Z_FULL_FLUSH);
+    if(gzfp) {
+      gzflush(gzFile(gzfp),Z_FULL_FLUSH);
+    }
 #endif
   }
   return *this;
 }
 
 bool OFile::checkRestart()const {
-  if(enforceRestart_) return true;
-  else if(enforceBackup_) return false;
-  else if(action) return action->getRestart();
-  else if(plumed) return plumed->getRestart();
-  else return false;
+  if(enforceRestart_) {
+    return true;
+  } else if(enforceBackup_) {
+    return false;
+  } else if(action) {
+    return action->getRestart();
+  } else if(plumed) {
+    return plumed->getRestart();
+  } else {
+    return false;
+  }
 }
 
 OFile& OFile::enforceRestart() {
