@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -28,8 +28,6 @@
 #include "core/GenericMolInfo.h"
 #include "Tensor.h"
 
-using namespace std;
-
 //+PLUMEDOC INTERNAL pdbreader
 /*
 PLUMED can use the PDB format in several places
@@ -133,33 +131,51 @@ In addition, as of PLUMED 2.5, we provide a \ref pdbrenumber "command line tool"
 namespace PLMD {
 
 void PDB::setAtomNumbers( const std::vector<AtomNumber>& atoms ) {
-  positions.resize( atoms.size() ); occupancy.resize( atoms.size() );
-  beta.resize( atoms.size() ); numbers.resize( atoms.size() );
-  for(unsigned i=0; i<atoms.size(); ++i) { numbers[i]=atoms[i]; beta[i]=1.0; occupancy[i]=1.0; }
+  positions.resize( atoms.size() );
+  occupancy.resize( atoms.size() );
+  beta.resize( atoms.size() );
+  numbers.resize( atoms.size() );
+  for(unsigned i=0; i<atoms.size(); ++i) {
+    numbers[i]=atoms[i];
+    beta[i]=1.0;
+    occupancy[i]=1.0;
+  }
 }
 
 void PDB::setArgumentNames( const std::vector<std::string>& argument_names ) {
   argnames.resize( argument_names.size() );
+  std::vector<double> tmp(1,0);
   for(unsigned i=0; i<argument_names.size(); ++i) {
     argnames[i]=argument_names[i];
-    arg_data.insert( std::pair<std::string,double>( argnames[i], 0.0 ) );
+    arg_data.insert( std::pair<std::string,std::vector<double> >( argnames[i], tmp ) );
   }
 }
 
-bool PDB::getArgumentValue( const std::string& name, double& value ) const {
-  std::map<std::string,double>::const_iterator it = arg_data.find(name);
-  if( it!=arg_data.end() ) { value = it->second; return true; }
+bool PDB::getArgumentValue( const std::string& name, std::vector<double>& value ) const {
+  std::map<std::string,std::vector<double> >::const_iterator it = arg_data.find(name);
+  if( it!=arg_data.end() ) {
+    if( value.size()!=it->second.size() ) {
+      return false;
+    }
+    for(unsigned i=0; i<value.size(); ++i) {
+      value[i] = it->second[i];
+    }
+    return true;
+  }
   return false;
 }
 
 void PDB::setAtomPositions( const std::vector<Vector>& pos ) {
   plumed_assert( pos.size()==positions.size() );
-  for(unsigned i=0; i<positions.size(); ++i) positions[i]=pos[i];
+  for(unsigned i=0; i<positions.size(); ++i) {
+    positions[i]=pos[i];
+  }
 }
 
 void PDB::setArgumentValue( const std::string& argname, const double& val ) {
   // First set the value of the value of the argument in the map
-  arg_data.find(argname)->second = val;
+  arg_data.find(argname)->second.resize(1);
+  arg_data.find(argname)->second[0] = val;
 }
 
 // bool PDB::hasRequiredProperties( const std::vector<std::string>& inproperties ){
@@ -220,8 +236,13 @@ void PDB::addRemark( std::vector<std::string>& v1 ) {
       std::size_t eq=v1[i].find_first_of('=');
       std::string name=v1[i].substr(0,eq);
       std::string sval=v1[i].substr(eq+1);
-      double val; Tools::convert( sval, val );
-      arg_data.insert( std::pair<std::string,double>( name, val ) );
+      // double val; Tools::convert( sval, val );
+      std::vector<std::string> words=Tools::getWords(sval,"\t\n ,");
+      std::vector<double> val( words.size() );
+      for(unsigned i=0; i<val.size(); ++i) {
+        Tools::convert( words[i], val[i] );
+      }
+      arg_data.insert( std::pair<std::string,std::vector<double> >( name, val ) );
     } else {
       flags.push_back(v1[i]);
     }
@@ -230,7 +251,9 @@ void PDB::addRemark( std::vector<std::string>& v1 ) {
 
 bool PDB::hasFlag( const std::string& fname ) const {
   for(unsigned i=0; i<flags.size(); ++i) {
-    if( flags[i]==fname ) return true;
+    if( flags[i]==fname ) {
+      return true;
+    }
   }
   return false;
 }
@@ -255,28 +278,34 @@ const Tensor & PDB::getBoxVec()const {
 std::string PDB::getAtomName(AtomNumber a)const {
   const auto p=number2index.find(a);
   if(p==number2index.end()) {
-    std::string num; Tools::convert( a.serial(), num );
+    std::string num;
+    Tools::convert( a.serial(), num );
     plumed_merror("Name of atom " + num + " not found" );
-    return "";
-  } else return atomsymb[p->second];
+  } else {
+    return atomsymb[p->second];
+  }
 }
 
 unsigned PDB::getResidueNumber(AtomNumber a)const {
   const auto p=number2index.find(a);
   if(p==number2index.end()) {
-    std::string num; Tools::convert( a.serial(), num );
+    std::string num;
+    Tools::convert( a.serial(), num );
     plumed_merror("Residue for atom " + num + " not found" );
-    return 0;
-  } else return residue[p->second];
+  } else {
+    return residue[p->second];
+  }
 }
 
 std::string PDB::getResidueName(AtomNumber a) const {
   const auto p=number2index.find(a);
   if(p==number2index.end()) {
-    std::string num; Tools::convert( a.serial(), num );
+    std::string num;
+    Tools::convert( a.serial(), num );
     plumed_merror("Residue for atom " + num + " not found" );
-    return "";
-  } else return residuenames[p->second];
+  } else {
+    return residuenames[p->second];
+  }
 }
 
 unsigned PDB::size()const {
@@ -286,36 +315,51 @@ unsigned PDB::size()const {
 bool PDB::readFromFilepointer(FILE *fp,bool naturalUnits,double scale) {
   //cerr<<file<<endl;
   bool file_is_alive=false;
-  if(naturalUnits) scale=1.0;
-  string line;
-  fpos_t pos; bool between_ters=true;
+  if(naturalUnits) {
+    scale=1.0;
+  }
+  std::string line;
+  fpos_t pos;
+  bool between_ters=true;
   while(Tools::getline(fp,line)) {
     //cerr<<line<<"\n";
     fgetpos (fp,&pos);
-    while(line.length()<80) line.push_back(' ');
-    string record=line.substr(0,6);
-    string serial=line.substr(6,5);
-    string atomname=line.substr(12,4);
-    string residuename=line.substr(17,3);
-    string chainID=line.substr(21,1);
-    string resnum=line.substr(22,4);
-    string x=line.substr(30,8);
-    string y=line.substr(38,8);
-    string z=line.substr(46,8);
-    string occ=line.substr(54,6);
-    string bet=line.substr(60,6);
-    string BoxX=line.substr(6,9);
-    string BoxY=line.substr(15,9);
-    string BoxZ=line.substr(24,9);
-    string BoxA=line.substr(33,7);
-    string BoxB=line.substr(40,7);
-    string BoxG=line.substr(47,7);
+    while(line.length()<80) {
+      line.push_back(' ');
+    }
+    std::string record=line.substr(0,6);
+    std::string serial=line.substr(6,5);
+    std::string atomname=line.substr(12,4);
+    std::string residuename=line.substr(17,3);
+    std::string chainID=line.substr(21,1);
+    std::string resnum=line.substr(22,4);
+    std::string x=line.substr(30,8);
+    std::string y=line.substr(38,8);
+    std::string z=line.substr(46,8);
+    std::string occ=line.substr(54,6);
+    std::string bet=line.substr(60,6);
+    std::string BoxX=line.substr(6,9);
+    std::string BoxY=line.substr(15,9);
+    std::string BoxZ=line.substr(24,9);
+    std::string BoxA=line.substr(33,7);
+    std::string BoxB=line.substr(40,7);
+    std::string BoxG=line.substr(47,7);
     Tools::trim(record);
-    if(record=="TER") { between_ters=false; block_ends.push_back( positions.size() ); }
-    if(record=="END") { file_is_alive=true;  break;}
-    if(record=="ENDMDL") { file_is_alive=true;  break;}
+    if(record=="TER") {
+      between_ters=false;
+      block_ends.push_back( positions.size() );
+    }
+    if(record=="END") {
+      file_is_alive=true;
+      break;
+    }
+    if(record=="ENDMDL") {
+      file_is_alive=true;
+      break;
+    }
     if(record=="REMARK") {
-      vector<string> v1;  v1=Tools::getWords(line.substr(6));
+      std::vector<std::string> v1;
+      v1=Tools::getWords(line.substr(6));
       addRemark( v1 );
     }
     if(record=="CRYST1") {
@@ -326,28 +370,35 @@ bool PDB::readFromFilepointer(FILE *fp,bool naturalUnits,double scale) {
       Tools::convert(BoxB,BoxABG[1]);
       Tools::convert(BoxG,BoxABG[2]);
       BoxXYZ*=scale;
-      double cosA=cos(BoxABG[0]*pi/180.);
-      double cosB=cos(BoxABG[1]*pi/180.);
-      double cosG=cos(BoxABG[2]*pi/180.);
-      double sinG=sin(BoxABG[2]*pi/180.);
-      for (unsigned i=0; i<3; i++) {Box[i][0]=0.; Box[i][1]=0.; Box[i][2]=0.;}
+      double cosA=std::cos(BoxABG[0]*pi/180.);
+      double cosB=std::cos(BoxABG[1]*pi/180.);
+      double cosG=std::cos(BoxABG[2]*pi/180.);
+      double sinG=std::sin(BoxABG[2]*pi/180.);
+      for (unsigned i=0; i<3; i++) {
+        Box[i][0]=0.;
+        Box[i][1]=0.;
+        Box[i][2]=0.;
+      }
       Box[0][0]=BoxXYZ[0];
       Box[1][0]=BoxXYZ[1]*cosG;
       Box[1][1]=BoxXYZ[1]*sinG;
       Box[2][0]=BoxXYZ[2]*cosB;
       Box[2][1]=(BoxXYZ[2]*BoxXYZ[1]*cosA-Box[2][0]*Box[1][0])/Box[1][1];
-      Box[2][2]=sqrt(BoxXYZ[2]*BoxXYZ[2]-Box[2][0]*Box[2][0]-Box[2][1]*Box[2][1]);
+      Box[2][2]=std::sqrt(BoxXYZ[2]*BoxXYZ[2]-Box[2][0]*Box[2][0]-Box[2][1]*Box[2][1]);
     }
     if(record=="ATOM" || record=="HETATM") {
       between_ters=true;
-      AtomNumber a; unsigned resno;
+      AtomNumber a;
+      unsigned resno=0; // GB: when resnum string is not present, we set res number to zero
       double o,b;
       Vector p;
       {
         int result;
         auto trimmed=serial;
         Tools::trim(trimmed);
-        while(trimmed.length()<5) trimmed = std::string(" ") + trimmed;
+        while(trimmed.length()<5) {
+          trimmed = std::string(" ") + trimmed;
+        }
         const char* errmsg = h36::hy36decode(5, trimmed.c_str(),trimmed.length(), &result);
         if(errmsg) {
           std::string msg(errmsg);
@@ -356,7 +407,24 @@ bool PDB::readFromFilepointer(FILE *fp,bool naturalUnits,double scale) {
         a.setSerial(result);
       }
 
-      Tools::convert(resnum,resno);
+      // allow skipping residue number
+      {
+        auto trimmed=resnum;
+        Tools::trim(trimmed);
+        if(trimmed.length()>0) {
+          int result;
+          while(trimmed.length()<4) {
+            trimmed = std::string(" ") + trimmed;
+          }
+          const char* errmsg = h36::hy36decode(4, trimmed.c_str(),trimmed.length(), &result);
+          if(errmsg) {
+            std::string msg(errmsg);
+            plumed_merror(msg);
+          }
+          resno=result;
+        }
+      }
+
       Tools::convert(occ,o);
       Tools::convert(bet,b);
       Tools::convert(x,p[0]);
@@ -377,15 +445,23 @@ bool PDB::readFromFilepointer(FILE *fp,bool naturalUnits,double scale) {
       residuenames.push_back(residuename);
     }
   }
-  if( between_ters ) block_ends.push_back( positions.size() );
+  if( between_ters ) {
+    block_ends.push_back( positions.size() );
+  }
   return file_is_alive;
 }
 
 bool PDB::read(const std::string&file,bool naturalUnits,double scale) {
-  FILE* fp=fopen(file.c_str(),"r");
-  if(!fp) return false;
+  FILE* fp=std::fopen(file.c_str(),"r");
+  if(!fp) {
+    return false;
+  }
+// call fclose when exiting this function
+  auto deleter=[](auto f) {
+    std::fclose(f);
+  };
+  std::unique_ptr<FILE,decltype(deleter)> fp_deleter(fp,deleter);
   readFromFilepointer(fp,naturalUnits,scale);
-  fclose(fp);
   return true;
 }
 
@@ -393,7 +469,9 @@ void PDB::getChainNames( std::vector<std::string>& chains ) const {
   chains.resize(0);
   chains.push_back( chain[0] );
   for(unsigned i=1; i<size(); ++i) {
-    if( chains[chains.size()-1]!=chain[i] ) chains.push_back( chain[i] );
+    if( chains[chains.size()-1]!=chain[i] ) {
+      chains.push_back( chain[i] );
+    }
   }
 }
 
@@ -402,16 +480,21 @@ void PDB::getResidueRange( const std::string& chainname, unsigned& res_start, un
   for(unsigned i=0; i<size(); ++i) {
     if( chain[i]==chainname ) {
       if(!inres) {
-        if(foundchain) errmsg="found second start of chain named " + chainname;
+        if(foundchain) {
+          errmsg="found second start of chain named " + chainname;
+        }
         res_start=residue[i];
       }
-      inres=true; foundchain=true;
+      inres=true;
+      foundchain=true;
     } else if( inres && chain[i]!=chainname ) {
       inres=false;
       res_end=residue[i-1];
     }
   }
-  if(inres) res_end=residue[size()-1];
+  if(inres) {
+    res_end=residue[size()-1];
+  }
 }
 
 void PDB::getAtomRange( const std::string& chainname, AtomNumber& a_start, AtomNumber& a_end, std::string& errmsg ) const {
@@ -419,62 +502,78 @@ void PDB::getAtomRange( const std::string& chainname, AtomNumber& a_start, AtomN
   for(unsigned i=0; i<size(); ++i) {
     if( chain[i]==chainname ) {
       if(!inres) {
-        if(foundchain) errmsg="found second start of chain named " + chainname;
+        if(foundchain) {
+          errmsg="found second start of chain named " + chainname;
+        }
         a_start=numbers[i];
       }
-      inres=true; foundchain=true;
+      inres=true;
+      foundchain=true;
     } else if( inres && chain[i]!=chainname ) {
       inres=false;
       a_end=numbers[i-1];
     }
   }
-  if(inres) a_end=numbers[size()-1];
+  if(inres) {
+    a_end=numbers[size()-1];
+  }
 }
 
 std::string PDB::getResidueName( const unsigned& resnum ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( residue[i]==resnum ) return residuenames[i];
+    if( residue[i]==resnum ) {
+      return residuenames[i];
+    }
   }
-  std::string num; Tools::convert( resnum, num );
+  std::string num;
+  Tools::convert( resnum, num );
   plumed_merror("residue " + num + " not found" );
-  return "";
 }
 
 std::string PDB::getResidueName(const unsigned& resnum,const std::string& chainid ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( residue[i]==resnum && ( chainid=="*" || chain[i]==chainid) ) return residuenames[i];
+    if( residue[i]==resnum && ( chainid=="*" || chain[i]==chainid) ) {
+      return residuenames[i];
+    }
   }
-  std::string num; Tools::convert( resnum, num );
+  std::string num;
+  Tools::convert( resnum, num );
   plumed_merror("residue " + num + " not found in chain " + chainid );
-  return "";
 }
 
 
 AtomNumber PDB::getNamedAtomFromResidue( const std::string& aname, const unsigned& resnum ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( residue[i]==resnum && atomsymb[i]==aname ) return numbers[i];
+    if( residue[i]==resnum && atomsymb[i]==aname ) {
+      return numbers[i];
+    }
   }
-  std::string num; Tools::convert( resnum, num );
+  std::string num;
+  Tools::convert( resnum, num );
   plumed_merror("residue " + num + " does not contain an atom named " + aname );
-  return numbers[0]; // This is to stop compiler errors
 }
 
 AtomNumber PDB::getNamedAtomFromResidueAndChain( const std::string& aname, const unsigned& resnum, const std::string& chainid ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( residue[i]==resnum && atomsymb[i]==aname && ( chainid=="*" || chain[i]==chainid) ) return numbers[i];
+    if( residue[i]==resnum && atomsymb[i]==aname && ( chainid=="*" || chain[i]==chainid) ) {
+      return numbers[i];
+    }
   }
-  std::string num; Tools::convert( resnum, num );
+  std::string num;
+  Tools::convert( resnum, num );
   plumed_merror("residue " + num + " from chain " + chainid + " does not contain an atom named " + aname );
-  return numbers[0]; // This is to stop compiler errors
 }
 
 std::vector<AtomNumber> PDB::getAtomsInResidue(const unsigned& resnum,const std::string& chainid)const {
   std::vector<AtomNumber> tmp;
   for(unsigned i=0; i<size(); ++i) {
-    if( residue[i]==resnum && ( chainid=="*" || chain[i]==chainid) ) tmp.push_back(numbers[i]);
+    if( residue[i]==resnum && ( chainid=="*" || chain[i]==chainid) ) {
+      tmp.push_back(numbers[i]);
+    }
   }
   if(tmp.size()==0) {
-    std::string num; Tools::convert( resnum, num );
+    std::string num;
+    Tools::convert( resnum, num );
     plumed_merror("Cannot find residue " + num + " from chain " + chainid  );
   }
   return tmp;
@@ -483,7 +582,9 @@ std::vector<AtomNumber> PDB::getAtomsInResidue(const unsigned& resnum,const std:
 std::vector<AtomNumber> PDB::getAtomsInChain(const std::string& chainid)const {
   std::vector<AtomNumber> tmp;
   for(unsigned i=0; i<size(); ++i) {
-    if( chainid=="*" || chain[i]==chainid ) tmp.push_back(numbers[i]);
+    if( chainid=="*" || chain[i]==chainid ) {
+      tmp.push_back(numbers[i]);
+    }
   }
   if(tmp.size()==0) {
     plumed_merror("Cannot find atoms from chain " + chainid  );
@@ -493,21 +594,37 @@ std::vector<AtomNumber> PDB::getAtomsInChain(const std::string& chainid)const {
 
 std::string PDB::getChainID(const unsigned& resnumber) const {
   for(unsigned i=0; i<size(); ++i) {
-    if(resnumber==residue[i]) return chain[i];
+    if(resnumber==residue[i]) {
+      return chain[i];
+    }
   }
   plumed_merror("Not enough residues in pdb input file");
 }
 
+std::string PDB::getChainID(AtomNumber a) const {
+  const auto p=number2index.find(a);
+  if(p==number2index.end()) {
+    std::string num;
+    Tools::convert( a.serial(), num );
+    plumed_merror("Chain for atom " + num + " not found" );
+  }
+  return chain[p->second];
+}
+
 bool PDB::checkForResidue( const std::string& name ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( residuenames[i]==name ) return true;
+    if( residuenames[i]==name ) {
+      return true;
+    }
   }
   return false;
 }
 
 bool PDB::checkForAtom( const std::string& name ) const {
   for(unsigned i=0; i<size(); ++i) {
-    if( atomsymb[i]==name ) return true;
+    if( atomsymb[i]==name ) {
+      return true;
+    }
   }
   return false;
 }
@@ -518,9 +635,10 @@ bool PDB::checkForAtom( AtomNumber a ) const {
 }
 
 Log& operator<<(Log& ostr, const PDB&  pdb) {
-  char buffer[1000];
+  const std::size_t bufferlen=1000;
+  char buffer[bufferlen];
   for(unsigned i=0; i<pdb.positions.size(); i++) {
-    sprintf(buffer,"ATOM %3d %8.3f %8.3f %8.3f\n",pdb.numbers[i].serial(),pdb.positions[i][0],pdb.positions[i][1],pdb.positions[i][2]);
+    std::snprintf(buffer,bufferlen,"ATOM %3u %8.3f %8.3f %8.3f\n",pdb.numbers[i].serial(),pdb.positions[i][0],pdb.positions[i][1],pdb.positions[i][2]);
     ostr<<buffer;
   }
   return ostr;
@@ -528,8 +646,11 @@ Log& operator<<(Log& ostr, const PDB&  pdb) {
 
 Vector PDB::getPosition(AtomNumber a)const {
   const auto p=number2index.find(a);
-  if(p==number2index.end()) plumed_merror("atom not available");
-  else return positions[p->second];
+  if(p==number2index.end()) {
+    plumed_merror("atom not available");
+  } else {
+    return positions[p->second];
+  }
 }
 
 std::vector<std::string> PDB::getArgumentNames()const {
@@ -543,8 +664,11 @@ std::string PDB::getMtype() const {
 void PDB::print( const double& lunits, GenericMolInfo* mymoldat, OFile& ofile, const std::string& fmt ) {
   if( argnames.size()>0 ) {
     ofile.printf("REMARK ARG=%s", argnames[0].c_str() );
-    for(unsigned i=1; i<argnames.size(); ++i) ofile.printf(",%s",argnames[i].c_str() );
-    ofile.printf("\n"); ofile.printf("REMARK ");
+    for(unsigned i=1; i<argnames.size(); ++i) {
+      ofile.printf(",%s",argnames[i].c_str() );
+    }
+    ofile.printf("\n");
+    ofile.printf("REMARK ");
   }
   std::string descr2;
   if(fmt.find("-")!=std::string::npos) {
@@ -555,28 +679,48 @@ void PDB::print( const double& lunits, GenericMolInfo* mymoldat, OFile& ofile, c
     plumed_assert( psign!=std::string::npos );
     descr2="%s=%-" + fmt.substr(psign+1) + " ";
   }
-  for(std::map<std::string,double>::iterator it=arg_data.begin(); it!=arg_data.end(); ++it) ofile.printf( descr2.c_str(),it->first.c_str(), it->second );
-  if( argnames.size()>0 ) ofile.printf("\n");
+  for(std::map<std::string,std::vector<double> >::iterator it=arg_data.begin(); it!=arg_data.end(); ++it) {
+    ofile.printf( descr2.c_str(),it->first.c_str(), it->second[0] );
+  }
+  if( argnames.size()>0 ) {
+    ofile.printf("\n");
+  }
   if( !mymoldat ) {
     for(unsigned i=0; i<positions.size(); ++i) {
       std::array<char,6> at;
-      const char* msg = h36::hy36encode(5,numbers[i].serial(),&at[0]);
-      plumed_assert(msg==nullptr) << msg;
-      at[5]=0;
-      ofile.printf("ATOM  %s  X   RES  %4u    %8.3f%8.3f%8.3f%6.2f%6.2f\n",
-                   &at[0], i,
+      {
+        const char* msg = h36::hy36encode(5,numbers[i].serial(),&at[0]);
+        plumed_assert(msg==nullptr) << msg;
+        at[5]=0;
+      }
+      std::array<char,5> res;
+      {
+        const char* msg = h36::hy36encode(4,i,&res[0]);
+        plumed_assert(msg==nullptr) << msg;
+        res[4]=0;
+      }
+      ofile.printf("ATOM  %s  X   RES  %s    %8.3f%8.3f%8.3f%6.2f%6.2f\n",
+                   &at[0], &res[0],
                    lunits*positions[i][0], lunits*positions[i][1], lunits*positions[i][2],
                    occupancy[i], beta[i] );
     }
   } else {
     for(unsigned i=0; i<positions.size(); ++i) {
       std::array<char,6> at;
-      const char* msg = h36::hy36encode(5,numbers[i].serial(),&at[0]);
-      plumed_assert(msg==nullptr) << msg;
-      at[5]=0;
-      ofile.printf("ATOM  %s %-4s %3s  %4u    %8.3f%8.3f%8.3f%6.2f%6.2f\n",
+      {
+        const char* msg = h36::hy36encode(5,numbers[i].serial(),&at[0]);
+        plumed_assert(msg==nullptr) << msg;
+        at[5]=0;
+      }
+      std::array<char,5> res;
+      {
+        const char* msg = h36::hy36encode(4,mymoldat->getResidueNumber(numbers[i]),&res[0]);
+        plumed_assert(msg==nullptr) << msg;
+        res[4]=0;
+      }
+      ofile.printf("ATOM  %s %-4s %3s  %s    %8.3f%8.3f%8.3f%6.2f%6.2f\n",
                    &at[0], mymoldat->getAtomName(numbers[i]).c_str(),
-                   mymoldat->getResidueName(numbers[i]).c_str(), mymoldat->getResidueNumber(numbers[i]),
+                   mymoldat->getResidueName(numbers[i]).c_str(), &res[0],
                    lunits*positions[i][0], lunits*positions[i][1], lunits*positions[i][2],
                    occupancy[i], beta[i] );
     }
@@ -584,6 +728,264 @@ void PDB::print( const double& lunits, GenericMolInfo* mymoldat, OFile& ofile, c
   ofile.printf("END\n");
 }
 
+bool PDB::allowedResidue( const std::string& type, const std::string& residuename ) const {
+  if( type=="protein" ) {
+    if(residuename=="ALA") {
+      return true;
+    } else if(residuename=="ARG") {
+      return true;
+    } else if(residuename=="ASN") {
+      return true;
+    } else if(residuename=="ASP") {
+      return true;
+    } else if(residuename=="CYS") {
+      return true;
+    } else if(residuename=="GLN") {
+      return true;
+    } else if(residuename=="GLU") {
+      return true;
+    } else if(residuename=="GLY") {
+      return true;
+    } else if(residuename=="HIS") {
+      return true;
+    } else if(residuename=="ILE") {
+      return true;
+    } else if(residuename=="LEU") {
+      return true;
+    } else if(residuename=="LYS") {
+      return true;
+    } else if(residuename=="MET") {
+      return true;
+    } else if(residuename=="PHE") {
+      return true;
+    } else if(residuename=="PRO") {
+      return true;
+    } else if(residuename=="SER") {
+      return true;
+    } else if(residuename=="THR") {
+      return true;
+    } else if(residuename=="TRP") {
+      return true;
+    } else if(residuename=="TYR") {
+      return true;
+    } else if(residuename=="VAL") {
+      return true;
+    }
+// Terminal groups
+    else if(residuename=="ACE") {
+      return true;
+    } else if(residuename=="NME") {
+      return true;
+    } else if(residuename=="NH2") {
+      return true;
+    }
+// Alternative residue names in common force fields
+    else if(residuename=="GLH") {
+      return true;  // neutral GLU
+    } else if(residuename=="ASH") {
+      return true;  // neutral ASP
+    } else if(residuename=="HID") {
+      return true;  // HIS-D amber
+    } else if(residuename=="HSD") {
+      return true;  // HIS-D charmm
+    } else if(residuename=="HIE") {
+      return true;  // HIS-E amber
+    } else if(residuename=="HSE") {
+      return true;  // HIS-E charmm
+    } else if(residuename=="HIP") {
+      return true;  // HIS-P amber
+    } else if(residuename=="HSP") {
+      return true;  // HIS-P charmm
+    } else if(residuename=="CYX") {
+      return true;  // disulfide bridge CYS
+    }
+// Weird amino acids
+    else if(residuename=="NLE") {
+      return true;
+    } else if(residuename=="SFO") {
+      return true;
+    } else {
+      return false;
+    }
+  } else if( type=="dna" ) {
+    if(residuename=="A") {
+      return true;
+    } else if(residuename=="A5") {
+      return true;
+    } else if(residuename=="A3") {
+      return true;
+    } else if(residuename=="AN") {
+      return true;
+    } else if(residuename=="G") {
+      return true;
+    } else if(residuename=="G5") {
+      return true;
+    } else if(residuename=="G3") {
+      return true;
+    } else if(residuename=="GN") {
+      return true;
+    } else if(residuename=="T") {
+      return true;
+    } else if(residuename=="T5") {
+      return true;
+    } else if(residuename=="T3") {
+      return true;
+    } else if(residuename=="TN") {
+      return true;
+    } else if(residuename=="C") {
+      return true;
+    } else if(residuename=="C5") {
+      return true;
+    } else if(residuename=="C3") {
+      return true;
+    } else if(residuename=="CN") {
+      return true;
+    } else if(residuename=="DA") {
+      return true;
+    } else if(residuename=="DA5") {
+      return true;
+    } else if(residuename=="DA3") {
+      return true;
+    } else if(residuename=="DAN") {
+      return true;
+    } else if(residuename=="DG") {
+      return true;
+    } else if(residuename=="DG5") {
+      return true;
+    } else if(residuename=="DG3") {
+      return true;
+    } else if(residuename=="DGN") {
+      return true;
+    } else if(residuename=="DT") {
+      return true;
+    } else if(residuename=="DT5") {
+      return true;
+    } else if(residuename=="DT3") {
+      return true;
+    } else if(residuename=="DTN") {
+      return true;
+    } else if(residuename=="DC") {
+      return true;
+    } else if(residuename=="DC5") {
+      return true;
+    } else if(residuename=="DC3") {
+      return true;
+    } else if(residuename=="DCN") {
+      return true;
+    } else {
+      return false;
+    }
+  } else if( type=="rna" ) {
+    if(residuename=="A") {
+      return true;
+    } else if(residuename=="A5") {
+      return true;
+    } else if(residuename=="A3") {
+      return true;
+    } else if(residuename=="AN") {
+      return true;
+    } else if(residuename=="G") {
+      return true;
+    } else if(residuename=="G5") {
+      return true;
+    } else if(residuename=="G3") {
+      return true;
+    } else if(residuename=="GN") {
+      return true;
+    } else if(residuename=="U") {
+      return true;
+    } else if(residuename=="U5") {
+      return true;
+    } else if(residuename=="U3") {
+      return true;
+    } else if(residuename=="UN") {
+      return true;
+    } else if(residuename=="C") {
+      return true;
+    } else if(residuename=="C5") {
+      return true;
+    } else if(residuename=="C3") {
+      return true;
+    } else if(residuename=="CN") {
+      return true;
+    } else if(residuename=="RA") {
+      return true;
+    } else if(residuename=="RA5") {
+      return true;
+    } else if(residuename=="RA3") {
+      return true;
+    } else if(residuename=="RAN") {
+      return true;
+    } else if(residuename=="RG") {
+      return true;
+    } else if(residuename=="RG5") {
+      return true;
+    } else if(residuename=="RG3") {
+      return true;
+    } else if(residuename=="RGN") {
+      return true;
+    } else if(residuename=="RU") {
+      return true;
+    } else if(residuename=="RU5") {
+      return true;
+    } else if(residuename=="RU3") {
+      return true;
+    } else if(residuename=="RUN") {
+      return true;
+    } else if(residuename=="RC") {
+      return true;
+    } else if(residuename=="RC5") {
+      return true;
+    } else if(residuename=="RC3") {
+      return true;
+    } else if(residuename=="RCN") {
+      return true;
+    } else {
+      return false;
+    }
+  } else if( type=="water" ) {
+    if(residuename=="SOL") {
+      return true;
+    }
+    if(residuename=="WAT") {
+      return true;
+    }
+    return false;
+  } else if( type=="ion" ) {
+    if(residuename=="IB+") {
+      return true;
+    }
+    if(residuename=="CA") {
+      return true;
+    }
+    if(residuename=="CL") {
+      return true;
+    }
+    if(residuename=="NA") {
+      return true;
+    }
+    if(residuename=="MG") {
+      return true;
+    }
+    if(residuename=="K") {
+      return true;
+    }
+    if(residuename=="RB") {
+      return true;
+    }
+    if(residuename=="CS") {
+      return true;
+    }
+    if(residuename=="LI") {
+      return true;
+    }
+    if(residuename=="ZN") {
+      return true;
+    }
+    return false;
+  }
+  return false;
+}
 
 }
 
