@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2021 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -43,30 +43,32 @@ Random::Random(const std::string & name):
 // In practice: without this it is not possible to declare
 // a static Random object without enforcing the order of the
 // static constructors.
-  name(&name!=&noname?name:"noname")
-{
+  name(&name!=&noname?name:"noname") {
   iy=0;
-  for(unsigned i=0; i<NTAB; i++) iv[i]=0;
+  for(unsigned i=0; i<NTAB; i++) {
+    iv[i]=0;
+  }
   setSeed(0);
 }
 
 void Random::setSeed(int idum_) {
-  if(idum_>0) idum_=-idum_;
+  if(idum_>0) {
+    idum_=-idum_;
+  }
   idum=idum_;
   incPrec=false;
 }
 
-double Random::RandU01 ()
-{
-  if (incPrec)
+double Random::RandU01 () {
+  if (incPrec) {
     return U01d();
-  else
+  } else {
     return U01();
+  }
 }
 
 
-double Random::U01d ()
-{
+double Random::U01d () {
   double u;
   u = U01();
   u += U01() * fact;
@@ -77,24 +79,36 @@ double Random::U01() {
   int j,k;
   double temp;
   if (idum <= 0 || !iy) {
-    if (-idum < 1) idum=1;
-    else idum = -idum;
+    if (-idum < 1) {
+      idum=1;
+    } else {
+      idum = -idum;
+    }
     for (j=NTAB+7; j>=0; j--) {
       k=idum/IQ;
       idum=IA*(idum-k*IQ)-IR*k;
-      if (idum < 0) idum += IM;
-      if (j < NTAB) iv[j] = idum;
+      if (idum < 0) {
+        idum += IM;
+      }
+      if (j < NTAB) {
+        iv[j] = idum;
+      }
     }
     iy=iv[0];
   }
   k=idum/IQ;
   idum=IA*(idum-k*IQ)-IR*k;
-  if (idum < 0) idum += IM;
+  if (idum < 0) {
+    idum += IM;
+  }
   j=iy/NDIV;
   iy=iv[j];
   iv[j] = idum;
-  if ((temp=AM*iy) > RNMX) return RNMX;
-  else return temp;
+  if ((temp=AM*iy) > RNMX) {
+    return RNMX;
+  } else {
+    return temp;
+  }
 }
 
 void Random::WriteStateFull(std::ostream & out)const {
@@ -111,7 +125,9 @@ void Random::WriteStateFull(std::ostream & out)const {
 void Random::ReadStateFull (std::istream & in) {
   getline(in,name);
   in>>idum>>iy;
-  for (int i = 0; i < NTAB; i++) in>>iv[i];
+  for (int i = 0; i < NTAB; i++) {
+    in>>iv[i];
+  }
   in>>switchGaussian;
   in>>saveGaussian;
 }
@@ -127,10 +143,15 @@ void Random::toString(std::string & str)const {
 
 void Random::fromString(const std::string & str) {
   std::string s=str;
-  for(unsigned i=0; i<s.length(); i++) if(s[i]=='|') s[i]=' ';
+  for(unsigned i=0; i<s.length(); i++)
+    if(s[i]=='|') {
+      s[i]=' ';
+    }
   std::istringstream istr(s.c_str());
   istr>>idum>>iy;
-  for (int i = 0; i < NTAB; i++) istr>>iv[i];
+  for (int i = 0; i < NTAB; i++) {
+    istr>>iv[i];
+  }
 }
 
 // This allows to have the same stream of random numbers
@@ -149,9 +170,11 @@ double Random::Gaussian() {
     v1=2.0*RandU01()-1.0;
     v2=2.0*RandU01()-1.0;
     rsq=v1*v1+v2*v2;
-    if(rsq<1.0 && rsq>0.0) break;
+    if(rsq<1.0 && rsq>0.0) {
+      break;
+    }
   }
-  double fac=sqrt(-2.*std::log(rsq)/rsq);
+  double fac=std::sqrt(-2.*std::log(rsq)/rsq);
   saveGaussian=v1*fac;
   switchGaussian=true;
   return v2*fac;
