@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2011-2021 The plumed team
+   Copyright (c) 2011-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -23,6 +23,9 @@
 #define __PLUMED_tools_Tools_h
 
 #include "AtomNumber.h"
+#include "Vector.h"
+#include "Tensor.h"
+#include "small_vector/small_vector.h"
 #include <vector>
 #include <string>
 #include <cctype>
@@ -32,6 +35,14 @@
 #include <algorithm>
 #include <sstream>
 #include <memory>
+#include <cstddef>
+#include <queue>
+#include <mutex>
+#include <filesystem>
+#include <utility>
+#include <unordered_map>
+#include <map>
+#include <condition_variable>
 
 namespace PLMD {
 
@@ -39,15 +50,25 @@ class IFile;
 
 /// \ingroup TOOLBOX
 /// Very small non-zero number
-const double epsilon(std::numeric_limits<double>::epsilon());
+constexpr double epsilon(std::numeric_limits<double>::epsilon());
 
 /// \ingroup TOOLBOX
 /// Boltzman constant in kj/K
-const double kBoltzmann(0.0083144621);
+constexpr double kBoltzmann(0.0083144621);
 
 /// \ingroup TOOLBOX
 /// PI
-const double pi(3.141592653589793238462643383279502884197169399375105820974944592307);
+constexpr double pi(3.141592653589793238462643383279502884197169399375105820974944592307);
+
+constexpr double dp2cutoff(6.25);
+
+constexpr double dp2cutoffA=1.00193418799744762399; // 1.0/(1-std::exp(-dp2cutoff));
+constexpr double dp2cutoffB=-.00193418799744762399; // -std::exp(-dp2cutoff)/(1-std::exp(-dp2cutoff));
+
+inline static bool dp2cutoffNoStretch() {
+  static const auto* res=std::getenv("PLUMED_DP2CUTOFF_NOSTRETCH");
+  return res;
+}
 
 /// \ingroup TOOLBOX
 /// Empty class which just contains several (static) tools
@@ -62,13 +83,19 @@ class Tools {
 /// class to convert a string to a int type T
   template<class T>
   static bool convertToInt(const std::string & str,T &t);
+/// @brief the  recursive part of the template fastpow implementation
+  template <int exp, typename T=double, std::enable_if_t< (exp >=0), bool> = true>
+  static inline /*consteval*/ T fastpow_rec(T base, T result);
 public:
 /// Split the line in words using separators.
 /// It also take into account parenthesis. Outer parenthesis found are removed from
 /// output, and the text between them is considered as a single word. Only the
 /// outer parenthesis are processed, to allow nesting them.
 /// parlevel, if not NULL, is increased or decreased according to the number of opened/closed parenthesis
-  static std::vector<std::string> getWords(const std::string & line,const char* sep=NULL,int* parlevel=NULL,const char* parenthesis="{", const bool& delete_parenthesis=true);
+  static std::vector<std::string> getWords(std::string_view line,const char* sep=NULL,int* parlevel=NULL,const char* parenthesis="{", const bool& delete_parenthesis=true);
+/// Faster version
+/// This version does not parse parenthesis and operates on a preallocated small_vector of string_view's
+  static void getWordsSimple(gch::small_vector<std::string_view> & words,std::string_view line);
 /// Get a line from the file pointer ifile
   static bool getline(FILE*,std::string & line);
 /// Get a parsed line from the file pointer ifile
@@ -78,28 +105,35 @@ public:
 /// compare two string in a case insensitive manner
   static bool caseInSensStringCompare(const std::string & str1, const std::string &str2);
 /// Convert a string to a double, reading it
-  static bool convert(const std::string & str,double & t);
+  static bool convertNoexcept(const std::string & str,double & t);
 /// Convert a string to a long double, reading it
-  static bool convert(const std::string & str,long double & t);
+  static bool convertNoexcept(const std::string & str,long double & t);
 /// Convert a string to a float, reading it
-  static bool convert(const std::string & str,float & t);
+  static bool convertNoexcept(const std::string & str,float & t);
 /// Convert a string to a int, reading it
-  static bool convert(const std::string & str,int & t);
+  static bool convertNoexcept(const std::string & str,int & t);
 /// Convert a string to a long int, reading it
-  static bool convert(const std::string & str,long int & t);
+  static bool convertNoexcept(const std::string & str,long int & t);
+/// Convert a string to a long long int, reading it
+  static bool convertNoexcept(const std::string & str,long long int & t);
 /// Convert a string to an unsigned int, reading it
-  static bool convert(const std::string & str,unsigned & t);
+  static bool convertNoexcept(const std::string & str,unsigned & t);
 /// Convert a string to a long unsigned int, reading it
-  static bool convert(const std::string & str,long unsigned & t);
+  static bool convertNoexcept(const std::string & str,long unsigned & t);
+/// Convert a string to a long long unsigned int, reading it
+  static bool convertNoexcept(const std::string & str,long long unsigned & t);
 /// Convert a string to a atom number, reading it
-  static bool convert(const std::string & str,AtomNumber & t);
+  static bool convertNoexcept(const std::string & str,AtomNumber & t);
 /// Convert a string to a string (i.e. copy)
-  static bool convert(const std::string & str,std::string & t);
+  static bool convertNoexcept(const std::string & str,std::string & t);
 /// Convert anything into a string
   template<typename T>
-  static void convert(T i,std::string & str);
+  static bool convertNoexcept(T i,std::string & str);
+/// Convert anything into anything, throwing an exception in case there is an error
 /// Remove trailing blanks
   static void trim(std::string & s);
+/// Remove leading blanks
+  static void ltrim(std::string & s);
 /// Remove trailing comments
   static void trimComments(std::string & s);
 /// Apply pbc for a unitary cell
@@ -112,7 +146,11 @@ public:
 /// will set s="xx"
   static bool getKey(std::vector<std::string>& line,const std::string & key,std::string & s,int rep=-1);
 /// Find a keyword on the input line, eventually deleting it, and saving its value to val
-  template <class T>
+  template <typename T,typename U>
+  static void convert(const T & t,U & u) {
+    plumed_assert(convertNoexcept(t,u)) <<"Error converting  "<<t;
+  }
+  template <typename T>
   static bool parse(std::vector<std::string>&line,const std::string&key,T&val,int rep=-1);
 /// Find a keyword on the input line, eventually deleting it, and saving its value to a vector
   template <class T>
@@ -141,6 +179,9 @@ public:
   static std::string extension(const std::string&);
 /// Fast int power
   static double fastpow(double base,int exp);
+/// Fast int power for power known at compile time
+  template <int exp, typename T=double>
+  static inline /*consteval*/ T fastpow(T base);
 /// Modified 0th-order Bessel function of the first kind
   static double bessel0(const double& val);
 /// Check if a string full starts with string start.
@@ -184,26 +225,194 @@ public:
 /// In case system calls to change dir are not available it throws an exception.
 /// \warning By construction, changing directory breaks thread safety! Use with care.
   class DirectoryChanger {
-    static const size_t buffersize=4096;
-    char cwd[buffersize]= {0};
+    const std::filesystem::path path;
   public:
     explicit DirectoryChanger(const char*path);
     ~DirectoryChanger();
   };
+
+  template<class T, class... Args>
+  static auto make_unique(Args&&... args) {
+    return std::make_unique<T>(std::forward<Args>(args)...);
+  }
+
+  static void set_to_zero(double*ptr,unsigned n) {
+    for(unsigned i=0; i<n; i++) {
+      ptr[i]=0.0;
+    }
+  }
+
+  template<unsigned n>
+  static void set_to_zero(std::vector<VectorGeneric<n>> & vec) {
+    unsigned s=vec.size();
+    if(s==0) {
+      return;
+    }
+    set_to_zero(&vec[0][0],s*n);
+  }
+
+  template<unsigned n,unsigned m>
+  static void set_to_zero(std::vector<TensorGeneric<n,m>> & vec) {
+    unsigned s=vec.size();
+    if(s==0) {
+      return;
+    }
+    set_to_zero(&vec[0](0,0),s*n*m);
+  }
+
+  static std::unique_ptr<std::lock_guard<std::mutex>> molfile_lock();
+  /// Build a concatenated exception message.
+  /// Should be called with an in-flight exception.
+  static std::string concatenateExceptionMessages();
+
+
+  /// Tiny class implementing faster std::string_view access to an unordered_map
+  /// It exposes a limited number of methods of std::unordered_map. Others could be added.
+  /// Importantly, when it is accessed via a std::string_view, the access does not
+  /// require constructing a std::string and is thus faster.
+  /// Deletion would be slower instead. It's not even implemented yet.
+  template<class T>
+  class FastStringUnorderedMap {
+    std::unordered_map<std::string_view,T> map;
+    std::vector<std::unique_ptr<const char[]>> keys;
+
+    // see https://stackoverflow.com/questions/34596768/stdunordered-mapfind-using-a-type-different-than-the-key-type
+    std::unique_ptr<const char[]> conv(std::string_view str) {
+      auto p=std::make_unique<char[]>(str.size()+1);
+      std::memcpy(p.get(), str.data(), str.size()+1);
+      return p;
+    }
+
+  public:
+
+    FastStringUnorderedMap() = default;
+    FastStringUnorderedMap(std::initializer_list<std::pair<const std::string_view,T>> init) {
+      for(const auto & c : init) {
+        (*this)[c.first]=c.second;
+      }
+    }
+
+    T& operator[]( const std::string_view & key ) {
+      auto f=map.find(key);
+      if(f!=map.end()) {
+        return f->second;
+      }
+      keys.push_back(conv(key));
+      return map[keys.back().get()];
+    }
+
+    auto begin() {
+      return map.begin();
+    }
+    auto end() {
+      return map.end();
+    }
+    auto begin() const {
+      return map.begin();
+    }
+    auto end() const {
+      return map.end();
+    }
+    auto find(const std::string_view & key) {
+      return map.find(key);
+    }
+    auto find(const std::string_view & key) const {
+      return map.find(key);
+    }
+  };
+
+  /// Utility to create named critical sections
+  /// Key should be usable in a std::map
+  template<class Key>
+  class CriticalSectionWithKey {
+    std::mutex mutex;
+    std::condition_variable notify;
+    std::map<Key, int> in_progress;
+  public:
+    void start(const Key & key) {
+      std::unique_lock<std::mutex> lock(mutex);
+      while (in_progress[key] > 0) {
+        // Wait if this command is already in progress.
+        notify.wait(lock);
+      }
+      // Mark this command as in progress.
+      in_progress[key]++;
+    }
+    void stop(const Key & key) {
+      std::unique_lock<std::mutex> lock(mutex);
+      // Mark this command as completed.
+      in_progress[key]--;
+      // Notify other threads that may be waiting for this command to complete.
+      notify.notify_all();
+    }
+    class Handler {
+      CriticalSectionWithKey* section{nullptr};
+      Key key;
+      Handler(CriticalSectionWithKey* section,const Key& key):
+        section(section),
+        key(key) {
+        section->start(key);
+      }
+      friend class CriticalSectionWithKey;
+    public:
+      /// Default constructor
+      Handler() = default;
+      /// Default copy constructor is deleted (not copyable)
+      Handler(const Handler & handler) = delete;
+      /// Default copy assignment is deleted (not copyable)
+      Handler & operator=(const Handler & handler) = delete;
+      /// Move constructor.
+      Handler(Handler && handler) noexcept :
+        section(handler.section),
+        key(std::move(handler.key)) {
+        handler.section=nullptr;
+      };
+      /// Move assignment.
+      Handler & operator=(Handler && handler) noexcept {
+        if(this!=&handler) {
+          if(section) {
+            section->stop(key);
+          }
+          section=handler.section;
+          key=std::move(handler.key);
+        }
+        handler.section=nullptr;
+        return *this;
+      }
+      /// Destructor
+      ~Handler() {
+        if(section) {
+          section->stop(key);
+        }
+      }
+    };
+
+    Handler startStop(const Key & key) {
+      return Handler(this,key);
+    }
+
+  };
+
 };
 
 template <class T>
 bool Tools::parse(std::vector<std::string>&line,const std::string&key,T&val,int rep) {
   std::string s;
-  if(!getKey(line,key+"=",s,rep)) return false;
-  if(s.length()>0 && !convert(s,val))return false;
+  if(!getKey(line,key+"=",s,rep)) {
+    return false;
+  }
+  if(s.length()>0 && !convertNoexcept(s,val)) {
+    return false;
+  }
   return true;
 }
 
 template <class T>
 bool Tools::parseVector(std::vector<std::string>&line,const std::string&key,std::vector<T>&val,int rep) {
   std::string s;
-  if(!getKey(line,key+"=",s,rep)) return false;
+  if(!getKey(line,key+"=",s,rep)) {
+    return false;
+  }
   val.clear();
   std::vector<std::string> words=getWords(s,"\t\n ,");
   for(unsigned i=0; i<words.size(); ++i) {
@@ -216,15 +425,16 @@ bool Tools::parseVector(std::vector<std::string>&line,const std::string&key,std:
       plumed_assert(rep<static_cast<int>(words.size()));
       s=words[rep];
     }
-    if(!convert(s,v))return false;
+    if(!convertNoexcept(s,v)) {
+      return false;
+    }
     val.push_back(v);
   }
   return true;
 }
 
 template<typename T>
-void Tools::removeDuplicates(std::vector<T>& vec)
-{
+void Tools::removeDuplicates(std::vector<T>& vec) {
   std::sort(vec.begin(), vec.end());
   vec.erase(std::unique(vec.begin(), vec.end()), vec.end());
 }
@@ -245,40 +455,49 @@ bool Tools::parseFlag(std::vector<std::string>&line,const std::string&key,bool&v
 inline
 double Tools::pbc(double x) {
 #ifdef __PLUMED_PBC_WHILE
-  while (x>0.5) x-=1.0;
-  while (x<-0.5) x+=1.0;
+  while (x>0.5) {
+    x-=1.0;
+  }
+  while (x<-0.5) {
+    x+=1.0;
+  }
   return x;
 #else
-  if(std::numeric_limits<int>::round_style == std::round_toward_zero) {
-    const double offset=100.0;
+  if constexpr (std::numeric_limits<int>::round_style == std::round_toward_zero) {
+    constexpr double offset=100.0;
     const double y=x+offset;
-    if(y>=0) return y-int(y+0.5);
-    else     return y-int(y-0.5);
-  } else if(std::numeric_limits<int>::round_style == std::round_to_nearest) {
+    if(y>=0) {
+      return y-int(y+0.5);
+    } else {
+      return y-int(y-0.5);
+    }
+  } else if constexpr (std::numeric_limits<int>::round_style == std::round_to_nearest) {
     return x-int(x);
-  } else return x-floor(x+0.5);
+  } else {
+    return x-floor(x+0.5);
+  }
 #endif
 }
 
 template<typename T>
-void Tools::convert(T i,std::string & str) {
+bool Tools::convertNoexcept(T i,std::string & str) {
   std::ostringstream ostr;
   ostr<<i;
   str=ostr.str();
+  return true;
 }
 
 inline
-double Tools::fastpow(double base, int exp)
-{
+double Tools::fastpow(double base, int exp) {
   if(exp<0) {
     exp=-exp;
     base=1.0/base;
   }
   double result = 1.0;
-  while (exp)
-  {
-    if (exp & 1)
+  while (exp) {
+    if (exp & 1) {
       result *= base;
+    }
     exp >>= 1;
     base *= base;
   }
@@ -286,21 +505,44 @@ double Tools::fastpow(double base, int exp)
   return result;
 }
 
+template <int exp, typename T, std::enable_if_t< (exp >=0), bool>>
+inline T Tools::fastpow_rec(T const base, T result) {
+  if constexpr (exp == 0) {
+    return result;
+  }
+  if constexpr (exp & 1) {
+    result *= base;
+  }
+  return fastpow_rec<(exp>>1),T> (base*base, result);
+}
+
+template <int exp, typename T>
+inline T Tools::fastpow(T const base) {
+  if constexpr (exp<0) {
+    return  fastpow_rec<-exp,T>(1.0/base,1.0);
+  } else {
+    return fastpow_rec<exp,T>(base, 1.0);
+  }
+}
+
 template<typename T>
 std::vector<T*> Tools::unique2raw(const std::vector<std::unique_ptr<T>> & x) {
   std::vector<T*> v(x.size());
-  for(unsigned i=0; i<x.size(); i++) v[i]=x[i].get();
+  for(unsigned i=0; i<x.size(); i++) {
+    v[i]=x[i].get();
+  }
   return v;
 }
 
 template<typename T>
 std::vector<const T*> Tools::unique2raw(const std::vector<std::unique_ptr<const T>> & x) {
   std::vector<const T*> v(x.size());
-  for(unsigned i=0; i<x.size(); i++) v[i]=x[i].get();
+  for(unsigned i=0; i<x.size(); i++) {
+    v[i]=x[i].get();
+  }
   return v;
 }
 
 }
 
 #endif
-
