@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2018-2021 The plumed team
+   Copyright (c) 2018-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -58,26 +58,35 @@ namespace h36 {
 
 static
 const char*
-digits_upper() { return "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"; }
+digits_upper() {
+  return "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+}
 
 static
 const char*
-digits_lower() { return "0123456789abcdefghijklmnopqrstuvwxyz"; }
+digits_lower() {
+  return "0123456789abcdefghijklmnopqrstuvwxyz";
+}
 
 static
 const char*
-value_out_of_range() { return "value out of range."; }
+value_out_of_range() {
+  return "value out of range.";
+}
 
 static
-const char* invalid_number_literal() { return "invalid number literal."; }
+const char* invalid_number_literal() {
+  return "invalid number literal.";
+}
 
 static
-const char* unsupported_width() { return "unsupported width."; }
+const char* unsupported_width() {
+  return "unsupported width.";
+}
 
 static
 void
-fill_with_stars(unsigned width, char* result)
-{
+fill_with_stars(unsigned width, char* result) {
   while (width) {
     *result++ = '*';
     width--;
@@ -92,8 +101,7 @@ encode_pure(
   unsigned digits_size,
   unsigned width,
   int value,
-  char* result)
-{
+  char* result) {
   char buf[16];
   int rest;
   unsigned i, j;
@@ -106,12 +114,20 @@ encode_pure(
   while (1) {
     rest = value / digits_size;
     buf[i++] = digits[value - rest * digits_size];
-    if (rest == 0) break;
+    if (rest == 0) {
+      break;
+    }
     value = rest;
   }
-  if (j) buf[i++] = '-';
-  for(j=i; j<width; j++) *result++ = ' ';
-  while (i != 0) *result++ = buf[--i];
+  if (j) {
+    buf[i++] = '-';
+  }
+  for(j=i; j<width; j++) {
+    *result++ = ' ';
+  }
+  while (i != 0) {
+    *result++ = buf[--i];
+  }
   *result = '\0';
 }
 
@@ -122,8 +138,7 @@ decode_pure(
   unsigned digits_size,
   const char* s,
   unsigned s_size,
-  int* result)
-{
+  int* result) {
   int si, dv;
   int have_minus = 0;
   int have_non_blank = 0;
@@ -136,10 +151,11 @@ decode_pure(
       return invalid_number_literal();
     }
     if (si == ' ') {
-      if (!have_non_blank) continue;
+      if (!have_non_blank) {
+        continue;
+      }
       value *= digits_size;
-    }
-    else if (si == '-') {
+    } else if (si == '-') {
       if (have_non_blank) {
         *result = 0;
         return invalid_number_literal();
@@ -147,8 +163,7 @@ decode_pure(
       have_non_blank = 1;
       have_minus = 1;
       continue;
-    }
-    else {
+    } else {
       have_non_blank = 1;
       dv = digits_values[si];
       if (dv < 0 || dv >= digits_size) {
@@ -159,7 +174,9 @@ decode_pure(
       value += dv;
     }
   }
-  if (have_minus) value = -value;
+  if (have_minus) {
+    value = -value;
+  }
   *result = value;
   return 0;
 }
@@ -183,8 +200,7 @@ decode_pure(
       if (errmsg) throw std::runtime_error(errmsg);
  */
 const char*
-hy36encode(unsigned width, int value, char* result)
-{
+hy36encode(unsigned width, int value, char* result) {
   int i = value;
   if (width == 4U) {
     if (i >= -999) {
@@ -205,8 +221,7 @@ hy36encode(unsigned width, int value, char* result)
         return 0;
       }
     }
-  }
-  else if (width == 5U) {
+  } else if (width == 5U) {
     if (i >= -9999) {
       if (i < 100000) {
         encode_pure(digits_upper(), 10U, 5U, i, result);
@@ -225,8 +240,7 @@ hy36encode(unsigned width, int value, char* result)
         return 0;
       }
     }
-  }
-  else {
+  } else {
     fill_with_stars(width, result);
     return unsupported_width();
   }
@@ -257,8 +271,7 @@ hy36encode(unsigned width, int value, char* result)
       if (errmsg) throw std::runtime_error(errmsg);
  */
 const char*
-hy36decode(unsigned width, const char* s, unsigned s_size, int* result)
-{
+hy36decode(unsigned width, const char* s, unsigned s_size, int* result) {
   static const std::vector<int> digits_values_upper_vector([]() {
     std::vector<int> ret(128U,-1);
     for(unsigned i=0; i<36U; i++) {
@@ -269,7 +282,8 @@ hy36decode(unsigned width, const char* s, unsigned s_size, int* result)
       ret[di] = i;
     }
     return ret;
-  }());
+  }
+  ());
   static const int* digits_values_upper=digits_values_upper_vector.data();
   static const std::vector<int> digits_values_lower_vector([]() {
     std::vector<int> ret(128U,-1);
@@ -281,7 +295,8 @@ hy36decode(unsigned width, const char* s, unsigned s_size, int* result)
       ret[di] = i;
     }
     return ret;
-  }());
+  }
+  ());
   static const int* digits_values_lower=digits_values_lower_vector.data();
   int di;
   const char* errmsg;
@@ -292,31 +307,35 @@ hy36decode(unsigned width, const char* s, unsigned s_size, int* result)
         errmsg = decode_pure(digits_values_upper, 36U, s, s_size, result);
         if (errmsg == 0) {
           /* result - 10*36**(width-1) + 10**width */
-          if      (width == 4U) (*result) -= 456560;
-          else if (width == 5U) (*result) -= 16696160;
-          else {
+          if      (width == 4U) {
+            (*result) -= 456560;
+          } else if (width == 5U) {
+            (*result) -= 16696160;
+          } else {
             *result = 0;
             return unsupported_width();
           }
           return 0;
         }
-      }
-      else if (digits_values_lower[di] >= 10) {
+      } else if (digits_values_lower[di] >= 10) {
         errmsg = decode_pure(digits_values_lower, 36U, s, s_size, result);
         if (errmsg == 0) {
           /* result + 16*36**(width-1) + 10**width */
-          if      (width == 4U) (*result) += 756496;
-          else if (width == 5U) (*result) += 26973856;
-          else {
+          if      (width == 4U) {
+            (*result) += 756496;
+          } else if (width == 5U) {
+            (*result) += 26973856;
+          } else {
             *result = 0;
             return unsupported_width();
           }
           return 0;
         }
-      }
-      else {
+      } else {
         errmsg = decode_pure(digits_values_upper, 10U, s, s_size, result);
-        if (errmsg) return errmsg;
+        if (errmsg) {
+          return errmsg;
+        }
         if (!(width == 4U || width == 5U)) {
           *result = 0;
           return unsupported_width();
