@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2015-2021 The plumed team
+   Copyright (c) 2015-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,7 +20,7 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "ActionWithVirtualAtom.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "tools/Vector.h"
 #include "tools/Exception.h"
 
@@ -40,7 +40,7 @@ It is also possible to assign a predefined charge or mass to the atom.
 Similar to \ref POSITION this variable is not invariant for translation
 of the system. Adding a force on it can create serious troubles.
 
-Notice that the distance between to atoms created
+Notice that the distance between two atoms created
 using FIXEDATOM is invariant for translation.
 Additionally, if one first align atoms to a reference using \ref FIT_TO_TEMPLATE,
 then it is safe to add further fixed atoms without breaking translational invariance.
@@ -83,9 +83,9 @@ END
 
 
 class FixedAtom:
-  public ActionWithVirtualAtom
-{
+  public ActionWithVirtualAtom {
   Vector coord;
+  std::vector<Tensor> deriv;
   double mass,charge;
   bool scaled_components;
 public:
@@ -106,17 +106,20 @@ void FixedAtom::registerKeywords(Keywords& keys) {
 
 FixedAtom::FixedAtom(const ActionOptions&ao):
   Action(ao),
-  ActionWithVirtualAtom(ao)
-{
+  ActionWithVirtualAtom(ao) {
   std::vector<AtomNumber> atoms;
   parseAtomList("ATOMS",atoms);
-  if(atoms.size()!=0) error("ATOMS should be empty");
+  if(atoms.size()!=0) {
+    error("ATOMS should be empty");
+  }
 
   parseFlag("SCALED_COMPONENTS",scaled_components);
 
   std::vector<double> at;
   parseVector("AT",at);
-  if(at.size()!=3) error("AT should be a list of three real numbers");
+  if(at.size()!=3) {
+    error("AT should be a list of three real numbers");
+  }
 
   parse("SET_MASS",mass);
   parse("SET_CHARGE",charge);
@@ -127,11 +130,13 @@ FixedAtom::FixedAtom(const ActionOptions&ao):
 
   checkRead();
   log<<"  AT position "<<coord[0]<<" "<<coord[1]<<" "<<coord[2]<<"\n";
-  if(scaled_components) log<<"  position is in scaled components\n";
+  if(scaled_components) {
+    log<<"  position is in scaled components\n";
+  }
 }
 
 void FixedAtom::calculate() {
-  std::vector<Tensor> deriv(getNumberOfAtoms());
+  deriv.resize(getNumberOfAtoms());
   if(scaled_components) {
     setPosition(getPbc().scaledToReal(coord));
   } else {
@@ -141,7 +146,9 @@ void FixedAtom::calculate() {
   setCharge(charge);
   setAtomsDerivatives(deriv);
 // Virial contribution
-  if(!scaled_components) setBoxDerivativesNoPbc();
+  if(!scaled_components) {
+    setBoxDerivativesNoPbc();
+  }
 // notice that with scaled components there is no additional virial contribution
 }
 
