@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2012-2019 The plumed team
+   Copyright (c) 2012-2023 The plumed team
    (see the PEOPLE file at the root of the distribution for a list of names)
 
    See http://www.plumed.org for more information.
@@ -20,11 +20,10 @@
    along with plumed.  If not, see <http://www.gnu.org/licenses/>.
 +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
 #include "ActionWithVirtualAtom.h"
-#include "ActionRegister.h"
+#include "core/ActionRegister.h"
 #include "tools/Vector.h"
 #include "tools/Exception.h"
-
-using namespace std;
+#include <array>
 
 namespace PLMD {
 namespace vatom {
@@ -36,6 +35,17 @@ Calculate the absolute position of a ghost atom with fixed coordinates in the lo
 The computed ghost atom is stored as a virtual atom that can be accessed in
  an atom list through the the label for the GHOST action that creates it.
 
+When running with periodic boundary conditions, the atoms should be
+in the proper periodic image. This is done automatically since PLUMED 2.10,
+by considering the ordered list of atoms and rebuilding the molecule using a procedure
+that is equivalent to that done in \ref WHOLEMOLECULES . Notice that
+rebuilding is local to this action. This is different from \ref WHOLEMOLECULES
+which actually modifies the coordinates stored in PLUMED.
+
+In case you want to recover the old behavior you should use the NOPBC flag.
+In that case you need to take care that atoms are in the correct
+periodic image.
+
 \par Examples
 
 The following input instructs plumed to print the distance between the
@@ -52,12 +62,13 @@ PRINT ARG=d1
 
 
 class Ghost:
-  public ActionWithVirtualAtom
-{
-  vector<double> coord;
+  public ActionWithVirtualAtom {
+  std::vector<double> coord;
+  std::vector<Tensor> deriv;
+  bool nopbc=false;
 public:
   explicit Ghost(const ActionOptions&ao);
-  void calculate();
+  void calculate() override;
   static void registerKeywords( Keywords& keys );
 };
 
@@ -66,34 +77,53 @@ PLUMED_REGISTER_ACTION(Ghost,"GHOST")
 void Ghost::registerKeywords(Keywords& keys) {
   ActionWithVirtualAtom::registerKeywords(keys);
   keys.add("atoms","COORDINATES","coordinates of the ghost atom in the local reference frame");
+  keys.addFlag("NOPBC",false,"ignore the periodic boundary conditions when calculating distances");
 }
 
 Ghost::Ghost(const ActionOptions&ao):
   Action(ao),
-  ActionWithVirtualAtom(ao)
-{
-  vector<AtomNumber> atoms;
+  ActionWithVirtualAtom(ao) {
+  std::vector<AtomNumber> atoms;
   parseAtomList("ATOMS",atoms);
-  if(atoms.size()!=3) error("ATOMS should contain a list of three atoms");
+  if(atoms.size()!=3) {
+    error("ATOMS should contain a list of three atoms");
+  }
 
   parseVector("COORDINATES",coord);
-  if(coord.size()!=3) error("COORDINATES should be a list of three real numbers");
+  if(coord.size()!=3) {
+    error("COORDINATES should be a list of three real numbers");
+  }
+
+  parseFlag("NOPBC",nopbc);
 
   checkRead();
   log.printf("  of atoms");
-  for(unsigned i=0; i<atoms.size(); ++i) log.printf(" %d",atoms[i].serial());
+  for(unsigned i=0; i<atoms.size(); ++i) {
+    log.printf(" %d",atoms[i].serial());
+  }
   log.printf("\n");
+
+  if(nopbc) {
+    log<<"  PBC will be ignored\n";
+  } else {
+    log<<"  broken molecules will be rebuilt assuming atoms are in the proper order\n";
+  }
   requestAtoms(atoms);
 }
 
 void Ghost::calculate() {
+
+  if(!nopbc) {
+    makeWhole();
+  }
+
   Vector pos;
-  vector<Tensor> deriv(getNumberOfAtoms());
-  vector<Vector> n;
+  deriv.resize(getNumberOfAtoms());
+  std::array<Vector,3> n;
 
 // first versor
   Vector n01 = delta(getPosition(0), getPosition(1));
-  n.push_back(n01/n01.modulo());
+  n[0]=n01/n01.modulo();
 
 // auxiliary vector
   Vector n02 = delta(getPosition(0), getPosition(2));
@@ -101,10 +131,10 @@ void Ghost::calculate() {
 // second versor
   Vector n03 = crossProduct(n[0],n02);
   double n03_norm = n03.modulo();
-  n.push_back(n03/n03_norm);
+  n[1]=n03/n03_norm;
 
 // third versor
-  n.push_back(crossProduct(n[0],n[1]));
+  n[2]=crossProduct(n[0],n[1]);
 
 // origin of the reference system
   pos = getPosition(0);
