@@ -1,5 +1,5 @@
 /* +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-   Copyright (c) 2016-2018 The VES code team
+   Copyright (c) 2016-2021 The VES code team
    (see the PEOPLE-VES file at the root of this folder for a list of names)
 
    See http://www.ves-code.org for more information.
@@ -27,7 +27,7 @@
 #include "GridProjWeights.h"
 
 #include "cltools/CLTool.h"
-#include "cltools/CLToolRegister.h"
+#include "core/CLToolRegister.h"
 #include "tools/Vector.h"
 #include "tools/Random.h"
 #include "tools/Grid.h"
@@ -134,14 +134,16 @@ PRINT ARG=p.x,p.y,ene FILE=colvar.data FMT=%8.4f
 
 class MD_LinearExpansionPES : public PLMD::CLTool {
 public:
-  std::string description() const override {return "MD of a one particle on a linear expansion PES";}
+  std::string description() const override {
+    return "MD of a one particle on a linear expansion PES";
+  }
   static void registerKeywords( Keywords& keys );
   explicit MD_LinearExpansionPES( const CLToolOptions& co );
   int main( FILE* in, FILE* out, PLMD::Communicator& pc) override;
 private:
-  unsigned int dim;
+  size_t dim;
   std::string dim_string_prefix;
-  LinearBasisSetExpansion* potential_expansion_pntr;
+  std::unique_ptr<LinearBasisSetExpansion> potential_expansion_pntr;
   //
   double calc_energy( const std::vector<Vector>&, std::vector<Vector>& );
   double calc_temp( const std::vector<Vector>& );
@@ -177,9 +179,7 @@ void MD_LinearExpansionPES::registerKeywords( Keywords& keys ) {
 MD_LinearExpansionPES::MD_LinearExpansionPES( const CLToolOptions& co ):
   CLTool(co),
   dim(0),
-  dim_string_prefix("dim"),
-  potential_expansion_pntr(NULL)
-{
+  dim_string_prefix("dim") {
   inputdata=ifile; //commandline;
 }
 
@@ -214,10 +214,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   Random random;
   unsigned int stepWrite=1000;
 
-  PLMD::PlumedMain* plumed=NULL;
-  PLMD::PlumedMain* plumed_bf=NULL;
+  std::unique_ptr<PLMD::PlumedMain> plumed;
 
-  unsigned int replicas;
+  size_t replicas;
   unsigned int coresPerReplica;
   parse("replicas",replicas);
   if(replicas==1) {
@@ -236,7 +235,7 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     pc.Split(intra.Get_rank(),0,inter);
   }
 
-  unsigned int nsteps;
+  long long unsigned int nsteps;
   parse("nstep",nsteps);
   double tstep;
   parse("tstep",tstep);
@@ -246,11 +245,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   parseVector("temperature",temps_vec);
   if(temps_vec.size()==1) {
     temp = temps_vec[0];
-  }
-  else if(replicas > 1 && temps_vec.size()==replicas) {
+  } else if(replicas > 1 && temps_vec.size()==replicas) {
     temp = temps_vec[inter.Get_rank()];
-  }
-  else {
+  } else {
     error("problem with temperature keyword, you need to give either one value or a value for each replica.");
   }
   //
@@ -259,11 +256,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   parseVector("friction",frictions_vec);
   if(frictions_vec.size()==1) {
     friction = frictions_vec[0];
-  }
-  else if(frictions_vec.size()==replicas) {
+  } else if(frictions_vec.size()==replicas) {
     friction = frictions_vec[inter.Get_rank()];
-  }
-  else {
+  } else {
     error("problem with friction keyword, you need to give either one value or a value for each replica.");
   }
   //
@@ -271,19 +266,24 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   std::vector<int> seeds_vec(0);
   parseVector("random_seed",seeds_vec);
   for(unsigned int i=0; i<seeds_vec.size(); i++) {
-    if(seeds_vec[i]>0) {seeds_vec[i] = -seeds_vec[i];}
+    if(seeds_vec[i]>0) {
+      seeds_vec[i] = -seeds_vec[i];
+    }
   }
   if(replicas==1) {
-    if(seeds_vec.size()>1) {error("problem with random_seed keyword, for a single replica you should only give one value");}
+    if(seeds_vec.size()>1) {
+      error("problem with random_seed keyword, for a single replica you should only give one value");
+    }
     seed = seeds_vec[0];
-  }
-  else {
+  } else {
     if(seeds_vec.size()!=1 && seeds_vec.size()!=replicas) {
       error("problem with random_seed keyword, for multiple replicas you should give either one value or a separate value for each replica");
     }
     if(seeds_vec.size()==1) {
       seeds_vec.resize(replicas);
-      for(unsigned int i=1; i<seeds_vec.size(); i++) {seeds_vec[i] = seeds_vec[0] + i;}
+      for(unsigned int i=1; i<seeds_vec.size(); i++) {
+        seeds_vec[i] = seeds_vec[0] + i;
+      }
     }
     seed = seeds_vec[inter.Get_rank()];
   }
@@ -306,35 +306,41 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
         initPos[i][k]=initPosTmp[k];
       }
     }
-  }
-  else if(initPosTmp.size()==dim*replicas) {
+  } else if(initPosTmp.size()==dim*replicas) {
     for(unsigned int i=0; i<replicas; i++) {
       for(unsigned int k=0; k<dim; k++) {
         initPos[i][k]=initPosTmp[i*dim+k];
       }
     }
-  }
-  else {
+  } else {
     error("problem with initial_position keyword, you need to give either one value or a value for each replica.");
   }
 
-
-  plumed_bf = new PLMD::PlumedMain;
-  unsigned int nn=1;
+  auto deleter=[](FILE* f) {
+    fclose(f);
+  };
   FILE* file_dummy = fopen("/dev/null","w+");
+  plumed_assert(file_dummy);
+  // call fclose when file_dummy_deleter goes out of scope
+  std::unique_ptr<FILE,decltype(deleter)> file_dummy_deleter(file_dummy,deleter);
+  // Note: this should be declared before plumed_bf to make sure the file is closed after plumed_bf has been destroyed
+
+  auto plumed_bf = Tools::make_unique<PLMD::PlumedMain>();
+  unsigned int nn=1;
   plumed_bf->cmd("setNatoms",&nn);
   plumed_bf->cmd("setLog",file_dummy);
   plumed_bf->cmd("init",&nn);
   std::vector<BasisFunctions*> basisf_pntrs(dim);
   std::vector<std::string> basisf_keywords(dim);
-  std::vector<Value*> args(dim);
+  std::vector<std::unique_ptr<Value>> args(dim);
   std::vector<bool> periodic(dim);
   std::vector<double> interval_min(dim);
   std::vector<double> interval_max(dim);
   std::vector<double> interval_range(dim);
   for(unsigned int i=0; i<dim; i++) {
     std::string bf_keyword;
-    std::string is; Tools::convert(i+1,is);
+    std::string is;
+    Tools::convert(i+1,is);
     parse("basis_functions_"+is,bf_keyword);
     if(bf_keyword.size()==0) {
       error("basis_functions_"+is+" is needed");
@@ -345,7 +351,7 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     basisf_keywords[i] = bf_keyword;
     plumed_bf->readInputLine(bf_keyword+" LABEL="+dim_string_prefix+is);
     basisf_pntrs[i] = plumed_bf->getActionSet().selectWithLabel<BasisFunctions*>(dim_string_prefix+is);
-    args[i] = new Value(NULL,dim_string_prefix+is,false);
+    args[i] = Tools::make_unique<Value>(nullptr,dim_string_prefix+is,false);
     args[i]->setNotPeriodic();
     periodic[i] = basisf_pntrs[i]->arePeriodic();
     interval_min[i] = basisf_pntrs[i]->intervalMin();
@@ -353,8 +359,8 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     interval_range[i] = basisf_pntrs[i]->intervalMax()-basisf_pntrs[i]->intervalMin();
   }
   Communicator comm_dummy;
-  CoeffsVector* coeffs_pntr = new CoeffsVector("pot.coeffs",args,basisf_pntrs,comm_dummy,false);
-  potential_expansion_pntr = new LinearBasisSetExpansion("potential",1.0/temp,comm_dummy,args,basisf_pntrs,coeffs_pntr);
+  auto coeffs_pntr = Tools::make_unique<CoeffsVector>("pot.coeffs",Tools::unique2raw(args),basisf_pntrs,comm_dummy,false);
+  potential_expansion_pntr = Tools::make_unique<LinearBasisSetExpansion>("potential",1.0/temp,comm_dummy,Tools::unique2raw(args),basisf_pntrs,coeffs_pntr.get());
 
   std::string template_coeffs_fname="";
   parse("template_coeffs_file",template_coeffs_fname);
@@ -364,7 +370,7 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     ofile_coeffstmpl.open(template_coeffs_fname);
     coeffs_pntr->writeToFile(ofile_coeffstmpl,true);
     ofile_coeffstmpl.close();
-    printf("Only generating a template coefficient file - Should stop now.");
+    std::printf("Only generating a template coefficient file - Should stop now.");
     return 0;
   }
 
@@ -374,12 +380,10 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   bool diff_input_coeffs = false;
   if(input_coeffs_fnames.size()==1) {
     input_coeffs_fname = input_coeffs_fnames[0];
-  }
-  else if(replicas > 1 && input_coeffs_fnames.size()==replicas) {
+  } else if(replicas > 1 && input_coeffs_fnames.size()==replicas) {
     diff_input_coeffs = true;
     input_coeffs_fname = input_coeffs_fnames[inter.Get_rank()];
-  }
-  else {
+  } else {
     error("problem with coeffs_file keyword, you need to give either one value or a value for each replica.");
   }
   coeffs_pntr->readFromFile(input_coeffs_fname,true,true);
@@ -389,12 +393,10 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     double coeffs_prefactor = 1.0;
     if(coeffs_prefactors.size()==1) {
       coeffs_prefactor = coeffs_prefactors[0];
-    }
-    else if(replicas > 1 && coeffs_prefactors.size()==replicas) {
+    } else if(replicas > 1 && coeffs_prefactors.size()==replicas) {
       diff_input_coeffs = true;
       coeffs_prefactor = coeffs_prefactors[inter.Get_rank()];
-    }
-    else {
+    } else {
       error("problem with coeffs_prefactor keyword, you need to give either one value or a value for each replica.");
     }
     coeffs_pntr->scaleAllValues(coeffs_prefactor);
@@ -422,11 +424,12 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   ofile_potential.close();
   if(dim>1) {
     for(unsigned int i=0; i<dim; i++) {
-      std::string is; Tools::convert(i+1,is);
+      std::string is;
+      Tools::convert(i+1,is);
       std::vector<std::string> proj_arg(1);
       proj_arg[0] = dim_string_prefix+is;
-      FesWeight* Fw = new FesWeight(1/temp);
-      Grid proj_grid = (potential_expansion_pntr->getPntrToBiasGrid())->project(proj_arg,Fw);
+      auto Fw = Tools::make_unique<FesWeight>(1/temp);
+      Grid proj_grid = (potential_expansion_pntr->getPntrToBiasGrid())->project(proj_arg,Fw.get());
       proj_grid.setMinToZero();
 
       std::string output_potential_proj_fname = FileBase::appendSuffix(output_potential_fname,"."+dim_string_prefix+is);
@@ -435,7 +438,6 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
       ofile_potential_proj.open(output_potential_proj_fname);
       proj_grid.writeToFile(ofile_potential_proj);
       ofile_potential_proj.close();
-      delete Fw;
     }
   }
 
@@ -481,32 +483,42 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   ofile_coeffsout.close();
 
   if(pc.Get_rank() == 0) {
-    fprintf(out,"Replicas                              %u\n",replicas);
-    fprintf(out,"Cores per replica                     %u\n",coresPerReplica);
-    fprintf(out,"Number of steps                       %u\n",nsteps);
-    fprintf(out,"Timestep                              %f\n",tstep);
-    fprintf(out,"Temperature                           %f",temps_vec[0]);
-    for(unsigned int i=1; i<temps_vec.size(); i++) {fprintf(out,",%f",temps_vec[i]);}
-    fprintf(out,"\n");
-    fprintf(out,"Friction                              %f",frictions_vec[0]);
-    for(unsigned int i=1; i<frictions_vec.size(); i++) {fprintf(out,",%f",frictions_vec[i]);}
-    fprintf(out,"\n");
-    fprintf(out,"Random seed                           %d",seeds_vec[0]);
-    for(unsigned int i=1; i<seeds_vec.size(); i++) {fprintf(out,",%d",seeds_vec[i]);}
-    fprintf(out,"\n");
-    fprintf(out,"Dimensions                            %u\n",dim);
+    std::fprintf(out,"Replicas                              %zu\n",replicas);
+    std::fprintf(out,"Cores per replica                     %u\n",coresPerReplica);
+    std::fprintf(out,"Number of steps                       %llu\n",nsteps);
+    std::fprintf(out,"Timestep                              %f\n",tstep);
+    std::fprintf(out,"Temperature                           %f",temps_vec[0]);
+    for(unsigned int i=1; i<temps_vec.size(); i++) {
+      std::fprintf(out,",%f",temps_vec[i]);
+    }
+    std::fprintf(out,"\n");
+    std::fprintf(out,"Friction                              %f",frictions_vec[0]);
+    for(unsigned int i=1; i<frictions_vec.size(); i++) {
+      std::fprintf(out,",%f",frictions_vec[i]);
+    }
+    std::fprintf(out,"\n");
+    std::fprintf(out,"Random seed                           %d",seeds_vec[0]);
+    for(unsigned int i=1; i<seeds_vec.size(); i++) {
+      std::fprintf(out,",%d",seeds_vec[i]);
+    }
+    std::fprintf(out,"\n");
+    std::fprintf(out,"Dimensions                            %zu\n",dim);
     for(unsigned int i=0; i<dim; i++) {
-      fprintf(out,"Basis Function %u                      %s\n",i+1,basisf_keywords[i].c_str());
+      std::fprintf(out,"Basis Function %u                      %s\n",i+1,basisf_keywords[i].c_str());
+    }
+    std::fprintf(out,"PLUMED input                          %s",plumed_inputfiles[0].c_str());
+    for(unsigned int i=1; i<plumed_inputfiles.size(); i++) {
+      std::fprintf(out,",%s",plumed_inputfiles[i].c_str());
+    }
+    std::fprintf(out,"\n");
+    std::fprintf(out,"kBoltzmann taken as 1, use NATURAL_UNITS in the plumed input\n");
+    if(diff_input_coeffs) {
+      std::fprintf(out,"using different coefficients for each replica\n");
     }
-    fprintf(out,"PLUMED input                          %s",plumed_inputfiles[0].c_str());
-    for(unsigned int i=1; i<plumed_inputfiles.size(); i++) {fprintf(out,",%s",plumed_inputfiles[i].c_str());}
-    fprintf(out,"\n");
-    fprintf(out,"kBoltzmann taken as 1, use NATURAL_UNITS in the plumed input\n");
-    if(diff_input_coeffs) {fprintf(out,"using different coefficients for each replica\n");}
   }
 
 
-  plumed=new PLMD::PlumedMain;
+  plumed=Tools::make_unique<PLMD::PlumedMain>();
 
 
 
@@ -525,7 +537,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
         error("More than 1 replica but no MPI");
       }
     } else {
-      if(Communicator::initialized()) plumed->cmd("setMPIComm",&pc.Get_comm());
+      if(Communicator::initialized()) {
+        plumed->cmd("setMPIComm",&pc.Get_comm());
+      }
     }
   }
 
@@ -543,9 +557,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   }
 
   if(plumed) {
-    plumed->cmd("setNoVirial");
     int natoms=1;
     plumed->cmd("setNatoms",&natoms);
+    plumed->cmd("setNoVirial");
     plumed->cmd("setMDEngine","mdrunner_linearexpansion");
     plumed->cmd("setTimestep",&tstep);
     plumed->cmd("setPlumedDat",plumed_input.c_str());
@@ -559,16 +573,20 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
   // Setup random number generator
   random.setSeed(seed);
 
-  double potential, therm_eng=0; std::vector<double> masses(1,1);
+  double potential, therm_eng=0;
+  std::vector<double> masses(1,1);
   std::vector<Vector> positions(1), velocities(1), forces(1);
   for(unsigned int k=0; k<dim; k++) {
     positions[0][k] = initPos[inter.Get_rank()][k];
     if(periodic[k]) {
       positions[0][k] = positions[0][k] - floor((positions[0][k]-interval_min[k])/interval_range[k])*interval_range[k];
-    }
-    else {
-      if(positions[0][k]>interval_max[k]) {positions[0][k]=interval_max[k];}
-      if(positions[0][k]<interval_min[k]) {positions[0][k]=interval_min[k];}
+    } else {
+      if(positions[0][k]>interval_max[k]) {
+        positions[0][k]=interval_max[k];
+      }
+      if(positions[0][k]<interval_min[k]) {
+        positions[0][k]=interval_min[k];
+      }
     }
   }
 
@@ -577,18 +595,22 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     velocities[0][k]=random.Gaussian() * sqrt( temp );
   }
 
-  potential=calc_energy(positions,forces); double ttt=calc_temp(velocities);
+  potential=calc_energy(positions,forces);
+  double ttt=calc_temp(velocities);
 
   FILE* fp=fopen(stats_filename.c_str(),"w+");
+  // call fclose when fp_deleter goes out of scope
+  std::unique_ptr<FILE,decltype(deleter)> fp_deleter(fp,deleter);
+
   double conserved = potential+1.5*ttt+therm_eng;
-  //fprintf(fp,"%d %f %f %f %f %f %f %f %f \n", 0, 0., positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
+  //std::fprintf(fp,"%d %f %f %f %f %f %f %f %f \n", 0, 0., positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
   if( intra.Get_rank()==0 ) {
-    fprintf(fp,"%d %f %f %f %f %f %f %f %f \n", 0, 0., positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
+    std::fprintf(fp,"%d %f %f %f %f %f %f %f %f \n", 0, 0., positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
   }
 
   if(plumed) {
-    int step_tmp = 0;
-    plumed->cmd("setStep",&step_tmp);
+    long long unsigned int step_tmp = 0;
+    plumed->cmd("setStepLongLong",&step_tmp);
     plumed->cmd("setMasses",&masses[0]);
     plumed->cmd("setForces",&forces[0][0]);
     plumed->cmd("setEnergy",&potential);
@@ -596,8 +618,8 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     plumed->cmd("calc");
   }
 
-  for(unsigned int istep=0; istep<nsteps; ++istep) {
-    //if( istep%20==0 && pc.Get_rank()==0 ) printf("Doing step %d\n",istep);
+  for(long long unsigned int istep=0; istep<nsteps; ++istep) {
+    //if( istep%20==0 && pc.Get_rank()==0 ) printf("Doing step %llu\n",istep);
 
     // Langevin thermostat
     double lscale=exp(-0.5*tstep*friction); //exp(-0.5*tstep/friction);
@@ -615,8 +637,7 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
 
       if(periodic[k]) {
         positions[0][k] = positions[0][k] - floor((positions[0][k]-interval_min[k])/interval_range[k])*interval_range[k];
-      }
-      else {
+      } else {
         if(positions[0][k]>interval_max[k]) {
           positions[0][k]=interval_max[k];
           velocities[0][k]=-std::abs(velocities[0][k]);
@@ -631,9 +652,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     potential=calc_energy(positions,forces);
 
     if(plumed) {
-      int istepplusone=istep+1;
+      long long unsigned int istepplusone=istep+1;
       plumedWantsToStop=0;
-      plumed->cmd("setStep",&istepplusone);
+      plumed->cmd("setStepLongLong",&istepplusone);
       plumed->cmd("setMasses",&masses[0]);
       plumed->cmd("setForces",&forces[0][0]);
       plumed->cmd("setEnergy",&potential);
@@ -641,7 +662,9 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
       plumed->cmd("setStopFlag",&plumedWantsToStop);
       plumed->cmd("calc");
       //if(istep%2000==0) plumed->cmd("writeCheckPointFile");
-      if(plumedWantsToStop) nsteps=istep;
+      if(plumedWantsToStop) {
+        nsteps=istep;
+      }
     }
 
     // Second step of velocity verlet
@@ -662,20 +685,12 @@ int MD_LinearExpansionPES::main( FILE* in, FILE* out, PLMD::Communicator& pc) {
     ttt = calc_temp( velocities );
     conserved = potential+1.5*ttt+therm_eng;
     if( (intra.Get_rank()==0) && ((istep % stepWrite)==0) ) {
-      fprintf(fp,"%u %f %f %f %f %f %f %f %f \n", istep, istep*tstep, positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
+      std::fprintf(fp,"%llu %f %f %f %f %f %f %f %f \n", istep, istep*tstep, positions[0][0], positions[0][1], positions[0][2], conserved, ttt, potential, therm_eng );
     }
   }
 
-  if(plumed) {delete plumed;}
-  if(plumed_bf) {delete plumed_bf;}
-  if(potential_expansion_pntr) {delete potential_expansion_pntr;}
-  delete coeffs_pntr;
-  for(unsigned int i=0; i<args.size(); i++) {delete args[i];}
-  args.clear();
   //printf("Rank: %d, Size: %d \n", pc.Get_rank(), pc.Get_size() );
   //printf("Rank: %d, Size: %d, MultiSimCommRank: %d, MultiSimCommSize: %d \n", pc.Get_rank(), pc.Get_size(), multi_sim_comm.Get_rank(), multi_sim_comm.Get_size() );
-  fclose(fp);
-  fclose(file_dummy);
 
   return 0;
 }
